# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/postgresql/v1/cluster.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/postgresql/v1/cluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from yandex.cloud.mdb.postgresql.v1.config import host10_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host10__pb2
from yandex.cloud.mdb.postgresql.v1.config import host10_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host10__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host11_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host11__pb2
from yandex.cloud.mdb.postgresql.v1.config import host11_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host11__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host12_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host12__pb2
from yandex.cloud.mdb.postgresql.v1.config import host12_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host12__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host13_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host13__pb2
from yandex.cloud.mdb.postgresql.v1.config import host13_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host13__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host14_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host14__pb2
from yandex.cloud.mdb.postgresql.v1.config import host14_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host14__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host15_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host15__pb2
from yandex.cloud.mdb.postgresql.v1.config import host15_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host15__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host16_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host16__pb2
from yandex.cloud.mdb.postgresql.v1.config import host16_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host16__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host17_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host17__pb2
from yandex.cloud.mdb.postgresql.v1.config import host17_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host17__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host9_6_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host9__6__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql10_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql10__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql10_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql10__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql11_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql11__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql11_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql11__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql12_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql12__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql12_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql12__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql13_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql13__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql13_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql13__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql14_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql14__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql14_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql14__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql15_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql15__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql15_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql15__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql16_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql16__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql16_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql16__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql17_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql17__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql17_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql17__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql9_6_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql9__6__pb2
from yandex.cloud.mdb.postgresql.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_maintenance__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/mdb/postgresql/v1/cluster.proto\x12\x1eyandex.cloud.mdb.postgresql.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/type/timeofday.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host10.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host10_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host11.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host11_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host12.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host12_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host13.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host13_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host14.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host14_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host15.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host15_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host16.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host16_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host17.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host17_1c.proto\x1a\x33yandex/cloud/mdb/postgresql/v1/config/host9_6.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql10.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql10_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql11.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql11_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql12.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql12_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql13.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql13_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql14.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql14_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql15.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql15_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql16.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql16_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql17.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql17_1c.proto\x1a\x39yandex/cloud/mdb/postgresql/v1/config/postgresql9_6.proto\x1a\x30yandex/cloud/mdb/postgresql/v1/maintenance.proto\x1a\x1dyandex/cloud/validation.proto\"\xc4\x08\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x43\n\x06labels\x18\x06 \x03(\x0b\x32\x33.yandex.cloud.mdb.postgresql.v1.Cluster.LabelsEntry\x12H\n\x0b\x65nvironment\x18\x07 \x01(\x0e\x32\x33.yandex.cloud.mdb.postgresql.v1.Cluster.Environment\x12>\n\nmonitoring\x18\x08 \x03(\x0b\x32*.yandex.cloud.mdb.postgresql.v1.Monitoring\x12=\n\x06\x63onfig\x18\t \x01(\x0b\x32-.yandex.cloud.mdb.postgresql.v1.ClusterConfig\x12\x12\n\nnetwork_id\x18\n \x01(\t\x12>\n\x06health\x18\x0b \x01(\x0e\x32..yandex.cloud.mdb.postgresql.v1.Cluster.Health\x12>\n\x06status\x18\x0c \x01(\x0e\x32..yandex.cloud.mdb.postgresql.v1.Cluster.Status\x12M\n\x12maintenance_window\x18\r \x01(\x0b\x32\x31.yandex.cloud.mdb.postgresql.v1.MaintenanceWindow\x12O\n\x11planned_operation\x18\x0e \x01(\x0b\x32\x34.yandex.cloud.mdb.postgresql.v1.MaintenanceOperation\x12\x1a\n\x12security_group_ids\x18\x0f \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x10 \x01(\x08\x12\x16\n\x0ehost_group_ids\x18\x11 \x03(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\x0b\x45nvironment\x12\x1b\n\x17\x45NVIRONMENT_UNSPECIFIED\x10\x00\x12\x0e\n\nPRODUCTION\x10\x01\x12\r\n\tPRESTABLE\x10\x02\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"y\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08UPDATING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\x0b\n\x07STOPPED\x10\x06\x12\x0c\n\x08STARTING\x10\x07\"=\n\nMonitoring\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\"\xd2\x14\n\rClusterConfig\x12\x0f\n\x07version\x18\x01 \x01(\t\x12t\n\x15postgresql_config_9_6\x18\x02 \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet9_6H\x00R\x14postgresqlConfig_9_6\x12z\n\x17postgresql_config_10_1c\x18\n \x01(\x0b\x32?.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet10_1CH\x00R\x16postgresqlConfig_10_1c\x12q\n\x14postgresql_config_10\x18\x03 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet10H\x00R\x13postgresqlConfig_10\x12q\n\x14postgresql_config_11\x18\x08 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet11H\x00R\x13postgresqlConfig_11\x12z\n\x17postgresql_config_11_1c\x18\r \x01(\x0b\x32?.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet11_1CH\x00R\x16postgresqlConfig_11_1c\x12q\n\x14postgresql_config_12\x18\x0b \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet12H\x00R\x13postgresqlConfig_12\x12z\n\x17postgresql_config_12_1c\x18\x0e \x01(\x0b\x32?.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet12_1CH\x00R\x16postgresqlConfig_12_1c\x12q\n\x14postgresql_config_13\x18\x0f \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet13H\x00R\x13postgresqlConfig_13\x12z\n\x17postgresql_config_13_1c\x18\x12 \x01(\x0b\x32?.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet13_1CH\x00R\x16postgresqlConfig_13_1c\x12q\n\x14postgresql_config_14\x18\x10 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet14H\x00R\x13postgresqlConfig_14\x12z\n\x17postgresql_config_14_1c\x18\x13 \x01(\x0b\x32?.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet14_1CH\x00R\x16postgresqlConfig_14_1c\x12q\n\x14postgresql_config_15\x18\x15 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet15H\x00R\x13postgresqlConfig_15\x12z\n\x17postgresql_config_15_1c\x18\x16 \x01(\x0b\x32?.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet15_1CH\x00R\x16postgresqlConfig_15_1c\x12q\n\x14postgresql_config_16\x18\x18 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet16H\x00R\x13postgresqlConfig_16\x12z\n\x17postgresql_config_16_1c\x18\x19 \x01(\x0b\x32?.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet16_1CH\x00R\x16postgresqlConfig_16_1c\x12q\n\x14postgresql_config_17\x18\x1b \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet17H\x00R\x13postgresqlConfig_17\x12z\n\x17postgresql_config_17_1c\x18\x1c \x01(\x0b\x32?.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet17_1CH\x00R\x16postgresqlConfig_17_1c\x12M\n\rpooler_config\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.mdb.postgresql.v1.ConnectionPoolerConfig\x12<\n\tresources\x18\x05 \x01(\x0b\x32).yandex.cloud.mdb.postgresql.v1.Resources\x12\x30\n\x0c\x61utofailover\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x07 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12H\n\x19\x62\x61\x63kup_retain_period_days\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x37-60\x12\x36\n\x06\x61\x63\x63\x65ss\x18\t \x01(\x0b\x32&.yandex.cloud.mdb.postgresql.v1.Access\x12W\n\x17performance_diagnostics\x18\x0c \x01(\x0b\x32\x36.yandex.cloud.mdb.postgresql.v1.PerformanceDiagnostics\x12R\n\x15\x64isk_size_autoscaling\x18\x17 \x01(\x0b\x32\x33.yandex.cloud.mdb.postgresql.v1.DiskSizeAutoscalingB\x13\n\x11postgresql_configJ\x04\x08\x14\x10\x15J\x04\x08\x1a\x10\x1b\"\xfe\x01\n\x16\x43onnectionPoolerConfig\x12X\n\x0cpooling_mode\x18\x01 \x01(\x0e\x32\x42.yandex.cloud.mdb.postgresql.v1.ConnectionPoolerConfig.PoolingMode\x12\x30\n\x0cpool_discard\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"X\n\x0bPoolingMode\x12\x1c\n\x18POOLING_MODE_UNSPECIFIED\x10\x00\x12\x0b\n\x07SESSION\x10\x01\x12\x0f\n\x0bTRANSACTION\x10\x02\x12\r\n\tSTATEMENT\x10\x03\"\xf0\x05\n\x04Host\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x0f\n\x07zone_id\x18\x03 \x01(\t\x12<\n\tresources\x18\x04 \x01(\x0b\x32).yandex.cloud.mdb.postgresql.v1.Resources\x12\x37\n\x04role\x18\x05 \x01(\x0e\x32).yandex.cloud.mdb.postgresql.v1.Host.Role\x12;\n\x06health\x18\x06 \x01(\x0e\x32+.yandex.cloud.mdb.postgresql.v1.Host.Health\x12\x39\n\x08services\x18\x07 \x03(\x0b\x32\'.yandex.cloud.mdb.postgresql.v1.Service\x12\x11\n\tsubnet_id\x18\x08 \x01(\t\x12\x1a\n\x12replication_source\x18\t \x01(\t\x12-\n\x08priority\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x06\x63onfig\x18\x0b \x01(\x0b\x32*.yandex.cloud.mdb.postgresql.v1.HostConfig\x12\x18\n\x10\x61ssign_public_ip\x18\x0c \x01(\x08\x12\x46\n\x0creplica_type\x18\r \x01(\x0e\x32\x30.yandex.cloud.mdb.postgresql.v1.Host.ReplicaType\"1\n\x04Role\x12\x10\n\x0cROLE_UNKNOWN\x10\x00\x12\n\n\x06MASTER\x10\x01\x12\x0b\n\x07REPLICA\x10\x02\"H\n\x0bReplicaType\x12\x18\n\x14REPLICA_TYPE_UNKNOWN\x10\x00\x12\t\n\x05\x41SYNC\x10\x01\x12\x08\n\x04SYNC\x10\x02\x12\n\n\x06QUORUM\x10\x03\"M\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\x12\x0c\n\x08READONLY\x10\x04\"\xe4\x10\n\nHostConfig\x12y\n\x15postgresql_config_9_6\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig9_6H\x00R\x18postgresqlHostConfig_9_6\x12\x7f\n\x17postgresql_config_10_1c\x18\x04 \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig10_1CH\x00R\x1apostgresqlHostConfig_10_1c\x12v\n\x14postgresql_config_10\x18\x02 \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig10H\x00R\x17postgresqlHostConfig_10\x12v\n\x14postgresql_config_11\x18\x03 \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig11H\x00R\x17postgresqlHostConfig_11\x12\x7f\n\x17postgresql_config_11_1c\x18\x06 \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig11_1CH\x00R\x1apostgresqlHostConfig_11_1c\x12v\n\x14postgresql_config_12\x18\x05 \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig12H\x00R\x17postgresqlHostConfig_12\x12\x7f\n\x17postgresql_config_12_1c\x18\x07 \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig12_1CH\x00R\x1apostgresqlHostConfig_12_1c\x12v\n\x14postgresql_config_13\x18\x08 \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig13H\x00R\x17postgresqlHostConfig_13\x12\x7f\n\x17postgresql_config_13_1c\x18\n \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig13_1CH\x00R\x1apostgresqlHostConfig_13_1c\x12v\n\x14postgresql_config_14\x18\t \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig14H\x00R\x17postgresqlHostConfig_14\x12\x7f\n\x17postgresql_config_14_1c\x18\x0b \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig14_1CH\x00R\x1apostgresqlHostConfig_14_1c\x12v\n\x14postgresql_config_15\x18\x0c \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig15H\x00R\x17postgresqlHostConfig_15\x12\x7f\n\x17postgresql_config_15_1c\x18\r \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig15_1CH\x00R\x1apostgresqlHostConfig_15_1c\x12v\n\x14postgresql_config_16\x18\x0e \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig16H\x00R\x17postgresqlHostConfig_16\x12\x7f\n\x17postgresql_config_16_1c\x18\x0f \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig16_1CH\x00R\x1apostgresqlHostConfig_16_1c\x12v\n\x14postgresql_config_17\x18\x10 \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig17H\x00R\x17postgresqlHostConfig_17\x12\x7f\n\x17postgresql_config_17_1c\x18\x11 \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig17_1CH\x00R\x1apostgresqlHostConfig_17_1cB\x13\n\x11postgresql_config\"\x80\x02\n\x07Service\x12:\n\x04type\x18\x01 \x01(\x0e\x32,.yandex.cloud.mdb.postgresql.v1.Service.Type\x12>\n\x06health\x18\x02 \x01(\x0e\x32..yandex.cloud.mdb.postgresql.v1.Service.Health\"8\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nPOSTGRESQL\x10\x01\x12\n\n\x06POOLER\x10\x02\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08READONLY\x10\x03\"P\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x11\n\tdisk_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x64isk_type_id\x18\x03 \x01(\t\"m\n\x06\x41\x63\x63\x65ss\x12\x11\n\tdata_lens\x18\x01 \x01(\x08\x12\x0f\n\x07web_sql\x18\x02 \x01(\x08\x12\x12\n\nserverless\x18\x03 \x01(\x08\x12\x15\n\rdata_transfer\x18\x04 \x01(\x08\x12\x14\n\x0cyandex_query\x18\x05 \x01(\x08\"\x8d\x01\n\x16PerformanceDiagnostics\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12/\n\x1asessions_sampling_interval\x18\x02 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-86400\x12\x31\n\x1cstatements_sampling_interval\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-86400\"\x90\x01\n\x13\x44iskSizeAutoscaling\x12.\n\x17planned_usage_threshold\x18\x01 \x01(\x03\x42\r\xe8\xc7\x31\x00\xfa\xc7\x31\x05\x30-100\x12\x30\n\x19\x65mergency_usage_threshold\x18\x02 \x01(\x03\x42\r\xe8\xc7\x31\x00\xfa\xc7\x31\x05\x30-100\x12\x17\n\x0f\x64isk_size_limit\x18\x03 \x01(\x03\x42s\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.postgresql.v1.cluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresql'
  _globals['_CLUSTER_LABELSENTRY']._loaded_options = None
  _globals['_CLUSTER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CLUSTERCONFIG'].fields_by_name['backup_retain_period_days']._loaded_options = None
  _globals['_CLUSTERCONFIG'].fields_by_name['backup_retain_period_days']._serialized_options = b'\372\3071\0047-60'
  _globals['_PERFORMANCEDIAGNOSTICS'].fields_by_name['sessions_sampling_interval']._loaded_options = None
  _globals['_PERFORMANCEDIAGNOSTICS'].fields_by_name['sessions_sampling_interval']._serialized_options = b'\372\3071\0071-86400'
  _globals['_PERFORMANCEDIAGNOSTICS'].fields_by_name['statements_sampling_interval']._loaded_options = None
  _globals['_PERFORMANCEDIAGNOSTICS'].fields_by_name['statements_sampling_interval']._serialized_options = b'\372\3071\0071-86400'
  _globals['_DISKSIZEAUTOSCALING'].fields_by_name['planned_usage_threshold']._loaded_options = None
  _globals['_DISKSIZEAUTOSCALING'].fields_by_name['planned_usage_threshold']._serialized_options = b'\350\3071\000\372\3071\0050-100'
  _globals['_DISKSIZEAUTOSCALING'].fields_by_name['emergency_usage_threshold']._loaded_options = None
  _globals['_DISKSIZEAUTOSCALING'].fields_by_name['emergency_usage_threshold']._serialized_options = b'\350\3071\000\372\3071\0050-100'
  _globals['_CLUSTER']._serialized_start=2176
  _globals['_CLUSTER']._serialized_end=3268
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=2960
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=3005
  _globals['_CLUSTER_ENVIRONMENT']._serialized_start=3007
  _globals['_CLUSTER_ENVIRONMENT']._serialized_end=3080
  _globals['_CLUSTER_HEALTH']._serialized_start=3082
  _globals['_CLUSTER_HEALTH']._serialized_end=3145
  _globals['_CLUSTER_STATUS']._serialized_start=3147
  _globals['_CLUSTER_STATUS']._serialized_end=3268
  _globals['_MONITORING']._serialized_start=3270
  _globals['_MONITORING']._serialized_end=3331
  _globals['_CLUSTERCONFIG']._serialized_start=3334
  _globals['_CLUSTERCONFIG']._serialized_end=5976
  _globals['_CONNECTIONPOOLERCONFIG']._serialized_start=5979
  _globals['_CONNECTIONPOOLERCONFIG']._serialized_end=6233
  _globals['_CONNECTIONPOOLERCONFIG_POOLINGMODE']._serialized_start=6145
  _globals['_CONNECTIONPOOLERCONFIG_POOLINGMODE']._serialized_end=6233
  _globals['_HOST']._serialized_start=6236
  _globals['_HOST']._serialized_end=6988
  _globals['_HOST_ROLE']._serialized_start=6786
  _globals['_HOST_ROLE']._serialized_end=6835
  _globals['_HOST_REPLICATYPE']._serialized_start=6837
  _globals['_HOST_REPLICATYPE']._serialized_end=6909
  _globals['_HOST_HEALTH']._serialized_start=6911
  _globals['_HOST_HEALTH']._serialized_end=6988
  _globals['_HOSTCONFIG']._serialized_start=6991
  _globals['_HOSTCONFIG']._serialized_end=9139
  _globals['_SERVICE']._serialized_start=9142
  _globals['_SERVICE']._serialized_end=9398
  _globals['_SERVICE_TYPE']._serialized_start=9277
  _globals['_SERVICE_TYPE']._serialized_end=9333
  _globals['_SERVICE_HEALTH']._serialized_start=9335
  _globals['_SERVICE_HEALTH']._serialized_end=9398
  _globals['_RESOURCES']._serialized_start=9400
  _globals['_RESOURCES']._serialized_end=9480
  _globals['_ACCESS']._serialized_start=9482
  _globals['_ACCESS']._serialized_end=9591
  _globals['_PERFORMANCEDIAGNOSTICS']._serialized_start=9594
  _globals['_PERFORMANCEDIAGNOSTICS']._serialized_end=9735
  _globals['_DISKSIZEAUTOSCALING']._serialized_start=9738
  _globals['_DISKSIZEAUTOSCALING']._serialized_end=9882
# @@protoc_insertion_point(module_scope)
