# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cloudregistry/v1/registry_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cloudregistry/v1/registry_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.cloudregistry.v1 import registry_pb2 as yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.cloudregistry.v1 import ip_permission_pb2 as yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_ip__permission__pb2
from yandex.cloud.cloudregistry.v1 import artifact_pb2 as yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_artifact__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/cloudregistry/v1/registry_service.proto\x12\x1dyandex.cloud.cloudregistry.v1\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a,yandex/cloud/cloudregistry/v1/registry.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a google/protobuf/field_mask.proto\x1a\x31yandex/cloud/cloudregistry/v1/ip_permission.proto\x1a,yandex/cloud/cloudregistry/v1/artifact.proto\x1a\x1cgoogle/api/annotations.proto\"7\n\x12GetRegistryRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"v\n\x15ListRegistriesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"n\n\x16ListRegistriesResponse\x12;\n\nregistries\x18\x01 \x03(\x0b\x32\'.yandex.cloud.cloudregistry.v1.Registry\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x94\x05\n\x15\x43reateRegistryRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x8d\x01\n\x06labels\x18\x03 \x03(\x0b\x32@.yandex.cloud.cloudregistry.v1.CreateRegistryRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12@\n\x04kind\x18\x04 \x01(\x0e\x32,.yandex.cloud.cloudregistry.v1.Registry.KindB\x04\xe8\xc7\x31\x01\x12@\n\x04type\x18\x05 \x01(\x0e\x32,.yandex.cloud.cloudregistry.v1.Registry.TypeB\x04\xe8\xc7\x31\x01\x12\x1f\n\x0b\x64\x65scription\x18\x06 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x91\x01\n\nproperties\x18\x07 \x03(\x0b\x32\x44.yandex.cloud.cloudregistry.v1.CreateRegistryRequest.PropertiesEntryB7\xf2\xc7\x31\x0e[-_0-9a-zA-Z]+\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x11\x12\t[a-zA-Z]+\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16\x43reateRegistryMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\"\xc3\x04\n\x15UpdateRegistryRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x8d\x01\n\x06labels\x18\x04 \x03(\x0b\x32@.yandex.cloud.cloudregistry.v1.UpdateRegistryRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x1f\n\x0b\x64\x65scription\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x91\x01\n\nproperties\x18\x06 \x03(\x0b\x32\x44.yandex.cloud.cloudregistry.v1.UpdateRegistryRequest.PropertiesEntryB7\xf2\xc7\x31\x0e[-_0-9a-zA-Z]+\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x11\x12\t[a-zA-Z]+\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16UpdateRegistryMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\":\n\x15\x44\x65leteRegistryRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65leteRegistryMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\"\x81\x01\n\x17SetIpPermissionsRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x43\n\x0eip_permissions\x18\x02 \x03(\x0b\x32+.yandex.cloud.cloudregistry.v1.IpPermission\"\x8f\x01\n\x1aUpdateIpPermissionsRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12N\n\x14ip_permission_deltas\x18\x02 \x03(\x0b\x32\x30.yandex.cloud.cloudregistry.v1.IpPermissionDelta\"=\n\x18ListIpPermissionsRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"]\n\x19ListIpPermissionsResponse\x12@\n\x0bpermissions\x18\x01 \x03(\x0b\x32+.yandex.cloud.cloudregistry.v1.IpPermission\"/\n\x18SetIpPermissionsMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\"2\n\x1bUpdateIpPermissionsMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\"\xd2\x01\n\x14ListArtifactsRequest\x12\x1d\n\x0bregistry_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12]\n\x04path\x18\x02 \x01(\tBO\xf2\xc7\x31K|[a-zA-Z0-9]+(?:[._-][a-zA-Z0-9]+)*(/([a-zA-Z0-9]+(?:[._-][a-zA-Z0-9]+)*))*\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\"l\n\x15ListArtifactsResponse\x12:\n\tartifacts\x18\x01 \x03(\x0b\x32\'.yandex.cloud.cloudregistry.v1.Artifact\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xae\x13\n\x0fRegistryService\x12\x96\x01\n\x03Get\x12\x31.yandex.cloud.cloudregistry.v1.GetRegistryRequest\x1a\'.yandex.cloud.cloudregistry.v1.Registry\"3\x82\xd3\xe4\x93\x02-\x12+/cloud-registry/v1/registries/{registry_id}\x12\x9a\x01\n\x04List\x12\x34.yandex.cloud.cloudregistry.v1.ListRegistriesRequest\x1a\x35.yandex.cloud.cloudregistry.v1.ListRegistriesResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cloud-registry/v1/registries\x12\xb1\x01\n\x06\x43reate\x12\x34.yandex.cloud.cloudregistry.v1.CreateRegistryRequest\x1a!.yandex.cloud.operation.Operation\"N\xb2\xd2*\"\n\x16\x43reateRegistryMetadata\x12\x08Registry\x82\xd3\xe4\x93\x02\"\"\x1d/cloud-registry/v1/registries:\x01*\x12\xbf\x01\n\x06Update\x12\x34.yandex.cloud.cloudregistry.v1.UpdateRegistryRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*\"\n\x16UpdateRegistryMetadata\x12\x08Registry\x82\xd3\xe4\x93\x02\x30\x32+/cloud-registry/v1/registries/{registry_id}:\x01*\x12\xc9\x01\n\x06\x44\x65lete\x12\x34.yandex.cloud.cloudregistry.v1.DeleteRegistryRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*/\n\x16\x44\x65leteRegistryMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02-*+/cloud-registry/v1/registries/{registry_id}\x12\xbd\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"F\x82\xd3\xe4\x93\x02@\x12>/cloud-registry/v1/registries/{resource_id}:listAccessBindings\x12\xed\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x42\"=/cloud-registry/v1/registries/{resource_id}:setAccessBindings:\x01*\x12\xf9\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8b\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x45\"@/cloud-registry/v1/registries/{resource_id}:updateAccessBindings:\x01*\x12\xcd\x01\n\x11ListIpPermissions\x12\x37.yandex.cloud.cloudregistry.v1.ListIpPermissionsRequest\x1a\x38.yandex.cloud.cloudregistry.v1.ListIpPermissionsResponse\"E\x82\xd3\xe4\x93\x02?\x12=/cloud-registry/v1/registries/{registry_id}:listIpPermissions\x12\xeb\x01\n\x10SetIpPermissions\x12\x36.yandex.cloud.cloudregistry.v1.SetIpPermissionsRequest\x1a!.yandex.cloud.operation.Operation\"|\xb2\xd2*1\n\x18SetIpPermissionsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x41\"</cloud-registry/v1/registries/{registry_id}:setIpPermissions:\x01*\x12\xf8\x01\n\x13UpdateIpPermissions\x12\x39.yandex.cloud.cloudregistry.v1.UpdateIpPermissionsRequest\x1a!.yandex.cloud.operation.Operation\"\x82\x01\xb2\xd2*4\n\x1bUpdateIpPermissionsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x44\"?/cloud-registry/v1/registries/{registry_id}:updateIpPermissions:\x01*\x12\xbd\x01\n\rListArtifacts\x12\x33.yandex.cloud.cloudregistry.v1.ListArtifactsRequest\x1a\x34.yandex.cloud.cloudregistry.v1.ListArtifactsResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/cloud-registry/v1/registries/{registry_id}:listArtifactsBt\n!yandex.cloud.api.cloudregistry.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudregistry/v1;cloudregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cloudregistry.v1.registry_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.cloudregistry.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudregistry/v1;cloudregistry'
  _globals['_GETREGISTRYREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_GETREGISTRYREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATEREGISTRYREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEREGISTRYREQUEST_PROPERTIESENTRY']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['kind']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['kind']._serialized_options = b'\350\3071\001'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['type']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['type']._serialized_options = b'\350\3071\001'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['properties']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['properties']._serialized_options = b'\362\3071\016[-_0-9a-zA-Z]+\202\3101\004<=64\212\3101\004<=63\262\3101\021\022\t[a-zA-Z]+\032\0041-63'
  _globals['_UPDATEREGISTRYREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEREGISTRYREQUEST_PROPERTIESENTRY']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['properties']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['properties']._serialized_options = b'\362\3071\016[-_0-9a-zA-Z]+\202\3101\004<=64\212\3101\004<=63\262\3101\021\022\t[a-zA-Z]+\032\0041-63'
  _globals['_DELETEREGISTRYREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_DELETEREGISTRYREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SETIPPERMISSIONSREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_SETIPPERMISSIONSREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEIPPERMISSIONSREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_UPDATEIPPERMISSIONSREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTIPPERMISSIONSREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_LISTIPPERMISSIONSREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTARTIFACTSREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_LISTARTIFACTSREQUEST'].fields_by_name['registry_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTARTIFACTSREQUEST'].fields_by_name['path']._loaded_options = None
  _globals['_LISTARTIFACTSREQUEST'].fields_by_name['path']._serialized_options = b'\362\3071K|[a-zA-Z0-9]+(?:[._-][a-zA-Z0-9]+)*(/([a-zA-Z0-9]+(?:[._-][a-zA-Z0-9]+)*))*'
  _globals['_LISTARTIFACTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTARTIFACTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTARTIFACTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTARTIFACTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_REGISTRYSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002-\022+/cloud-registry/v1/registries/{registry_id}'
  _globals['_REGISTRYSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\037\022\035/cloud-registry/v1/registries'
  _globals['_REGISTRYSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateRegistryMetadata\022\010Registry\202\323\344\223\002\"\"\035/cloud-registry/v1/registries:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateRegistryMetadata\022\010Registry\202\323\344\223\00202+/cloud-registry/v1/registries/{registry_id}:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteRegistryMetadata\022\025google.protobuf.Empty\202\323\344\223\002-*+/cloud-registry/v1/registries/{registry_id}'
  _globals['_REGISTRYSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002@\022>/cloud-registry/v1/registries/{resource_id}:listAccessBindings'
  _globals['_REGISTRYSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002B\"=/cloud-registry/v1/registries/{resource_id}:setAccessBindings:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002E\"@/cloud-registry/v1/registries/{resource_id}:updateAccessBindings:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['ListIpPermissions']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['ListIpPermissions']._serialized_options = b'\202\323\344\223\002?\022=/cloud-registry/v1/registries/{registry_id}:listIpPermissions'
  _globals['_REGISTRYSERVICE'].methods_by_name['SetIpPermissions']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['SetIpPermissions']._serialized_options = b'\262\322*1\n\030SetIpPermissionsMetadata\022\025google.protobuf.Empty\202\323\344\223\002A\"</cloud-registry/v1/registries/{registry_id}:setIpPermissions:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['UpdateIpPermissions']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['UpdateIpPermissions']._serialized_options = b'\262\322*4\n\033UpdateIpPermissionsMetadata\022\025google.protobuf.Empty\202\323\344\223\002D\"?/cloud-registry/v1/registries/{registry_id}:updateIpPermissions:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['ListArtifacts']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['ListArtifacts']._serialized_options = b'\202\323\344\223\002;\0229/cloud-registry/v1/registries/{registry_id}:listArtifacts'
  _globals['_GETREGISTRYREQUEST']._serialized_start=433
  _globals['_GETREGISTRYREQUEST']._serialized_end=488
  _globals['_LISTREGISTRIESREQUEST']._serialized_start=490
  _globals['_LISTREGISTRIESREQUEST']._serialized_end=608
  _globals['_LISTREGISTRIESRESPONSE']._serialized_start=610
  _globals['_LISTREGISTRIESRESPONSE']._serialized_end=720
  _globals['_CREATEREGISTRYREQUEST']._serialized_start=723
  _globals['_CREATEREGISTRYREQUEST']._serialized_end=1383
  _globals['_CREATEREGISTRYREQUEST_LABELSENTRY']._serialized_start=1287
  _globals['_CREATEREGISTRYREQUEST_LABELSENTRY']._serialized_end=1332
  _globals['_CREATEREGISTRYREQUEST_PROPERTIESENTRY']._serialized_start=1334
  _globals['_CREATEREGISTRYREQUEST_PROPERTIESENTRY']._serialized_end=1383
  _globals['_CREATEREGISTRYMETADATA']._serialized_start=1385
  _globals['_CREATEREGISTRYMETADATA']._serialized_end=1430
  _globals['_UPDATEREGISTRYREQUEST']._serialized_start=1433
  _globals['_UPDATEREGISTRYREQUEST']._serialized_end=2012
  _globals['_UPDATEREGISTRYREQUEST_LABELSENTRY']._serialized_start=1287
  _globals['_UPDATEREGISTRYREQUEST_LABELSENTRY']._serialized_end=1332
  _globals['_UPDATEREGISTRYREQUEST_PROPERTIESENTRY']._serialized_start=1334
  _globals['_UPDATEREGISTRYREQUEST_PROPERTIESENTRY']._serialized_end=1383
  _globals['_UPDATEREGISTRYMETADATA']._serialized_start=2014
  _globals['_UPDATEREGISTRYMETADATA']._serialized_end=2059
  _globals['_DELETEREGISTRYREQUEST']._serialized_start=2061
  _globals['_DELETEREGISTRYREQUEST']._serialized_end=2119
  _globals['_DELETEREGISTRYMETADATA']._serialized_start=2121
  _globals['_DELETEREGISTRYMETADATA']._serialized_end=2166
  _globals['_SETIPPERMISSIONSREQUEST']._serialized_start=2169
  _globals['_SETIPPERMISSIONSREQUEST']._serialized_end=2298
  _globals['_UPDATEIPPERMISSIONSREQUEST']._serialized_start=2301
  _globals['_UPDATEIPPERMISSIONSREQUEST']._serialized_end=2444
  _globals['_LISTIPPERMISSIONSREQUEST']._serialized_start=2446
  _globals['_LISTIPPERMISSIONSREQUEST']._serialized_end=2507
  _globals['_LISTIPPERMISSIONSRESPONSE']._serialized_start=2509
  _globals['_LISTIPPERMISSIONSRESPONSE']._serialized_end=2602
  _globals['_SETIPPERMISSIONSMETADATA']._serialized_start=2604
  _globals['_SETIPPERMISSIONSMETADATA']._serialized_end=2651
  _globals['_UPDATEIPPERMISSIONSMETADATA']._serialized_start=2653
  _globals['_UPDATEIPPERMISSIONSMETADATA']._serialized_end=2703
  _globals['_LISTARTIFACTSREQUEST']._serialized_start=2706
  _globals['_LISTARTIFACTSREQUEST']._serialized_end=2916
  _globals['_LISTARTIFACTSRESPONSE']._serialized_start=2918
  _globals['_LISTARTIFACTSRESPONSE']._serialized_end=3026
  _globals['_REGISTRYSERVICE']._serialized_start=3029
  _globals['_REGISTRYSERVICE']._serialized_end=5507
# @@protoc_insertion_point(module_scope)
