# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/video/v1/channel_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/video/v1/channel_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.video.v1 import channel_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/video/v1/channel_service.proto\x12\x15yandex.cloud.video.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a#yandex/cloud/video/v1/channel.proto\"5\n\x11GetChannelRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xaf\x01\n\x13ListChannelsRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x1f\n\npage_token\x18\x65 \x01(\tB\x0b\x8a\xc8\x31\x07<=15000\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x1a\n\x06\x66ilter\x18g \x01(\tB\n\x8a\xc8\x31\x06<=1000J\x04\x08\x02\x10\x64\"g\n\x14ListChannelsResponse\x12\x30\n\x08\x63hannels\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.video.v1.Channel\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\xf1\x02\n\x14\x43reateChannelRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x05title\x18\x02 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=2500\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x8c\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x37.yandex.cloud.video.v1.CreateChannelRequest.LabelsEntryBB\xf2\xc7\x31\x12[-_.@:/0-9a-zA-Z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12\x39\n\x08settings\x18\xc9\x01 \x01(\x0b\x32&.yandex.cloud.video.v1.ChannelSettings\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x05\x08\x04\x10\xc8\x01\"+\n\x15\x43reateChannelMetadata\x12\x12\n\nchannel_id\x18\x01 \x01(\t\"\x9e\x03\n\x14UpdateChannelRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x34\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x19\n\x05title\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2500\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x8c\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x37.yandex.cloud.video.v1.UpdateChannelRequest.LabelsEntryBB\xf2\xc7\x31\x12[-_.@:/0-9a-zA-Z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12\x39\n\x08settings\x18\xc9\x01 \x01(\x0b\x32&.yandex.cloud.video.v1.ChannelSettings\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x05\x08\x05\x10\xc8\x01\"+\n\x15UpdateChannelMetadata\x12\x12\n\nchannel_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteChannelRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteChannelMetadata\x12\x12\n\nchannel_id\x18\x01 \x01(\t\"k\n\x1a\x42\x61tchDeleteChannelsRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12&\n\x0b\x63hannel_ids\x18\x02 \x03(\tB\x11\x82\xc8\x31\x05\x31-100\x8a\xc8\x31\x04<=50\"2\n\x1b\x42\x61tchDeleteChannelsMetadata\x12\x13\n\x0b\x63hannel_ids\x18\x01 \x03(\t2\xf8\x0c\n\x0e\x43hannelService\x12x\n\x03Get\x12(.yandex.cloud.video.v1.GetChannelRequest\x1a\x1e.yandex.cloud.video.v1.Channel\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/video/v1/channels/{channel_id}\x12{\n\x04List\x12*.yandex.cloud.video.v1.ListChannelsRequest\x1a+.yandex.cloud.video.v1.ListChannelsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/video/v1/channels\x12\x9b\x01\n\x06\x43reate\x12+.yandex.cloud.video.v1.CreateChannelRequest\x1a!.yandex.cloud.operation.Operation\"A\xb2\xd2* \n\x15\x43reateChannelMetadata\x12\x07\x43hannel\x82\xd3\xe4\x93\x02\x17\"\x12/video/v1/channels:\x01*\x12\xa8\x01\n\x06Update\x12+.yandex.cloud.video.v1.UpdateChannelRequest\x1a!.yandex.cloud.operation.Operation\"N\xb2\xd2* \n\x15UpdateChannelMetadata\x12\x07\x43hannel\x82\xd3\xe4\x93\x02$2\x1f/video/v1/channels/{channel_id}:\x01*\x12\xb3\x01\n\x06\x44\x65lete\x12+.yandex.cloud.video.v1.DeleteChannelRequest\x1a!.yandex.cloud.operation.Operation\"Y\xb2\xd2*.\n\x15\x44\x65leteChannelMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02!*\x1f/video/v1/channels/{channel_id}\x12\xc6\x01\n\x0b\x42\x61tchDelete\x12\x31.yandex.cloud.video.v1.BatchDeleteChannelsRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*4\n\x1b\x42\x61tchDeleteChannelsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02#\"\x1e/video/v1/channels:batchDelete:\x01*\x12\xb2\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/video/v1/channels/{resource_id}:listAccessBindings\x12\xf1\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x89\x01\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02\x37\"2/video/v1/channels/{resource_id}:setAccessBindings:\x01*\x12\xfd\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8f\x01\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02:25/video/v1/channels/{resource_id}:updateAccessBindings:\x01*B\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.channel_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_GETCHANNELREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_GETCHANNELREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCHANNELSREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_LISTCHANNELSREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCHANNELSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCHANNELSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_LISTCHANNELSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCHANNELSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\007<=15000'
  _globals['_LISTCHANNELSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCHANNELSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATECHANNELREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATECHANNELREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATECHANNELREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_CREATECHANNELREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECHANNELREQUEST'].fields_by_name['title']._loaded_options = None
  _globals['_CREATECHANNELREQUEST'].fields_by_name['title']._serialized_options = b'\350\3071\001\212\3101\006<=2500'
  _globals['_CREATECHANNELREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATECHANNELREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\022[-_.@:/0-9a-zA-Z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_UPDATECHANNELREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATECHANNELREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATECHANNELREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_UPDATECHANNELREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECHANNELREQUEST'].fields_by_name['field_mask']._loaded_options = None
  _globals['_UPDATECHANNELREQUEST'].fields_by_name['field_mask']._serialized_options = b'\350\3071\001'
  _globals['_UPDATECHANNELREQUEST'].fields_by_name['title']._loaded_options = None
  _globals['_UPDATECHANNELREQUEST'].fields_by_name['title']._serialized_options = b'\212\3101\006<=2500'
  _globals['_UPDATECHANNELREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATECHANNELREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\022[-_.@:/0-9a-zA-Z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_DELETECHANNELREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_DELETECHANNELREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BATCHDELETECHANNELSREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_BATCHDELETECHANNELSREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BATCHDELETECHANNELSREQUEST'].fields_by_name['channel_ids']._loaded_options = None
  _globals['_BATCHDELETECHANNELSREQUEST'].fields_by_name['channel_ids']._serialized_options = b'\202\3101\0051-100\212\3101\004<=50'
  _globals['_CHANNELSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CHANNELSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002!\022\037/video/v1/channels/{channel_id}'
  _globals['_CHANNELSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CHANNELSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\024\022\022/video/v1/channels'
  _globals['_CHANNELSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CHANNELSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateChannelMetadata\022\007Channel\202\323\344\223\002\027\"\022/video/v1/channels:\001*'
  _globals['_CHANNELSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CHANNELSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateChannelMetadata\022\007Channel\202\323\344\223\002$2\037/video/v1/channels/{channel_id}:\001*'
  _globals['_CHANNELSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CHANNELSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteChannelMetadata\022\025google.protobuf.Empty\202\323\344\223\002!*\037/video/v1/channels/{channel_id}'
  _globals['_CHANNELSERVICE'].methods_by_name['BatchDelete']._loaded_options = None
  _globals['_CHANNELSERVICE'].methods_by_name['BatchDelete']._serialized_options = b'\262\322*4\n\033BatchDeleteChannelsMetadata\022\025google.protobuf.Empty\202\323\344\223\002#\"\036/video/v1/channels:batchDelete:\001*'
  _globals['_CHANNELSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_CHANNELSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0025\0223/video/v1/channels/{resource_id}:listAccessBindings'
  _globals['_CHANNELSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_CHANNELSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\0027\"2/video/v1/channels/{resource_id}:setAccessBindings:\001*'
  _globals['_CHANNELSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_CHANNELSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002:25/video/v1/channels/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETCHANNELREQUEST']._serialized_start=310
  _globals['_GETCHANNELREQUEST']._serialized_end=363
  _globals['_LISTCHANNELSREQUEST']._serialized_start=366
  _globals['_LISTCHANNELSREQUEST']._serialized_end=541
  _globals['_LISTCHANNELSRESPONSE']._serialized_start=543
  _globals['_LISTCHANNELSRESPONSE']._serialized_end=646
  _globals['_CREATECHANNELREQUEST']._serialized_start=649
  _globals['_CREATECHANNELREQUEST']._serialized_end=1018
  _globals['_CREATECHANNELREQUEST_LABELSENTRY']._serialized_start=966
  _globals['_CREATECHANNELREQUEST_LABELSENTRY']._serialized_end=1011
  _globals['_CREATECHANNELMETADATA']._serialized_start=1020
  _globals['_CREATECHANNELMETADATA']._serialized_end=1063
  _globals['_UPDATECHANNELREQUEST']._serialized_start=1066
  _globals['_UPDATECHANNELREQUEST']._serialized_end=1480
  _globals['_UPDATECHANNELREQUEST_LABELSENTRY']._serialized_start=966
  _globals['_UPDATECHANNELREQUEST_LABELSENTRY']._serialized_end=1011
  _globals['_UPDATECHANNELMETADATA']._serialized_start=1482
  _globals['_UPDATECHANNELMETADATA']._serialized_end=1525
  _globals['_DELETECHANNELREQUEST']._serialized_start=1527
  _globals['_DELETECHANNELREQUEST']._serialized_end=1583
  _globals['_DELETECHANNELMETADATA']._serialized_start=1585
  _globals['_DELETECHANNELMETADATA']._serialized_end=1628
  _globals['_BATCHDELETECHANNELSREQUEST']._serialized_start=1630
  _globals['_BATCHDELETECHANNELSREQUEST']._serialized_end=1737
  _globals['_BATCHDELETECHANNELSMETADATA']._serialized_start=1739
  _globals['_BATCHDELETECHANNELSMETADATA']._serialized_end=1789
  _globals['_CHANNELSERVICE']._serialized_start=1792
  _globals['_CHANNELSERVICE']._serialized_end=3448
# @@protoc_insertion_point(module_scope)
