"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.billing.v1.billable_object_pb2
import yandex.cloud.billing.v1.billing_account_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetBillingAccountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the billing account to return.
    To get the billing account ID, use [BillingAccountService.List] request.
    """
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id"]) -> None: ...

global___GetBillingAccountRequest = GetBillingAccountRequest

@typing.final
class ListBillingAccountsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListBillingAccountsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListBillingAccountsResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListBillingAccountsRequest = ListBillingAccountsRequest

@typing.final
class ListBillingAccountsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListBillingAccountsRequest.page_size], use
    [next_page_token] as the value
    for the [ListBillingAccountsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def billing_accounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.v1.billing_account_pb2.BillingAccount]:
        """List of billing accounts."""

    def __init__(
        self,
        *,
        billing_accounts: collections.abc.Iterable[yandex.cloud.billing.v1.billing_account_pb2.BillingAccount] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["billing_accounts", b"billing_accounts", "next_page_token", b"next_page_token"]) -> None: ...

global___ListBillingAccountsResponse = ListBillingAccountsResponse

@typing.final
class ListBillableObjectBindingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    billing_account_id: builtins.str
    """ID of the billing account to list associated billable object bindings.
    To get the billing account ID, use [BillingAccountService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListBillableObjectBindingsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListBillableObjectBindingsResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        billing_account_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["billing_account_id", b"billing_account_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListBillableObjectBindingsRequest = ListBillableObjectBindingsRequest

@typing.final
class ListBillableObjectBindingsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLABLE_OBJECT_BINDINGS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListBillableObjectBindingsRequest.page_size], use
    [next_page_token] as the value
    for the [ListBillableObjectBindingsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def billable_object_bindings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.v1.billable_object_pb2.BillableObjectBinding]:
        """List of billable object bindings."""

    def __init__(
        self,
        *,
        billable_object_bindings: collections.abc.Iterable[yandex.cloud.billing.v1.billable_object_pb2.BillableObjectBinding] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["billable_object_bindings", b"billable_object_bindings", "next_page_token", b"next_page_token"]) -> None: ...

global___ListBillableObjectBindingsResponse = ListBillableObjectBindingsResponse

@typing.final
class BindBillableObjectRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    BILLABLE_OBJECT_FIELD_NUMBER: builtins.int
    billing_account_id: builtins.str
    """ID of the billing account to bind billable object.
    To get the billing account ID, use [BillingAccountService.List] request.
    """
    @property
    def billable_object(self) -> yandex.cloud.billing.v1.billable_object_pb2.BillableObject:
        """[yandex.cloud.billing.v1.BillableObject] to bind with billing account."""

    def __init__(
        self,
        *,
        billing_account_id: builtins.str = ...,
        billable_object: yandex.cloud.billing.v1.billable_object_pb2.BillableObject | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["billable_object", b"billable_object"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["billable_object", b"billable_object", "billing_account_id", b"billing_account_id"]) -> None: ...

global___BindBillableObjectRequest = BindBillableObjectRequest

@typing.final
class BindBillableObjectMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLABLE_OBJECT_ID_FIELD_NUMBER: builtins.int
    billable_object_id: builtins.str
    """ID of the [yandex.cloud.billing.v1.BillableObject] that was bound to billing account."""
    def __init__(
        self,
        *,
        billable_object_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["billable_object_id", b"billable_object_id"]) -> None: ...

global___BindBillableObjectMetadata = BindBillableObjectMetadata
