"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _BatchInferenceTaskStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BatchInferenceTaskStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BatchInferenceTaskStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BATCH_INFERENCE_TASK_STATUS_UNSPECIFIED: _BatchInferenceTaskStatus.ValueType  # 0
    CREATED: _BatchInferenceTaskStatus.ValueType  # 1
    PENDING: _BatchInferenceTaskStatus.ValueType  # 2
    IN_PROGRESS: _BatchInferenceTaskStatus.ValueType  # 3
    COMPLETED: _BatchInferenceTaskStatus.ValueType  # 4
    FAILED: _BatchInferenceTaskStatus.ValueType  # 5
    CANCELED: _BatchInferenceTaskStatus.ValueType  # 6

class BatchInferenceTaskStatus(_BatchInferenceTaskStatus, metaclass=_BatchInferenceTaskStatusEnumTypeWrapper):
    """Enum representing the status of a batch inference."""

BATCH_INFERENCE_TASK_STATUS_UNSPECIFIED: BatchInferenceTaskStatus.ValueType  # 0
CREATED: BatchInferenceTaskStatus.ValueType  # 1
PENDING: BatchInferenceTaskStatus.ValueType  # 2
IN_PROGRESS: BatchInferenceTaskStatus.ValueType  # 3
COMPLETED: BatchInferenceTaskStatus.ValueType  # 4
FAILED: BatchInferenceTaskStatus.ValueType  # 5
CANCELED: BatchInferenceTaskStatus.ValueType  # 6
global___BatchInferenceTaskStatus = BatchInferenceTaskStatus
