# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/vpc/v1/privatelink/private_endpoint.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/vpc/v1/privatelink/private_endpoint.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/vpc/v1/privatelink/private_endpoint.proto\x12\x1fyandex.cloud.vpc.v1.privatelink\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc2\x06\n\x0fPrivateEndpoint\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12L\n\x06labels\x18\x06 \x03(\x0b\x32<.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint.LabelsEntry\x12\x12\n\nnetwork_id\x18\x07 \x01(\t\x12G\n\x06status\x18\x08 \x01(\x0e\x32\x37.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint.Status\x12Q\n\x07\x61\x64\x64ress\x18\t \x01(\x0b\x32@.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint.EndpointAddress\x12P\n\x0b\x64ns_options\x18\n \x01(\x0b\x32;.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint.DnsOptions\x12X\n\x0eobject_storage\x18\x0b \x01(\x0b\x32>.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint.ObjectStorageH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x0f\n\rObjectStorage\x1a\x31\n\nDnsOptions\x12#\n\x1bprivate_dns_records_enabled\x18\x01 \x01(\x08\x1aI\n\x0f\x45ndpointAddress\x12\x11\n\tsubnet_id\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x12\n\naddress_id\x18\x03 \x01(\t\"J\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tAVAILABLE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x42\t\n\x07serviceBv\n#yandex.cloud.api.vpc.v1.privatelinkZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1/privatelink;privatelinkb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.vpc.v1.privatelink.private_endpoint_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#yandex.cloud.api.vpc.v1.privatelinkZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1/privatelink;privatelink'
  _globals['_PRIVATEENDPOINT_LABELSENTRY']._loaded_options = None
  _globals['_PRIVATEENDPOINT_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_PRIVATEENDPOINT']._serialized_start=125
  _globals['_PRIVATEENDPOINT']._serialized_end=959
  _globals['_PRIVATEENDPOINT_LABELSENTRY']._serialized_start=684
  _globals['_PRIVATEENDPOINT_LABELSENTRY']._serialized_end=729
  _globals['_PRIVATEENDPOINT_OBJECTSTORAGE']._serialized_start=731
  _globals['_PRIVATEENDPOINT_OBJECTSTORAGE']._serialized_end=746
  _globals['_PRIVATEENDPOINT_DNSOPTIONS']._serialized_start=748
  _globals['_PRIVATEENDPOINT_DNSOPTIONS']._serialized_end=797
  _globals['_PRIVATEENDPOINT_ENDPOINTADDRESS']._serialized_start=799
  _globals['_PRIVATEENDPOINT_ENDPOINTADDRESS']._serialized_end=872
  _globals['_PRIVATEENDPOINT_STATUS']._serialized_start=874
  _globals['_PRIVATEENDPOINT_STATUS']._serialized_end=948
# @@protoc_insertion_point(module_scope)
