# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/kms/v1/symmetric_key.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/kms/v1/symmetric_key.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/kms/v1/symmetric_key.proto\x12\x13yandex.cloud.kms.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\xfa\x04\n\x0cSymmetricKey\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12=\n\x06labels\x18\x06 \x03(\x0b\x32-.yandex.cloud.kms.v1.SymmetricKey.LabelsEntry\x12\x38\n\x06status\x18\x07 \x01(\x0e\x32(.yandex.cloud.kms.v1.SymmetricKey.Status\x12\x41\n\x0fprimary_version\x18\x08 \x01(\x0b\x32(.yandex.cloud.kms.v1.SymmetricKeyVersion\x12\x42\n\x11\x64\x65\x66\x61ult_algorithm\x18\t \x01(\x0e\x32\'.yandex.cloud.kms.v1.SymmetricAlgorithm\x12.\n\nrotated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0frotation_period\x18\x0b \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1b\n\x13\x64\x65letion_protection\x18\x0c \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08INACTIVE\x10\x03\"\x92\x03\n\x13SymmetricKeyVersion\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06key_id\x18\x02 \x01(\t\x12?\n\x06status\x18\x03 \x01(\x0e\x32/.yandex.cloud.kms.v1.SymmetricKeyVersion.Status\x12:\n\talgorithm\x18\x04 \x01(\x0e\x32\'.yandex.cloud.kms.v1.SymmetricAlgorithm\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07primary\x18\x06 \x01(\x08\x12.\n\ndestroy_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rhosted_by_hsm\x18\x08 \x01(\x08\"Z\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x1d\n\x19SCHEDULED_FOR_DESTRUCTION\x10\x02\x12\r\n\tDESTROYED\x10\x03*q\n\x12SymmetricAlgorithm\x12#\n\x1fSYMMETRIC_ALGORITHM_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x41\x45S_128\x10\x01\x12\x0b\n\x07\x41\x45S_192\x10\x02\x12\x0b\n\x07\x41\x45S_256\x10\x03\x12\x0f\n\x0b\x41\x45S_256_HSM\x10\x04\x42V\n\x17yandex.cloud.api.kms.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1;kmsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.kms.v1.symmetric_key_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.kms.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1;kms'
  _globals['_SYMMETRICKEY_LABELSENTRY']._loaded_options = None
  _globals['_SYMMETRICKEY_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_SYMMETRICALGORITHM']._serialized_start=1171
  _globals['_SYMMETRICALGORITHM']._serialized_end=1284
  _globals['_SYMMETRICKEY']._serialized_start=130
  _globals['_SYMMETRICKEY']._serialized_end=764
  _globals['_SYMMETRICKEY_LABELSENTRY']._serialized_start=645
  _globals['_SYMMETRICKEY_LABELSENTRY']._serialized_end=690
  _globals['_SYMMETRICKEY_STATUS']._serialized_start=692
  _globals['_SYMMETRICKEY_STATUS']._serialized_end=764
  _globals['_SYMMETRICKEYVERSION']._serialized_start=767
  _globals['_SYMMETRICKEYVERSION']._serialized_end=1169
  _globals['_SYMMETRICKEYVERSION_STATUS']._serialized_start=1079
  _globals['_SYMMETRICKEYVERSION_STATUS']._serialized_end=1169
# @@protoc_insertion_point(module_scope)
