# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/loadtesting/agent/v1/agent_registration_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/loadtesting/agent/v1/agent_registration_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nByandex/cloud/loadtesting/agent/v1/agent_registration_service.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\"E\n\x0fRegisterRequest\x12\x1b\n\x13\x63ompute_instance_id\x18\x01 \x01(\t\x12\x15\n\ragent_version\x18\x02 \x01(\t\"-\n\x10RegisterResponse\x12\x19\n\x11\x61gent_instance_id\x18\x01 \x01(\t\"\xbd\x02\n\x1c\x45xternalAgentRegisterRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x1b\n\x13\x63ompute_instance_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x15\n\ragent_version\x18\x04 \x01(\t\x12\x98\x01\n\x06labels\x18\x05 \x03(\x0b\x32K.yandex.cloud.loadtesting.agent.v1.ExternalAgentRegisterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n\x1d\x45xternalAgentRegisterMetadata\x12\x19\n\x11\x61gent_instance_id\x18\x01 \x01(\t2\xb2\x03\n\x18\x41gentRegistrationService\x12\xa5\x01\n\x08Register\x12\x32.yandex.cloud.loadtesting.agent.v1.RegisterRequest\x1a\x33.yandex.cloud.loadtesting.agent.v1.RegisterResponse\"0\x82\xd3\xe4\x93\x02*\"%/loadtesting/agent/v1/agents/register:\x01*\x12\xed\x01\n\x15\x45xternalAgentRegister\x12?.yandex.cloud.loadtesting.agent.v1.ExternalAgentRegisterRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*.\n\x1d\x45xternalAgentRegisterMetadata\x12\rAgentInstance\x82\xd3\xe4\x93\x02\x38\"3/loadtesting/agent/v1/agents/externalAgentsRegister:\x01*Bt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent'
  _globals['_EXTERNALAGENTREGISTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_EXTERNALAGENTREGISTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_EXTERNALAGENTREGISTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_EXTERNALAGENTREGISTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_AGENTREGISTRATIONSERVICE'].methods_by_name['Register']._loaded_options = None
  _globals['_AGENTREGISTRATIONSERVICE'].methods_by_name['Register']._serialized_options = b'\202\323\344\223\002*\"%/loadtesting/agent/v1/agents/register:\001*'
  _globals['_AGENTREGISTRATIONSERVICE'].methods_by_name['ExternalAgentRegister']._loaded_options = None
  _globals['_AGENTREGISTRATIONSERVICE'].methods_by_name['ExternalAgentRegister']._serialized_options = b'\262\322*.\n\035ExternalAgentRegisterMetadata\022\rAgentInstance\202\323\344\223\0028\"3/loadtesting/agent/v1/agents/externalAgentsRegister:\001*'
  _globals['_REGISTERREQUEST']._serialized_start=240
  _globals['_REGISTERREQUEST']._serialized_end=309
  _globals['_REGISTERRESPONSE']._serialized_start=311
  _globals['_REGISTERRESPONSE']._serialized_end=356
  _globals['_EXTERNALAGENTREGISTERREQUEST']._serialized_start=359
  _globals['_EXTERNALAGENTREGISTERREQUEST']._serialized_end=676
  _globals['_EXTERNALAGENTREGISTERREQUEST_LABELSENTRY']._serialized_start=631
  _globals['_EXTERNALAGENTREGISTERREQUEST_LABELSENTRY']._serialized_end=676
  _globals['_EXTERNALAGENTREGISTERMETADATA']._serialized_start=678
  _globals['_EXTERNALAGENTREGISTERMETADATA']._serialized_end=736
  _globals['_AGENTREGISTRATIONSERVICE']._serialized_start=739
  _globals['_AGENTREGISTRATIONSERVICE']._serialized_end=1173
# @@protoc_insertion_point(module_scope)
