"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.greenplum.v1.resource_groups_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateResourceGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    resource_group_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        resource_group_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "resource_group_name", b"resource_group_name"]) -> None: ...

global___CreateResourceGroupMetadata = CreateResourceGroupMetadata

@typing.final
class UpdateResourceGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    resource_group_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        resource_group_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "resource_group_name", b"resource_group_name"]) -> None: ...

global___UpdateResourceGroupMetadata = UpdateResourceGroupMetadata

@typing.final
class DeleteResourceGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    resource_group_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        resource_group_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "resource_group_name", b"resource_group_name"]) -> None: ...

global___DeleteResourceGroupMetadata = DeleteResourceGroupMetadata

@typing.final
class ListResourceGroupsRequest(google.protobuf.message.Message):
    """ResourceGroups API"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___ListResourceGroupsRequest = ListResourceGroupsRequest

@typing.final
class ListResourceGroupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_GROUPS_FIELD_NUMBER: builtins.int
    @property
    def resource_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.greenplum.v1.resource_groups_pb2.ResourceGroup]: ...
    def __init__(
        self,
        *,
        resource_groups: collections.abc.Iterable[yandex.cloud.mdb.greenplum.v1.resource_groups_pb2.ResourceGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_groups", b"resource_groups"]) -> None: ...

global___ListResourceGroupsResponse = ListResourceGroupsResponse

@typing.final
class GetResourceGroupAtRevisionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum cluster."""
    revision: builtins.int
    """Cluster revision"""
    resource_group_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        revision: builtins.int = ...,
        resource_group_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "resource_group_name", b"resource_group_name", "revision", b"revision"]) -> None: ...

global___GetResourceGroupAtRevisionRequest = GetResourceGroupAtRevisionRequest

@typing.final
class CreateResourceGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    @property
    def resource_group(self) -> yandex.cloud.mdb.greenplum.v1.resource_groups_pb2.ResourceGroup: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        resource_group: yandex.cloud.mdb.greenplum.v1.resource_groups_pb2.ResourceGroup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource_group", b"resource_group"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "resource_group", b"resource_group"]) -> None: ...

global___CreateResourceGroupRequest = CreateResourceGroupRequest

@typing.final
class UpdateResourceGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def resource_group(self) -> yandex.cloud.mdb.greenplum.v1.resource_groups_pb2.ResourceGroup: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        resource_group: yandex.cloud.mdb.greenplum.v1.resource_groups_pb2.ResourceGroup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource_group", b"resource_group", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "resource_group", b"resource_group", "update_mask", b"update_mask"]) -> None: ...

global___UpdateResourceGroupRequest = UpdateResourceGroupRequest

@typing.final
class DeleteResourceGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    resource_group_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        resource_group_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "resource_group_name", b"resource_group_name"]) -> None: ...

global___DeleteResourceGroupRequest = DeleteResourceGroupRequest
