"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.datatransfer.v1.endpoint.common_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MetrikaStreamType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MetrikaStreamTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MetrikaStreamType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    METRIKA_STREAM_TYPE_UNSPECIFIED: _MetrikaStreamType.ValueType  # 0
    METRIKA_STREAM_TYPE_HITS: _MetrikaStreamType.ValueType  # 1
    METRIKA_STREAM_TYPE_VISITS: _MetrikaStreamType.ValueType  # 2
    METRIKA_STREAM_TYPE_HITS_V2: _MetrikaStreamType.ValueType  # 3

class MetrikaStreamType(_MetrikaStreamType, metaclass=_MetrikaStreamTypeEnumTypeWrapper): ...

METRIKA_STREAM_TYPE_UNSPECIFIED: MetrikaStreamType.ValueType  # 0
METRIKA_STREAM_TYPE_HITS: MetrikaStreamType.ValueType  # 1
METRIKA_STREAM_TYPE_VISITS: MetrikaStreamType.ValueType  # 2
METRIKA_STREAM_TYPE_HITS_V2: MetrikaStreamType.ValueType  # 3
global___MetrikaStreamType = MetrikaStreamType

@typing.final
class MetrikaStream(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    type: global___MetrikaStreamType.ValueType
    @property
    def columns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        type: global___MetrikaStreamType.ValueType = ...,
        columns: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["columns", b"columns", "type", b"type"]) -> None: ...

global___MetrikaStream = MetrikaStream

@typing.final
class MetrikaSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNTER_IDS_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    STREAMS_FIELD_NUMBER: builtins.int
    @property
    def counter_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def token(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret: ...
    @property
    def streams(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MetrikaStream]: ...
    def __init__(
        self,
        *,
        counter_ids: collections.abc.Iterable[builtins.int] | None = ...,
        token: yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret | None = ...,
        streams: collections.abc.Iterable[global___MetrikaStream] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["token", b"token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counter_ids", b"counter_ids", "streams", b"streams", "token", b"token"]) -> None: ...

global___MetrikaSource = MetrikaSource
