"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _TransceiverType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TransceiverTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TransceiverType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRANSCEIVER_TYPE_UNSPECIFIED: _TransceiverType.ValueType  # 0
    TRANSCEIVER_TYPE_1000BASE_LX: _TransceiverType.ValueType  # 1
    TRANSCEIVER_TYPE_10GBASE_LR: _TransceiverType.ValueType  # 2
    TRANSCEIVER_TYPE_10GBASE_ER: _TransceiverType.ValueType  # 3
    TRANSCEIVER_TYPE_100GBASE_LR4: _TransceiverType.ValueType  # 4
    TRANSCEIVER_TYPE_100GBASE_ER4: _TransceiverType.ValueType  # 5

class TransceiverType(_TransceiverType, metaclass=_TransceiverTypeEnumTypeWrapper): ...

TRANSCEIVER_TYPE_UNSPECIFIED: TransceiverType.ValueType  # 0
TRANSCEIVER_TYPE_1000BASE_LX: TransceiverType.ValueType  # 1
TRANSCEIVER_TYPE_10GBASE_LR: TransceiverType.ValueType  # 2
TRANSCEIVER_TYPE_10GBASE_ER: TransceiverType.ValueType  # 3
TRANSCEIVER_TYPE_100GBASE_LR4: TransceiverType.ValueType  # 4
TRANSCEIVER_TYPE_100GBASE_ER4: TransceiverType.ValueType  # 5
global___TransceiverType = TransceiverType
