# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/compute/v1/reserved_instance_pool.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/compute/v1/reserved_instance_pool.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.compute.v1 import instance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2
from yandex.cloud.compute.v1 import instance_service_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/compute/v1/reserved_instance_pool.proto\x12\x17yandex.cloud.compute.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a&yandex/cloud/compute/v1/instance.proto\x1a.yandex/cloud/compute/v1/instance_service.proto\x1a\x1dyandex/cloud/validation.proto\"+\n\nProductIDs\x12\x1d\n\x0bproduct_ids\x18\x01 \x03(\tB\x08\x8a\xc8\x31\x04<=50\"\xbb\x01\n\x0c\x42ootDiskSpec\x12\x1b\n\x07\x64isk_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1c\n\x08image_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1f\n\x0bsnapshot_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12:\n\x0bproduct_ids\x18\x04 \x01(\x0b\x32#.yandex.cloud.compute.v1.ProductIDsH\x00\x42\x13\n\x0b\x62oot_source\x12\x04\xc0\xc1\x31\x01\"\x9d\x04\n\x14ReservedInstancePool\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07zone_id\x18\x02 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x03 \x01(\t\x12\x11\n\tfolder_id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12I\n\x06labels\x18\x07 \x03(\x0b\x32\x39.yandex.cloud.compute.v1.ReservedInstancePool.LabelsEntry\x12.\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bplatform_id\x18\t \x01(\t\x12>\n\x0eresources_spec\x18\n \x01(\x0b\x32&.yandex.cloud.compute.v1.ResourcesSpec\x12:\n\x0cgpu_settings\x18\x0b \x01(\x0b\x32$.yandex.cloud.compute.v1.GpuSettings\x12\x13\n\x0bproduct_ids\x18\x0c \x03(\t\x12\x42\n\x10network_settings\x18\r \x01(\x0b\x32(.yandex.cloud.compute.v1.NetworkSettings\x12\x0c\n\x04size\x18\x0e \x01(\x03\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x62\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.reserved_instance_pool_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _globals['_PRODUCTIDS'].fields_by_name['product_ids']._loaded_options = None
  _globals['_PRODUCTIDS'].fields_by_name['product_ids']._serialized_options = b'\212\3101\004<=50'
  _globals['_BOOTDISKSPEC'].oneofs_by_name['boot_source']._loaded_options = None
  _globals['_BOOTDISKSPEC'].oneofs_by_name['boot_source']._serialized_options = b'\300\3011\001'
  _globals['_BOOTDISKSPEC'].fields_by_name['disk_id']._loaded_options = None
  _globals['_BOOTDISKSPEC'].fields_by_name['disk_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_BOOTDISKSPEC'].fields_by_name['image_id']._loaded_options = None
  _globals['_BOOTDISKSPEC'].fields_by_name['image_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_BOOTDISKSPEC'].fields_by_name['snapshot_id']._loaded_options = None
  _globals['_BOOTDISKSPEC'].fields_by_name['snapshot_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_RESERVEDINSTANCEPOOL_LABELSENTRY']._loaded_options = None
  _globals['_RESERVEDINSTANCEPOOL_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_PRODUCTIDS']._serialized_start=233
  _globals['_PRODUCTIDS']._serialized_end=276
  _globals['_BOOTDISKSPEC']._serialized_start=279
  _globals['_BOOTDISKSPEC']._serialized_end=466
  _globals['_RESERVEDINSTANCEPOOL']._serialized_start=469
  _globals['_RESERVEDINSTANCEPOOL']._serialized_end=1010
  _globals['_RESERVEDINSTANCEPOOL_LABELSENTRY']._serialized_start=965
  _globals['_RESERVEDINSTANCEPOOL_LABELSENTRY']._serialized_end=1010
# @@protoc_insertion_point(module_scope)
