# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/logging/v1/log_resource.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/logging/v1/log_resource.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/logging/v1/log_resource.proto\x12\x17yandex.cloud.logging.v1\x1a\x1dyandex/cloud/validation.proto\"@\n\x10LogEntryResource\x12\x16\n\x04type\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=63\x12\x14\n\x02id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=63\"-\n\x10LogGroupResource\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0b\n\x03ids\x18\x02 \x03(\tBb\n\x1byandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;loggingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.logging.v1.log_resource_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;logging'
  _globals['_LOGENTRYRESOURCE'].fields_by_name['type']._loaded_options = None
  _globals['_LOGENTRYRESOURCE'].fields_by_name['type']._serialized_options = b'\212\3101\004<=63'
  _globals['_LOGENTRYRESOURCE'].fields_by_name['id']._loaded_options = None
  _globals['_LOGENTRYRESOURCE'].fields_by_name['id']._serialized_options = b'\212\3101\004<=63'
  _globals['_LOGENTRYRESOURCE']._serialized_start=102
  _globals['_LOGENTRYRESOURCE']._serialized_end=166
  _globals['_LOGGROUPRESOURCE']._serialized_start=168
  _globals['_LOGGROUPRESOURCE']._serialized_end=213
# @@protoc_insertion_point(module_scope)
