# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/containerregistry/v1/image_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/containerregistry/v1/image_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.containerregistry.v1 import image_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/containerregistry/v1/image_service.proto\x12!yandex.cloud.containerregistry.v1\x1a yandex/cloud/api/operation.proto\x1a-yandex/cloud/containerregistry/v1/image.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\"\xa4\x02\n\x11ListImagesRequest\x12\x1d\n\x0bregistry_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\\\n\x0frepository_name\x18\x02 \x01(\tBC\xf2\xc7\x31?|[a-z0-9]+(?:[._-][a-z0-9]+)*(/([a-z0-9]+(?:[._-][a-z0-9]+)*))*\x12\x1b\n\tfolder_id\x18\x07 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100\"g\n\x12ListImagesResponse\x12\x38\n\x06images\x18\x01 \x03(\x0b\x32(.yandex.cloud.containerregistry.v1.Image\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"1\n\x0fGetImageRequest\x12\x1e\n\x08image_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"4\n\x12\x44\x65leteImageRequest\x12\x1e\n\x08image_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\'\n\x13\x44\x65leteImageMetadata\x12\x10\n\x08image_id\x18\x01 \x01(\t2\x8a\x04\n\x0cImageService\x12\x9a\x01\n\x04List\x12\x34.yandex.cloud.containerregistry.v1.ListImagesRequest\x1a\x35.yandex.cloud.containerregistry.v1.ListImagesResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/container-registry/v1/images\x12\x95\x01\n\x03Get\x12\x32.yandex.cloud.containerregistry.v1.GetImageRequest\x1a(.yandex.cloud.containerregistry.v1.Image\"0\x82\xd3\xe4\x93\x02*\x12(/container-registry/v1/images/{image_id}\x12\xc4\x01\n\x06\x44\x65lete\x12\x35.yandex.cloud.containerregistry.v1.DeleteImageRequest\x1a!.yandex.cloud.operation.Operation\"`\xb2\xd2*,\n\x13\x44\x65leteImageMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02**(/container-registry/v1/images/{image_id}B\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.containerregistry.v1.image_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry'
  _globals['_LISTIMAGESREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_LISTIMAGESREQUEST'].fields_by_name['registry_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTIMAGESREQUEST'].fields_by_name['repository_name']._loaded_options = None
  _globals['_LISTIMAGESREQUEST'].fields_by_name['repository_name']._serialized_options = b'\362\3071?|[a-z0-9]+(?:[._-][a-z0-9]+)*(/([a-z0-9]+(?:[._-][a-z0-9]+)*))*'
  _globals['_LISTIMAGESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTIMAGESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTIMAGESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTIMAGESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTIMAGESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTIMAGESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTIMAGESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTIMAGESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTIMAGESREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTIMAGESREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_GETIMAGEREQUEST'].fields_by_name['image_id']._loaded_options = None
  _globals['_GETIMAGEREQUEST'].fields_by_name['image_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEIMAGEREQUEST'].fields_by_name['image_id']._loaded_options = None
  _globals['_DELETEIMAGEREQUEST'].fields_by_name['image_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_IMAGESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_IMAGESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\037\022\035/container-registry/v1/images'
  _globals['_IMAGESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_IMAGESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002*\022(/container-registry/v1/images/{image_id}'
  _globals['_IMAGESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_IMAGESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*,\n\023DeleteImageMetadata\022\025google.protobuf.Empty\202\323\344\223\002**(/container-registry/v1/images/{image_id}'
  _globals['_LISTIMAGESREQUEST']._serialized_start=275
  _globals['_LISTIMAGESREQUEST']._serialized_end=567
  _globals['_LISTIMAGESRESPONSE']._serialized_start=569
  _globals['_LISTIMAGESRESPONSE']._serialized_end=672
  _globals['_GETIMAGEREQUEST']._serialized_start=674
  _globals['_GETIMAGEREQUEST']._serialized_end=723
  _globals['_DELETEIMAGEREQUEST']._serialized_start=725
  _globals['_DELETEIMAGEREQUEST']._serialized_end=777
  _globals['_DELETEIMAGEMETADATA']._serialized_start=779
  _globals['_DELETEIMAGEMETADATA']._serialized_end=818
  _globals['_IMAGESERVICE']._serialized_start=821
  _globals['_IMAGESERVICE']._serialized_end=1343
# @@protoc_insertion_point(module_scope)
