# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/spqr/v1/host.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/spqr/v1/host.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.mdb.spqr.v1 import config_pb2 as yandex_dot_cloud_dot_mdb_dot_spqr_dot_v1_dot_config__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#yandex/cloud/mdb/spqr/v1/host.proto\x12\x18yandex.cloud.mdb.spqr.v1\x1a%yandex/cloud/mdb/spqr/v1/config.proto\x1a\x1dyandex/cloud/validation.proto\"\xf1\x08\n\x04Host\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x0f\n\x07zone_id\x18\x03 \x01(\t\x12\x36\n\tresources\x18\x04 \x01(\x0b\x32#.yandex.cloud.mdb.spqr.v1.Resources\x12\x31\n\x04role\x18\x05 \x01(\x0e\x32#.yandex.cloud.mdb.spqr.v1.Host.Role\x12\x35\n\x06health\x18\x06 \x01(\x0e\x32%.yandex.cloud.mdb.spqr.v1.Host.Health\x12\x33\n\x08services\x18\x07 \x03(\x0b\x32!.yandex.cloud.mdb.spqr.v1.Service\x12\x11\n\tsubnet_id\x18\x08 \x01(\t\x12\x18\n\x10\x61ssign_public_ip\x18\t \x01(\x08\x12\x31\n\x04type\x18\n \x01(\x0e\x32#.yandex.cloud.mdb.spqr.v1.Host.Type\x12\x12\n\nwalle_link\x18\x0b \x01(\t\x12\x14\n\x0cstate_reason\x18\x0c \x01(\t\x12<\n\x06system\x18\r \x01(\x0b\x32,.yandex.cloud.mdb.spqr.v1.Host.SystemMetrics\x12\x12\n\nshard_name\x18\x0e \x01(\t\x1a,\n\tCPUMetric\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x0c\n\x04used\x18\x02 \x01(\x01\x1a>\n\x0cMemoryMetric\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x0c\n\x04used\x18\x02 \x01(\x03\x12\r\n\x05total\x18\x03 \x01(\x03\x1a<\n\nDiskMetric\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x0c\n\x04used\x18\x02 \x01(\x03\x12\r\n\x05total\x18\x03 \x01(\x03\x1a\xbc\x01\n\rSystemMetrics\x12\x35\n\x03\x63pu\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.spqr.v1.Host.CPUMetric\x12;\n\x06memory\x18\x02 \x01(\x0b\x32+.yandex.cloud.mdb.spqr.v1.Host.MemoryMetric\x12\x37\n\x04\x64isk\x18\x03 \x01(\x0b\x32).yandex.cloud.mdb.spqr.v1.Host.DiskMetric\"\x87\x01\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06ROUTER\x10\x02\x12\x0f\n\x0b\x43OORDINATOR\x10\x03\x12\t\n\x05INFRA\x10\x04\x12\x0e\n\nPOSTGRESQL\x10\x05\x12\x17\n\x13\x45XTERNAL_POSTGRESQL\x10\x06\x12\x12\n\x0eMDB_POSTGRESQL\x10\x07\"\x04\x08\x01\x10\x01\"M\n\x04Role\x12\x10\n\x0cROLE_UNKNOWN\x10\x00\x12\x0b\n\x07PRIMARY\x10\x01\x12\r\n\tSECONDARY\x10\x02\x12\n\n\x06MASTER\x10\x03\x12\x0b\n\x07REPLICA\x10\x04\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"\xb6\x02\n\x07Service\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.yandex.cloud.mdb.spqr.v1.Service.Type\x12\x38\n\x06health\x18\x02 \x01(\x0e\x32(.yandex.cloud.mdb.spqr.v1.Service.Health\"\x87\x01\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06ROUTER\x10\x02\x12\x0f\n\x0b\x43OORDINATOR\x10\x03\x12\t\n\x05INFRA\x10\x04\x12\x0e\n\nPOSTGRESQL\x10\x05\x12\x17\n\x13\x45XTERNAL_POSTGRESQL\x10\x06\x12\x12\n\x0eMDB_POSTGRESQL\x10\x07\"\x04\x08\x01\x10\x01\"1\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\"\x86\x02\n\x08HostSpec\x12\x19\n\x07zone_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1b\n\tsubnet_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x61ssign_public_ip\x18\x03 \x01(\x08\x12\x37\n\x04type\x18\x04 \x01(\x0e\x32#.yandex.cloud.mdb.spqr.v1.Host.TypeB\x04\xe8\xc7\x31\x01\x12.\n\nshard_name\x18\x05 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12?\n\x0emdb_postgresql\x18\x06 \x01(\x0b\x32\'.yandex.cloud.mdb.spqr.v1.MDBPostgreSQLBa\n\x1cyandex.cloud.api.mdb.spqr.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/spqr/v1;spqrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.spqr.v1.host_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034yandex.cloud.api.mdb.spqr.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/spqr/v1;spqr'
  _globals['_HOSTSPEC'].fields_by_name['zone_id']._loaded_options = None
  _globals['_HOSTSPEC'].fields_by_name['zone_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_HOSTSPEC'].fields_by_name['subnet_id']._loaded_options = None
  _globals['_HOSTSPEC'].fields_by_name['subnet_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_HOSTSPEC'].fields_by_name['type']._loaded_options = None
  _globals['_HOSTSPEC'].fields_by_name['type']._serialized_options = b'\350\3071\001'
  _globals['_HOSTSPEC'].fields_by_name['shard_name']._loaded_options = None
  _globals['_HOSTSPEC'].fields_by_name['shard_name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_HOST']._serialized_start=136
  _globals['_HOST']._serialized_end=1273
  _globals['_HOST_CPUMETRIC']._serialized_start=630
  _globals['_HOST_CPUMETRIC']._serialized_end=674
  _globals['_HOST_MEMORYMETRIC']._serialized_start=676
  _globals['_HOST_MEMORYMETRIC']._serialized_end=738
  _globals['_HOST_DISKMETRIC']._serialized_start=740
  _globals['_HOST_DISKMETRIC']._serialized_end=800
  _globals['_HOST_SYSTEMMETRICS']._serialized_start=803
  _globals['_HOST_SYSTEMMETRICS']._serialized_end=991
  _globals['_HOST_TYPE']._serialized_start=994
  _globals['_HOST_TYPE']._serialized_end=1129
  _globals['_HOST_ROLE']._serialized_start=1131
  _globals['_HOST_ROLE']._serialized_end=1208
  _globals['_HOST_HEALTH']._serialized_start=1210
  _globals['_HOST_HEALTH']._serialized_end=1273
  _globals['_SERVICE']._serialized_start=1276
  _globals['_SERVICE']._serialized_end=1586
  _globals['_SERVICE_TYPE']._serialized_start=994
  _globals['_SERVICE_TYPE']._serialized_end=1129
  _globals['_SERVICE_HEALTH']._serialized_start=1210
  _globals['_SERVICE_HEALTH']._serialized_end=1259
  _globals['_HOSTSPEC']._serialized_start=1589
  _globals['_HOSTSPEC']._serialized_end=1851
# @@protoc_insertion_point(module_scope)
