# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cdn/v1/resource_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cdn/v1/resource_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.cdn.v1 import origin_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2
from yandex.cloud.cdn.v1 import resource_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/cdn/v1/resource_service.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/cdn/v1/origin.proto\x1a\"yandex/cloud/cdn/v1/resource.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"7\n\x12GetResourceRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"u\n\x14ListResourcesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"b\n\x15ListResourcesResponse\x12\x30\n\tresources\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.cdn.v1.Resource\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xd4\x05\n\x15\x43reateResourceRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x13\n\x05\x63name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12G\n\x06origin\x18\x03 \x01(\x0b\x32\x31.yandex.cloud.cdn.v1.CreateResourceRequest.OriginB\x04\xe8\xc7\x31\x01\x12\x44\n\x13secondary_hostnames\x18\x04 \x01(\x0b\x32\'.yandex.cloud.cdn.v1.SecondaryHostnames\x12<\n\x0forigin_protocol\x18\x05 \x01(\x0e\x32#.yandex.cloud.cdn.v1.OriginProtocol\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x07options\x18\x07 \x01(\x0b\x32$.yandex.cloud.cdn.v1.ResourceOptions\x12\x42\n\x0fssl_certificate\x18\x08 \x01(\x0b\x32).yandex.cloud.cdn.v1.SSLTargetCertificate\x12\x46\n\x06labels\x18\t \x03(\x0b\x32\x36.yandex.cloud.cdn.v1.CreateResourceRequest.LabelsEntry\x1a\x99\x01\n\x06Origin\x12\x19\n\x0forigin_group_id\x18\x01 \x01(\x03H\x00\x12\x17\n\rorigin_source\x18\x02 \x01(\tH\x00\x12I\n\x14origin_source_params\x18\x03 \x01(\x0b\x32).yandex.cloud.cdn.v1.ResourceOriginParamsH\x00\x42\x10\n\x0eorigin_variant\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n\x14ResourceOriginParams\x12\x0e\n\x06source\x18\x01 \x01(\t\x12-\n\x04meta\x18\x02 \x01(\x0b\x32\x1f.yandex.cloud.cdn.v1.OriginMeta\";\n\x16\x43reateResourceMetadata\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xa9\x04\n\x15UpdateResourceRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x34\n\x0forigin_group_id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x44\n\x13secondary_hostnames\x18\x03 \x01(\x0b\x32\'.yandex.cloud.cdn.v1.SecondaryHostnames\x12\x35\n\x07options\x18\x04 \x01(\x0b\x32$.yandex.cloud.cdn.v1.ResourceOptions\x12<\n\x0forigin_protocol\x18\x05 \x01(\x0e\x32#.yandex.cloud.cdn.v1.OriginProtocol\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x0fssl_certificate\x18\x07 \x01(\x0b\x32).yandex.cloud.cdn.v1.SSLTargetCertificate\x12\x46\n\x06labels\x18\x08 \x03(\x0b\x32\x36.yandex.cloud.cdn.v1.UpdateResourceRequest.LabelsEntry\x12\x15\n\rremove_labels\x18\t \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\";\n\x16UpdateResourceMetadata\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\":\n\x15\x44\x65leteResourceRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65leteResourceMetadata\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\":\n\x17GetProviderCNameRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"<\n\x18GetProviderCNameResponse\x12\r\n\x05\x63name\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t2\x98\x07\n\x0fResourceService\x12v\n\x03Get\x12\'.yandex.cloud.cdn.v1.GetResourceRequest\x1a\x1d.yandex.cloud.cdn.v1.Resource\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/cdn/v1/resources/{resource_id}\x12x\n\x04List\x12).yandex.cloud.cdn.v1.ListResourcesRequest\x1a*.yandex.cloud.cdn.v1.ListResourcesResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/cdn/v1/resources\x12\x9b\x01\n\x06\x43reate\x12*.yandex.cloud.cdn.v1.CreateResourceRequest\x1a!.yandex.cloud.operation.Operation\"B\xb2\xd2*\"\n\x16\x43reateResourceMetadata\x12\x08Resource\x82\xd3\xe4\x93\x02\x16\"\x11/cdn/v1/resources:\x01*\x12\xa9\x01\n\x06Update\x12*.yandex.cloud.cdn.v1.UpdateResourceRequest\x1a!.yandex.cloud.operation.Operation\"P\xb2\xd2*\"\n\x16UpdateResourceMetadata\x12\x08Resource\x82\xd3\xe4\x93\x02$2\x1f/cdn/v1/resources/{resource_id}:\x01*\x12\xb3\x01\n\x06\x44\x65lete\x12*.yandex.cloud.cdn.v1.DeleteResourceRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*/\n\x16\x44\x65leteResourceMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02!*\x1f/cdn/v1/resources/{resource_id}\x12\x92\x01\n\x10GetProviderCName\x12,.yandex.cloud.cdn.v1.GetProviderCNameRequest\x1a-.yandex.cloud.cdn.v1.GetProviderCNameResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/cdn/v1/cname/{folder_id}BV\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cdn.v1.resource_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn'
  _globals['_GETRESOURCEREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_GETRESOURCEREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTRESOURCESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTRESOURCESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTRESOURCESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTRESOURCESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTRESOURCESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTRESOURCESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATERESOURCEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATERESOURCEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATERESOURCEREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATERESOURCEREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATERESOURCEREQUEST'].fields_by_name['cname']._loaded_options = None
  _globals['_CREATERESOURCEREQUEST'].fields_by_name['cname']._serialized_options = b'\350\3071\001'
  _globals['_CREATERESOURCEREQUEST'].fields_by_name['origin']._loaded_options = None
  _globals['_CREATERESOURCEREQUEST'].fields_by_name['origin']._serialized_options = b'\350\3071\001'
  _globals['_CREATERESOURCEMETADATA'].fields_by_name['resource_id']._loaded_options = None
  _globals['_CREATERESOURCEMETADATA'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATERESOURCEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATERESOURCEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATERESOURCEREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_UPDATERESOURCEREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATERESOURCEMETADATA'].fields_by_name['resource_id']._loaded_options = None
  _globals['_UPDATERESOURCEMETADATA'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETERESOURCEREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_DELETERESOURCEREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETPROVIDERCNAMEREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_GETPROVIDERCNAMEREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESOURCESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_RESOURCESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002!\022\037/cdn/v1/resources/{resource_id}'
  _globals['_RESOURCESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_RESOURCESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\023\022\021/cdn/v1/resources'
  _globals['_RESOURCESERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_RESOURCESERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateResourceMetadata\022\010Resource\202\323\344\223\002\026\"\021/cdn/v1/resources:\001*'
  _globals['_RESOURCESERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_RESOURCESERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateResourceMetadata\022\010Resource\202\323\344\223\002$2\037/cdn/v1/resources/{resource_id}:\001*'
  _globals['_RESOURCESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_RESOURCESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteResourceMetadata\022\025google.protobuf.Empty\202\323\344\223\002!*\037/cdn/v1/resources/{resource_id}'
  _globals['_RESOURCESERVICE'].methods_by_name['GetProviderCName']._loaded_options = None
  _globals['_RESOURCESERVICE'].methods_by_name['GetProviderCName']._serialized_options = b'\202\323\344\223\002\033\022\031/cdn/v1/cname/{folder_id}'
  _globals['_GETRESOURCEREQUEST']._serialized_start=304
  _globals['_GETRESOURCEREQUEST']._serialized_end=359
  _globals['_LISTRESOURCESREQUEST']._serialized_start=361
  _globals['_LISTRESOURCESREQUEST']._serialized_end=478
  _globals['_LISTRESOURCESRESPONSE']._serialized_start=480
  _globals['_LISTRESOURCESRESPONSE']._serialized_end=578
  _globals['_CREATERESOURCEREQUEST']._serialized_start=581
  _globals['_CREATERESOURCEREQUEST']._serialized_end=1305
  _globals['_CREATERESOURCEREQUEST_ORIGIN']._serialized_start=1105
  _globals['_CREATERESOURCEREQUEST_ORIGIN']._serialized_end=1258
  _globals['_CREATERESOURCEREQUEST_LABELSENTRY']._serialized_start=1260
  _globals['_CREATERESOURCEREQUEST_LABELSENTRY']._serialized_end=1305
  _globals['_RESOURCEORIGINPARAMS']._serialized_start=1307
  _globals['_RESOURCEORIGINPARAMS']._serialized_end=1392
  _globals['_CREATERESOURCEMETADATA']._serialized_start=1394
  _globals['_CREATERESOURCEMETADATA']._serialized_end=1453
  _globals['_UPDATERESOURCEREQUEST']._serialized_start=1456
  _globals['_UPDATERESOURCEREQUEST']._serialized_end=2009
  _globals['_UPDATERESOURCEREQUEST_LABELSENTRY']._serialized_start=1260
  _globals['_UPDATERESOURCEREQUEST_LABELSENTRY']._serialized_end=1305
  _globals['_UPDATERESOURCEMETADATA']._serialized_start=2011
  _globals['_UPDATERESOURCEMETADATA']._serialized_end=2070
  _globals['_DELETERESOURCEREQUEST']._serialized_start=2072
  _globals['_DELETERESOURCEREQUEST']._serialized_end=2130
  _globals['_DELETERESOURCEMETADATA']._serialized_start=2132
  _globals['_DELETERESOURCEMETADATA']._serialized_end=2177
  _globals['_GETPROVIDERCNAMEREQUEST']._serialized_start=2179
  _globals['_GETPROVIDERCNAMEREQUEST']._serialized_end=2237
  _globals['_GETPROVIDERCNAMERESPONSE']._serialized_start=2239
  _globals['_GETPROVIDERCNAMERESPONSE']._serialized_end=2299
  _globals['_RESOURCESERVICE']._serialized_start=2302
  _globals['_RESOURCESERVICE']._serialized_end=3222
# @@protoc_insertion_point(module_scope)
