# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/speechsense/v1/search.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/speechsense/v1/search.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/speechsense/v1/search.proto\x12\x1byandex.cloud.speechsense.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x86\x04\n\x06\x46ilter\x12\x0b\n\x03key\x18\x01 \x01(\t\x12@\n\tany_match\x18\x02 \x01(\x0b\x32+.yandex.cloud.speechsense.v1.AnyMatchFilterH\x00\x12@\n\tint_range\x18\x03 \x01(\x0b\x32+.yandex.cloud.speechsense.v1.IntRangeFilterH\x00\x12\x46\n\x0c\x64ouble_range\x18\x04 \x01(\x0b\x32..yandex.cloud.speechsense.v1.DoubleRangeFilterH\x00\x12\x42\n\ndate_range\x18\x05 \x01(\x0b\x32,.yandex.cloud.speechsense.v1.DateRangeFilterH\x00\x12J\n\x0e\x64uration_range\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.speechsense.v1.DurationRangeFilterH\x00\x12\x43\n\rboolean_match\x18\t \x01(\x0b\x32*.yandex.cloud.speechsense.v1.BooleanFilterH\x00\x12\x0f\n\x07inverse\x18\x07 \x01(\x08\x12\x33\n\x0e\x63hannel_number\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\n\x06\x66ilter\"[\n\x05Query\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0f\n\x07inverse\x18\x02 \x01(\x08\x12\x33\n\x0e\x63hannel_number\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\" \n\x0e\x41nyMatchFilter\x12\x0e\n\x06values\x18\x01 \x03(\t\"?\n\x0f\x42oundsInclusive\x12\x16\n\x0e\x66rom_inclusive\x18\x01 \x01(\x08\x12\x14\n\x0cto_inclusive\x18\x02 \x01(\x08\"\xb8\x01\n\x0eIntRangeFilter\x12/\n\nfrom_value\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12-\n\x08to_value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x46\n\x10\x62ounds_inclusive\x18\x03 \x01(\x0b\x32,.yandex.cloud.speechsense.v1.BoundsInclusive\"\xbd\x01\n\x11\x44oubleRangeFilter\x12\x30\n\nfrom_value\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12.\n\x08to_value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x46\n\x10\x62ounds_inclusive\x18\x03 \x01(\x0b\x32,.yandex.cloud.speechsense.v1.BoundsInclusive\"\xb7\x01\n\x0f\x44\x61teRangeFilter\x12.\n\nfrom_value\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08to_value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x46\n\x10\x62ounds_inclusive\x18\x03 \x01(\x0b\x32,.yandex.cloud.speechsense.v1.BoundsInclusive\"\xb9\x01\n\x13\x44urationRangeFilter\x12-\n\nfrom_value\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08to_value\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x46\n\x10\x62ounds_inclusive\x18\x03 \x01(\x0b\x32,.yandex.cloud.speechsense.v1.BoundsInclusive\"\x1e\n\rBooleanFilter\x12\r\n\x05value\x18\x01 \x01(\x08\"B\n\x08SortData\x12\x36\n\x06\x66ields\x18\x01 \x03(\x0b\x32&.yandex.cloud.speechsense.v1.SortField\"c\n\tSortField\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x35\n\x05order\x18\x02 \x01(\x0e\x32&.yandex.cloud.speechsense.v1.SortOrder\x12\x10\n\x08position\x18\x03 \x01(\x03*P\n\tSortOrder\x12\x1a\n\x16SORT_ORDER_UNSPECIFIED\x10\x00\x12\x12\n\x0eSORT_ORDER_ASC\x10\x01\x12\x13\n\x0fSORT_ORDER_DESC\x10\x02\x42{\n\x1fyandex.cloud.api.speechsense.v1B\x0bSearchProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.search_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.speechsense.v1B\013SearchProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsense'
  _globals['_SORTORDER']._serialized_start=1837
  _globals['_SORTORDER']._serialized_end=1917
  _globals['_FILTER']._serialized_start=171
  _globals['_FILTER']._serialized_end=689
  _globals['_QUERY']._serialized_start=691
  _globals['_QUERY']._serialized_end=782
  _globals['_ANYMATCHFILTER']._serialized_start=784
  _globals['_ANYMATCHFILTER']._serialized_end=816
  _globals['_BOUNDSINCLUSIVE']._serialized_start=818
  _globals['_BOUNDSINCLUSIVE']._serialized_end=881
  _globals['_INTRANGEFILTER']._serialized_start=884
  _globals['_INTRANGEFILTER']._serialized_end=1068
  _globals['_DOUBLERANGEFILTER']._serialized_start=1071
  _globals['_DOUBLERANGEFILTER']._serialized_end=1260
  _globals['_DATERANGEFILTER']._serialized_start=1263
  _globals['_DATERANGEFILTER']._serialized_end=1446
  _globals['_DURATIONRANGEFILTER']._serialized_start=1449
  _globals['_DURATIONRANGEFILTER']._serialized_end=1634
  _globals['_BOOLEANFILTER']._serialized_start=1636
  _globals['_BOOLEANFILTER']._serialized_end=1666
  _globals['_SORTDATA']._serialized_start=1668
  _globals['_SORTDATA']._serialized_end=1734
  _globals['_SORTFIELD']._serialized_start=1736
  _globals['_SORTFIELD']._serialized_end=1835
# @@protoc_insertion_point(module_scope)
