"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Points(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUIZ_FIELD_NUMBER: builtins.int
    @property
    def quiz(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Quiz]: ...
    def __init__(
        self,
        *,
        quiz: collections.abc.Iterable[global___Quiz] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["quiz", b"quiz"]) -> None: ...

global___Points = Points

@typing.final
class Quiz(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    request: builtins.str
    id: builtins.str
    @property
    def response(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        request: builtins.str = ...,
        response: google.protobuf.wrappers_pb2.StringValue | None = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["response", b"response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "request", b"request", "response", b"response"]) -> None: ...

global___Quiz = Quiz
