# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iot/devices/v1/registry_data_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iot/devices/v1/registry_data_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7yandex/cloud/iot/devices/v1/registry_data_service.proto\x12\x1byandex.cloud.iot.devices.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\"z\n\x1aPublishRegistryDataRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x05topic\x18\x02 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1024\x12\x1a\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x42\x0c\x8a\xc8\x31\x08<=262144\"\x1d\n\x1bPublishRegistryDataResponse2\xd1\x01\n\x13RegistryDataService\x12\xb9\x01\n\x07Publish\x12\x37.yandex.cloud.iot.devices.v1.PublishRegistryDataRequest\x1a\x38.yandex.cloud.iot.devices.v1.PublishRegistryDataResponse\";\x82\xd3\xe4\x93\x02\x35\"0/iot-devices/v1/registries/{registry_id}/publish:\x01*Bj\n\x1fyandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devicesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iot.devices.v1.registry_data_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devices'
  _globals['_PUBLISHREGISTRYDATAREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_PUBLISHREGISTRYDATAREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PUBLISHREGISTRYDATAREQUEST'].fields_by_name['topic']._loaded_options = None
  _globals['_PUBLISHREGISTRYDATAREQUEST'].fields_by_name['topic']._serialized_options = b'\350\3071\001\212\3101\006<=1024'
  _globals['_PUBLISHREGISTRYDATAREQUEST'].fields_by_name['data']._loaded_options = None
  _globals['_PUBLISHREGISTRYDATAREQUEST'].fields_by_name['data']._serialized_options = b'\212\3101\010<=262144'
  _globals['_REGISTRYDATASERVICE'].methods_by_name['Publish']._loaded_options = None
  _globals['_REGISTRYDATASERVICE'].methods_by_name['Publish']._serialized_options = b'\202\323\344\223\0025\"0/iot-devices/v1/registries/{registry_id}/publish:\001*'
  _globals['_PUBLISHREGISTRYDATAREQUEST']._serialized_start=149
  _globals['_PUBLISHREGISTRYDATAREQUEST']._serialized_end=271
  _globals['_PUBLISHREGISTRYDATARESPONSE']._serialized_start=273
  _globals['_PUBLISHREGISTRYDATARESPONSE']._serialized_end=302
  _globals['_REGISTRYDATASERVICE']._serialized_start=305
  _globals['_REGISTRYDATASERVICE']._serialized_end=514
# @@protoc_insertion_point(module_scope)
