# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/user_account.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/user_account.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/organizationmanager/v1/user_account.proto\x12#yandex.cloud.organizationmanager.v1\x1a\x1dyandex/cloud/validation.proto\"\xea\x01\n\x0bUserAccount\x12\n\n\x02id\x18\x01 \x01(\t\x12\x66\n\x1cyandex_passport_user_account\x18\x02 \x01(\x0b\x32>.yandex.cloud.organizationmanager.v1.YandexPassportUserAccountH\x00\x12Q\n\x11saml_user_account\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.organizationmanager.v1.SamlUserAccountH\x00\x42\x14\n\x0cuser_account\x12\x04\xc0\xc1\x31\x01\"A\n\x19YandexPassportUserAccount\x12\r\n\x05login\x18\x01 \x01(\t\x12\x15\n\rdefault_email\x18\x02 \x01(\t\"\xbf\x02\n\x0fSamlUserAccount\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1e\n\x07name_id\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x31-256\x12X\n\nattributes\x18\x03 \x03(\x0b\x32\x44.yandex.cloud.organizationmanager.v1.SamlUserAccount.AttributesEntry\x1a\x1a\n\tAttribute\x12\r\n\x05value\x18\x01 \x03(\t\x1aq\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12M\n\x05value\x18\x02 \x01(\x0b\x32>.yandex.cloud.organizationmanager.v1.SamlUserAccount.Attribute:\x02\x38\x01\x42\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.user_account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager'
  _globals['_USERACCOUNT'].oneofs_by_name['user_account']._loaded_options = None
  _globals['_USERACCOUNT'].oneofs_by_name['user_account']._serialized_options = b'\300\3011\001'
  _globals['_SAMLUSERACCOUNT_ATTRIBUTESENTRY']._loaded_options = None
  _globals['_SAMLUSERACCOUNT_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_SAMLUSERACCOUNT'].fields_by_name['federation_id']._loaded_options = None
  _globals['_SAMLUSERACCOUNT'].fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SAMLUSERACCOUNT'].fields_by_name['name_id']._loaded_options = None
  _globals['_SAMLUSERACCOUNT'].fields_by_name['name_id']._serialized_options = b'\350\3071\001\212\3101\0051-256'
  _globals['_USERACCOUNT']._serialized_start=127
  _globals['_USERACCOUNT']._serialized_end=361
  _globals['_YANDEXPASSPORTUSERACCOUNT']._serialized_start=363
  _globals['_YANDEXPASSPORTUSERACCOUNT']._serialized_end=428
  _globals['_SAMLUSERACCOUNT']._serialized_start=431
  _globals['_SAMLUSERACCOUNT']._serialized_end=750
  _globals['_SAMLUSERACCOUNT_ATTRIBUTE']._serialized_start=609
  _globals['_SAMLUSERACCOUNT_ATTRIBUTE']._serialized_end=635
  _globals['_SAMLUSERACCOUNT_ATTRIBUTESENTRY']._serialized_start=637
  _globals['_SAMLUSERACCOUNT_ATTRIBUTESENTRY']._serialized_end=750
# @@protoc_insertion_point(module_scope)
