# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iam/v1/workload/oidc/federation.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iam/v1/workload/oidc/federation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/iam/v1/workload/oidc/federation.proto\x12!yandex.cloud.iam.v1.workload.oidc\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbe\x02\n\nFederation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x05 \x01(\x08\x12\x11\n\taudiences\x18\x06 \x03(\t\x12\x0e\n\x06issuer\x18\x07 \x01(\t\x12\x10\n\x08jwks_url\x18\x08 \x01(\t\x12I\n\x06labels\x18\t \x03(\x0b\x32\x39.yandex.cloud.iam.v1.workload.oidc.Federation.LabelsEntry\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42s\n%yandex.cloud.api.iam.v1.workload.oidcZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1/workload/oidc;oidcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.workload.oidc.federation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.iam.v1.workload.oidcZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1/workload/oidc;oidc'
  _globals['_FEDERATION_LABELSENTRY']._loaded_options = None
  _globals['_FEDERATION_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_FEDERATION']._serialized_start=123
  _globals['_FEDERATION']._serialized_end=441
  _globals['_FEDERATION_LABELSENTRY']._serialized_start=396
  _globals['_FEDERATION_LABELSENTRY']._serialized_end=441
# @@protoc_insertion_point(module_scope)
