# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iam/v1/user_account_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iam/v1/user_account_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.iam.v1 import user_account_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_user__account__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/iam/v1/user_account_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a&yandex/cloud/iam/v1/user_account.proto\x1a\x1dyandex/cloud/validation.proto\">\n\x15GetUserAccountRequest\x12%\n\x0fuser_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=502\x9a\x01\n\x12UserAccountService\x12\x83\x01\n\x03Get\x12*.yandex.cloud.iam.v1.GetUserAccountRequest\x1a .yandex.cloud.iam.v1.UserAccount\".\x82\xd3\xe4\x93\x02(\x12&/iam/v1/userAccounts/{user_account_id}BV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.user_account_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _globals['_GETUSERACCOUNTREQUEST'].fields_by_name['user_account_id']._loaded_options = None
  _globals['_GETUSERACCOUNTREQUEST'].fields_by_name['user_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_USERACCOUNTSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_USERACCOUNTSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002(\022&/iam/v1/userAccounts/{user_account_id}'
  _globals['_GETUSERACCOUNTREQUEST']._serialized_start=172
  _globals['_GETUSERACCOUNTREQUEST']._serialized_end=234
  _globals['_USERACCOUNTSERVICE']._serialized_start=237
  _globals['_USERACCOUNTSERVICE']._serialized_end=391
# @@protoc_insertion_point(module_scope)
