# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/marketplace/pim/v1/saas/product_instance.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/marketplace/pim/v1/saas/product_instance.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;yandex/cloud/marketplace/pim/v1/saas/product_instance.proto\x12$yandex.cloud.marketplace.pim.v1.saas\x1a\x1fgoogle/protobuf/timestamp.proto\"\x90\x04\n\x0fProductInstance\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12I\n\rresource_type\x18\x03 \x01(\x0e\x32\x32.yandex.cloud.marketplace.pim.v1.saas.ResourceType\x12\x66\n\x11resource_metadata\x18\x04 \x03(\x0b\x32K.yandex.cloud.marketplace.pim.v1.saas.ProductInstance.ResourceMetadataEntry\x12:\n\x05state\x18\x05 \x01(\x0e\x32+.yandex.cloud.marketplace.pim.v1.saas.State\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x43\n\tsaas_info\x18\x08 \x01(\x0b\x32..yandex.cloud.marketplace.pim.v1.saas.SaasInfoH\x00\x1a\x37\n\x15ResourceMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\rresource_info\"\x8b\x01\n\x08SaasInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x46\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x38.yandex.cloud.marketplace.pim.v1.saas.SaasInfo.DataEntry\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01*s\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\r\n\tACTIVATED\x10\x01\x12\x0f\n\x0b\x44\x45\x41\x43TIVATED\x10\x02\x12\x16\n\x12PENDING_ACTIVATION\x10\x03\x12\x0e\n\nDEPRECATED\x10\x04\x12\x0b\n\x07\x44\x45LETED\x10\x05*]\n\x0cResourceType\x12\x1d\n\x19RESOURCE_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04SAAS\x10\x01\x12\x07\n\x03K8S\x10\x02\x12\x0b\n\x07\x43OMPUTE\x10\x03\x12\x0e\n\nCLOUD_APPS\x10\x04\x42y\n(yandex.cloud.api.marketplace.pim.v1.saasZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/pim/v1/saas;saasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.marketplace.pim.v1.saas.product_instance_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.marketplace.pim.v1.saasZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/pim/v1/saas;saas'
  _globals['_PRODUCTINSTANCE_RESOURCEMETADATAENTRY']._loaded_options = None
  _globals['_PRODUCTINSTANCE_RESOURCEMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_SAASINFO_DATAENTRY']._loaded_options = None
  _globals['_SAASINFO_DATAENTRY']._serialized_options = b'8\001'
  _globals['_STATE']._serialized_start=807
  _globals['_STATE']._serialized_end=922
  _globals['_RESOURCETYPE']._serialized_start=924
  _globals['_RESOURCETYPE']._serialized_end=1017
  _globals['_PRODUCTINSTANCE']._serialized_start=135
  _globals['_PRODUCTINSTANCE']._serialized_end=663
  _globals['_PRODUCTINSTANCE_RESOURCEMETADATAENTRY']._serialized_start=591
  _globals['_PRODUCTINSTANCE_RESOURCEMETADATAENTRY']._serialized_end=646
  _globals['_SAASINFO']._serialized_start=666
  _globals['_SAASINFO']._serialized_end=805
  _globals['_SAASINFO_DATAENTRY']._serialized_start=762
  _globals['_SAASINFO_DATAENTRY']._serialized_end=805
# @@protoc_insertion_point(module_scope)
