"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class NodeExecutionErrorDetails(google.protobuf.message.Message):
    """User code python execution's error details"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_NAME_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    TRACEBACK_FIELD_NUMBER: builtins.int
    error_name: builtins.str
    """Error name"""
    error_message: builtins.str
    """Error message"""
    @property
    def traceback(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Error traceback"""

    def __init__(
        self,
        *,
        error_name: builtins.str = ...,
        error_message: builtins.str = ...,
        traceback: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["error_message", b"error_message", "error_name", b"error_name", "traceback", b"traceback"]) -> None: ...

global___NodeExecutionErrorDetails = NodeExecutionErrorDetails
