# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/loadtesting/api/v1/common/quantiles.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/loadtesting/api/v1/common/quantiles.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/loadtesting/api/v1/common/quantiles.proto\x12&yandex.cloud.loadtesting.api.v1.common\"\x81\x01\n\tQuantiles\x12\x0b\n\x03q50\x18\x01 \x01(\x01\x12\x0b\n\x03q75\x18\x02 \x01(\x01\x12\x0b\n\x03q80\x18\x03 \x01(\x01\x12\x0b\n\x03q85\x18\x04 \x01(\x01\x12\x0b\n\x03q90\x18\x05 \x01(\x01\x12\x0b\n\x03q95\x18\x06 \x01(\x01\x12\x0b\n\x03q98\x18\x07 \x01(\x01\x12\x0b\n\x03q99\x18\x08 \x01(\x01\x12\x0c\n\x04q100\x18\t \x01(\x01*\xf4\x01\n\x0cQuantileType\x12\x1d\n\x19QUANTILE_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10QUANTILE_TYPE_50\x10\x01\x12\x14\n\x10QUANTILE_TYPE_75\x10\x02\x12\x14\n\x10QUANTILE_TYPE_80\x10\x03\x12\x14\n\x10QUANTILE_TYPE_85\x10\x04\x12\x14\n\x10QUANTILE_TYPE_90\x10\x05\x12\x14\n\x10QUANTILE_TYPE_95\x10\x06\x12\x14\n\x10QUANTILE_TYPE_98\x10\x07\x12\x14\n\x10QUANTILE_TYPE_99\x10\x08\x12\x15\n\x11QUANTILE_TYPE_100\x10\tB\x7f\n*yandex.cloud.api.loadtesting.api.v1.commonZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/common;commonb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.common.quantiles_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*yandex.cloud.api.loadtesting.api.v1.commonZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/common;common'
  _globals['_QUANTILETYPE']._serialized_start=231
  _globals['_QUANTILETYPE']._serialized_end=475
  _globals['_QUANTILES']._serialized_start=99
  _globals['_QUANTILES']._serialized_end=228
# @@protoc_insertion_point(module_scope)
