"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.loadtesting.api.v1.report.kpi_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Widget(google.protobuf.message.Message):
    """Regression dashboard widget."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LayoutPosition(google.protobuf.message.Message):
        """Widget position."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        X_FIELD_NUMBER: builtins.int
        Y_FIELD_NUMBER: builtins.int
        WIDTH_FIELD_NUMBER: builtins.int
        HEIGHT_FIELD_NUMBER: builtins.int
        x: builtins.int
        """X."""
        y: builtins.int
        """Y."""
        width: builtins.int
        """Width."""
        height: builtins.int
        """Height."""
        def __init__(
            self,
            *,
            x: builtins.int = ...,
            y: builtins.int = ...,
            width: builtins.int = ...,
            height: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["height", b"height", "width", b"width", "x", b"x", "y", b"y"]) -> None: ...

    POSITION_FIELD_NUMBER: builtins.int
    CHART_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    @property
    def position(self) -> global___Widget.LayoutPosition:
        """Widget position."""

    @property
    def chart(self) -> global___ChartWidget:
        """Chart widget."""

    @property
    def text(self) -> global___TextWidget:
        """Text widget."""

    @property
    def title(self) -> global___TitleWidget:
        """Title widget."""

    def __init__(
        self,
        *,
        position: global___Widget.LayoutPosition | None = ...,
        chart: global___ChartWidget | None = ...,
        text: global___TextWidget | None = ...,
        title: global___TitleWidget | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["chart", b"chart", "position", b"position", "text", b"text", "title", b"title", "widget", b"widget"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chart", b"chart", "position", b"position", "text", b"text", "title", b"title", "widget", b"widget"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["widget", b"widget"]) -> typing.Literal["chart", "text", "title"] | None: ...

global___Widget = Widget

@typing.final
class ChartWidget(google.protobuf.message.Message):
    """Regression chart."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FILTER_STR_FIELD_NUMBER: builtins.int
    TEST_CASE_FIELD_NUMBER: builtins.int
    KPIS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the chart."""
    name: builtins.str
    """Name of the chart."""
    description: builtins.str
    """Description of the chart."""
    filter_str: builtins.str
    """Test filter selector to show KPI values for."""
    test_case: builtins.str
    """Test case to show KPI values for."""
    @property
    def kpis(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.loadtesting.api.v1.report.kpi_pb2.Kpi]:
        """KPIs to show."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        filter_str: builtins.str = ...,
        test_case: builtins.str = ...,
        kpis: collections.abc.Iterable[yandex.cloud.loadtesting.api.v1.report.kpi_pb2.Kpi] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "filter_str", b"filter_str", "id", b"id", "kpis", b"kpis", "name", b"name", "test_case", b"test_case"]) -> None: ...

global___ChartWidget = ChartWidget

@typing.final
class TextWidget(google.protobuf.message.Message):
    """Text widget."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Text string."""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["text", b"text"]) -> None: ...

global___TextWidget = TextWidget

@typing.final
class TitleWidget(google.protobuf.message.Message):
    """Title widget."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _TitleSize:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TitleSizeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TitleWidget._TitleSize.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TITLE_SIZE_UNSPECIFIED: TitleWidget._TitleSize.ValueType  # 0
        """Unspecified."""
        TITLE_SIZE_XS: TitleWidget._TitleSize.ValueType  # 1
        """Extra small."""
        TITLE_SIZE_S: TitleWidget._TitleSize.ValueType  # 2
        """Small."""
        TITLE_SIZE_M: TitleWidget._TitleSize.ValueType  # 3
        """Medium."""
        TITLE_SIZE_L: TitleWidget._TitleSize.ValueType  # 4
        """Large."""

    class TitleSize(_TitleSize, metaclass=_TitleSizeEnumTypeWrapper):
        """Title size."""

    TITLE_SIZE_UNSPECIFIED: TitleWidget.TitleSize.ValueType  # 0
    """Unspecified."""
    TITLE_SIZE_XS: TitleWidget.TitleSize.ValueType  # 1
    """Extra small."""
    TITLE_SIZE_S: TitleWidget.TitleSize.ValueType  # 2
    """Small."""
    TITLE_SIZE_M: TitleWidget.TitleSize.ValueType  # 3
    """Medium."""
    TITLE_SIZE_L: TitleWidget.TitleSize.ValueType  # 4
    """Large."""

    TEXT_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Title string."""
    size: global___TitleWidget.TitleSize.ValueType
    """Title size."""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        size: global___TitleWidget.TitleSize.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["size", b"size", "text", b"text"]) -> None: ...

global___TitleWidget = TitleWidget
