"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.advanced_rate_limiter_profile_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetAdvancedRateLimiterProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADVANCED_RATE_LIMITER_PROFILE_ID_FIELD_NUMBER: builtins.int
    advanced_rate_limiter_profile_id: builtins.str
    """ID of the AdvancedRateLimiterProfile resource to return."""
    def __init__(
        self,
        *,
        advanced_rate_limiter_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["advanced_rate_limiter_profile_id", b"advanced_rate_limiter_profile_id"]) -> None: ...

global___GetAdvancedRateLimiterProfileRequest = GetAdvancedRateLimiterProfileRequest

@typing.final
class ListAdvancedRateLimiterProfilesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that the ARL profile belongs to.
    Currently page_size, page_token, filter and order_by are not supported and List method will return all ARL profiles in the folder.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id"]) -> None: ...

global___ListAdvancedRateLimiterProfilesRequest = ListAdvancedRateLimiterProfilesRequest

@typing.final
class ListAdvancedRateLimiterProfilesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADVANCED_RATE_LIMITER_PROFILES_FIELD_NUMBER: builtins.int
    @property
    def advanced_rate_limiter_profiles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.advanced_rate_limiter_profile_pb2.AdvancedRateLimiterProfile]:
        """List of AdvancedRateLimiterProfile resources.
        Currently next_page_token is not supported and List method will return all ARL profiles in the folder.
        """

    def __init__(
        self,
        *,
        advanced_rate_limiter_profiles: collections.abc.Iterable[yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.advanced_rate_limiter_profile_pb2.AdvancedRateLimiterProfile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["advanced_rate_limiter_profiles", b"advanced_rate_limiter_profiles"]) -> None: ...

global___ListAdvancedRateLimiterProfilesResponse = ListAdvancedRateLimiterProfilesResponse

@typing.final
class CreateAdvancedRateLimiterProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ADVANCED_RATE_LIMITER_RULES_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a ARL profile in."""
    name: builtins.str
    """Name of the ARL profile. The name is unique within the folder. 1-50 characters long."""
    description: builtins.str
    """Optional description of the ARL profile."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels as `` key:value `` pairs. Maximum of 64 per resource."""

    @property
    def advanced_rate_limiter_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.advanced_rate_limiter_profile_pb2.AdvancedRateLimiterRule]:
        """List of rules."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        advanced_rate_limiter_rules: collections.abc.Iterable[yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.advanced_rate_limiter_profile_pb2.AdvancedRateLimiterRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["advanced_rate_limiter_rules", b"advanced_rate_limiter_rules", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name"]) -> None: ...

global___CreateAdvancedRateLimiterProfileRequest = CreateAdvancedRateLimiterProfileRequest

@typing.final
class CreateAdvancedRateLimiterProfileMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADVANCED_RATE_LIMITER_PROFILE_ID_FIELD_NUMBER: builtins.int
    advanced_rate_limiter_profile_id: builtins.str
    """ID of the ARL profile that is being created."""
    def __init__(
        self,
        *,
        advanced_rate_limiter_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["advanced_rate_limiter_profile_id", b"advanced_rate_limiter_profile_id"]) -> None: ...

global___CreateAdvancedRateLimiterProfileMetadata = CreateAdvancedRateLimiterProfileMetadata

@typing.final
class UpdateAdvancedRateLimiterProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ADVANCED_RATE_LIMITER_PROFILE_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ADVANCED_RATE_LIMITER_RULES_FIELD_NUMBER: builtins.int
    advanced_rate_limiter_profile_id: builtins.str
    """ID of the ARL profile to update."""
    name: builtins.str
    """Name of the ARL profile. The name is unique within the folder. 1-50 characters long."""
    description: builtins.str
    """Optional description of the ARL profile."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the AdvancedRateLimiterProfile resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels as `` key:value `` pairs. Maximum of 64 per resource."""

    @property
    def advanced_rate_limiter_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.advanced_rate_limiter_profile_pb2.AdvancedRateLimiterRule]:
        """List of rules."""

    def __init__(
        self,
        *,
        advanced_rate_limiter_profile_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        advanced_rate_limiter_rules: collections.abc.Iterable[yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.advanced_rate_limiter_profile_pb2.AdvancedRateLimiterRule] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["advanced_rate_limiter_profile_id", b"advanced_rate_limiter_profile_id", "advanced_rate_limiter_rules", b"advanced_rate_limiter_rules", "description", b"description", "labels", b"labels", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateAdvancedRateLimiterProfileRequest = UpdateAdvancedRateLimiterProfileRequest

@typing.final
class UpdateAdvancedRateLimiterProfileMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADVANCED_RATE_LIMITER_PROFILE_ID_FIELD_NUMBER: builtins.int
    advanced_rate_limiter_profile_id: builtins.str
    """ID of the AdvancedRateLimiterProfile resource that is being updated."""
    def __init__(
        self,
        *,
        advanced_rate_limiter_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["advanced_rate_limiter_profile_id", b"advanced_rate_limiter_profile_id"]) -> None: ...

global___UpdateAdvancedRateLimiterProfileMetadata = UpdateAdvancedRateLimiterProfileMetadata

@typing.final
class DeleteAdvancedRateLimiterProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADVANCED_RATE_LIMITER_PROFILE_ID_FIELD_NUMBER: builtins.int
    advanced_rate_limiter_profile_id: builtins.str
    """ID of the ARL profile to delete."""
    def __init__(
        self,
        *,
        advanced_rate_limiter_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["advanced_rate_limiter_profile_id", b"advanced_rate_limiter_profile_id"]) -> None: ...

global___DeleteAdvancedRateLimiterProfileRequest = DeleteAdvancedRateLimiterProfileRequest

@typing.final
class DeleteAdvancedRateLimiterProfileMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADVANCED_RATE_LIMITER_PROFILE_ID_FIELD_NUMBER: builtins.int
    advanced_rate_limiter_profile_id: builtins.str
    """ID of the AdvancedRateLimiterProfile resource that is being deleted."""
    def __init__(
        self,
        *,
        advanced_rate_limiter_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["advanced_rate_limiter_profile_id", b"advanced_rate_limiter_profile_id"]) -> None: ...

global___DeleteAdvancedRateLimiterProfileMetadata = DeleteAdvancedRateLimiterProfileMetadata
