"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class AddMetricRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    CHUNKS_FIELD_NUMBER: builtins.int
    AGENT_INSTANCE_ID_FIELD_NUMBER: builtins.int
    compute_instance_id: builtins.str
    job_id: builtins.str
    agent_instance_id: builtins.str
    @property
    def chunks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MetricChunk]: ...
    def __init__(
        self,
        *,
        compute_instance_id: builtins.str = ...,
        job_id: builtins.str = ...,
        chunks: collections.abc.Iterable[global___MetricChunk] | None = ...,
        agent_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["agent_instance_id", b"agent_instance_id", "chunks", b"chunks", "compute_instance_id", b"compute_instance_id", "job_id", b"job_id"]) -> None: ...

global___AddMetricRequest = AddMetricRequest

@typing.final
class MetricChunk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    COMMENT_FIELD_NUMBER: builtins.int
    INSTANCE_HOST_FIELD_NUMBER: builtins.int
    timestamp: builtins.int
    comment: builtins.str
    instance_host: builtins.str
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Metric]: ...
    def __init__(
        self,
        *,
        data: collections.abc.Iterable[global___Metric] | None = ...,
        timestamp: builtins.int = ...,
        comment: builtins.str = ...,
        instance_host: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["comment", b"comment", "data", b"data", "instance_host", b"instance_host", "timestamp", b"timestamp"]) -> None: ...

global___MetricChunk = MetricChunk

@typing.final
class Metric(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METRIC_TYPE_FIELD_NUMBER: builtins.int
    METRIC_NAME_FIELD_NUMBER: builtins.int
    METRIC_VALUE_FIELD_NUMBER: builtins.int
    metric_type: builtins.str
    metric_name: builtins.str
    metric_value: builtins.float
    def __init__(
        self,
        *,
        metric_type: builtins.str = ...,
        metric_name: builtins.str = ...,
        metric_value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["metric_name", b"metric_name", "metric_type", b"metric_type", "metric_value", b"metric_value"]) -> None: ...

global___Metric = Metric

@typing.final
class AddMetricResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METRIC_TRAIL_ID_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    metric_trail_id: builtins.str
    code: builtins.int
    def __init__(
        self,
        *,
        metric_trail_id: builtins.str = ...,
        code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["code", b"code", "metric_trail_id", b"metric_trail_id"]) -> None: ...

global___AddMetricResponse = AddMetricResponse
