# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/video/v1/video.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/video/v1/video.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!yandex/cloud/video/v1/video.proto\x12\x15yandex.cloud.video.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xb0\t\n\x05Video\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x14\n\x0cthumbnail_id\x18\x05 \x01(\t\x12\x38\n\x06status\x18\x06 \x01(\x0e\x32(.yandex.cloud.video.v1.Video.VideoStatus\x12\x15\n\rerror_message\x18\x12 \x01(\t\x12H\n\x11visibility_status\x18\t \x01(\x0e\x32-.yandex.cloud.video.v1.Video.VisibilityStatus\x12+\n\x08\x64uration\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12<\n\x0e\x61uto_transcode\x18\x0b \x01(\x0e\x32$.yandex.cloud.video.v1.AutoTranscode\x12-\n\tenable_ad\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x14\n\x0csubtitle_ids\x18\x0c \x03(\t\x12\x36\n\x08\x66\x65\x61tures\x18\r \x01(\x0b\x32$.yandex.cloud.video.v1.VideoFeatures\x12\x37\n\x04tusd\x18\xe8\x07 \x01(\x0b\x32&.yandex.cloud.video.v1.VideoTUSDSourceH\x00\x12H\n\rpublic_access\x18\xd0\x0f \x01(\x0b\x32..yandex.cloud.video.v1.VideoPublicAccessRightsH\x01\x12K\n\x0fsign_url_access\x18\xd3\x0f \x01(\x0b\x32/.yandex.cloud.video.v1.VideoSignURLAccessRightsH\x01\x12.\n\ncreated_at\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x65 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x06labels\x18\xc8\x01 \x03(\x0b\x32(.yandex.cloud.video.v1.Video.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x7f\n\x0bVideoStatus\x12\x1c\n\x18VIDEO_STATUS_UNSPECIFIED\x10\x00\x12\x12\n\x0eWAIT_UPLOADING\x10\x01\x12\x0c\n\x08UPLOADED\x10\x02\x12\x0e\n\nPROCESSING\x10\x04\x12\t\n\x05READY\x10\x05\x12\t\n\x05\x45RROR\x10\x07\"\x04\x08\x03\x10\x03\"\x04\x08\x06\x10\x06\"U\n\x10VisibilityStatus\x12!\n\x1dVISIBILITY_STATUS_UNSPECIFIED\x10\x00\x12\r\n\tPUBLISHED\x10\x01\x12\x0f\n\x0bUNPUBLISHED\x10\x02\x42\x08\n\x06sourceB\x0f\n\raccess_rightsJ\x06\x08\xd1\x0f\x10\xd2\x0fJ\x06\x08\xd2\x0f\x10\xd3\x0fJ\x04\x08\x07\x10\x08J\x04\x08\n\x10\x0bJ\x04\x08\x0e\x10\x11J\x04\x08\x13\x10\x64J\x05\x08\x66\x10\xc8\x01J\x06\x08\xc9\x01\x10\xe8\x07J\x06\x08\xe9\x07\x10\xd0\x0f\"1\n\x0fVideoTUSDSource\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x11\n\tfile_size\x18\x02 \x01(\x03\"\x19\n\x17VideoPublicAccessRights\"\x1a\n\x18VideoSignURLAccessRights\"\x9a\x03\n\rVideoFeatures\x12=\n\x07summary\x18\x01 \x01(\x0b\x32,.yandex.cloud.video.v1.VideoFeatures.Summary\x1a\xdc\x01\n\x07Summary\x12\x42\n\x06result\x18\x01 \x01(\x0e\x32\x32.yandex.cloud.video.v1.VideoFeatures.FeatureResult\x12\x45\n\x04urls\x18\x03 \x03(\x0b\x32\x37.yandex.cloud.video.v1.VideoFeatures.Summary.SummaryURL\x1a@\n\nSummaryURL\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x13\n\x0btrack_index\x18\x02 \x01(\x03\x12\x10\n\x08src_lang\x18\x03 \x01(\tJ\x04\x08\x02\x10\x03\"k\n\rFeatureResult\x12\x1e\n\x1a\x46\x45\x41TURE_RESULT_UNSPECIFIED\x10\x00\x12\x11\n\rNOT_REQUESTED\x10\x01\x12\x0e\n\nPROCESSING\x10\x02\x12\x0b\n\x07SUCCESS\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04*H\n\rAutoTranscode\x12\x1e\n\x1a\x41UTO_TRANSCODE_UNSPECIFIED\x10\x00\x12\n\n\x06\x45NABLE\x10\x01\x12\x0b\n\x07\x44ISABLE\x10\x02\x42\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.video_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_VIDEO_LABELSENTRY']._loaded_options = None
  _globals['_VIDEO_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_AUTOTRANSCODE']._serialized_start=1879
  _globals['_AUTOTRANSCODE']._serialized_end=1951
  _globals['_VIDEO']._serialized_start=158
  _globals['_VIDEO']._serialized_end=1358
  _globals['_VIDEO_LABELSENTRY']._serialized_start=1007
  _globals['_VIDEO_LABELSENTRY']._serialized_end=1052
  _globals['_VIDEO_VIDEOSTATUS']._serialized_start=1054
  _globals['_VIDEO_VIDEOSTATUS']._serialized_end=1181
  _globals['_VIDEO_VISIBILITYSTATUS']._serialized_start=1183
  _globals['_VIDEO_VISIBILITYSTATUS']._serialized_end=1268
  _globals['_VIDEOTUSDSOURCE']._serialized_start=1360
  _globals['_VIDEOTUSDSOURCE']._serialized_end=1409
  _globals['_VIDEOPUBLICACCESSRIGHTS']._serialized_start=1411
  _globals['_VIDEOPUBLICACCESSRIGHTS']._serialized_end=1436
  _globals['_VIDEOSIGNURLACCESSRIGHTS']._serialized_start=1438
  _globals['_VIDEOSIGNURLACCESSRIGHTS']._serialized_end=1464
  _globals['_VIDEOFEATURES']._serialized_start=1467
  _globals['_VIDEOFEATURES']._serialized_end=1877
  _globals['_VIDEOFEATURES_SUMMARY']._serialized_start=1548
  _globals['_VIDEOFEATURES_SUMMARY']._serialized_end=1768
  _globals['_VIDEOFEATURES_SUMMARY_SUMMARYURL']._serialized_start=1698
  _globals['_VIDEOFEATURES_SUMMARY_SUMMARYURL']._serialized_end=1762
  _globals['_VIDEOFEATURES_FEATURERESULT']._serialized_start=1770
  _globals['_VIDEOFEATURES_FEATURERESULT']._serialized_end=1877
# @@protoc_insertion_point(module_scope)
