# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/sqlserver/v1/resource_preset_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/sqlserver/v1/resource_preset_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.mdb.sqlserver.v1 import resource_preset_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_resource__preset__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;yandex/cloud/mdb/sqlserver/v1/resource_preset_service.proto\x12\x1dyandex.cloud.mdb.sqlserver.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x33yandex/cloud/mdb/sqlserver/v1/resource_preset.proto\x1a\x1dyandex/cloud/validation.proto\"<\n\x18GetResourcePresetRequest\x12 \n\x12resource_preset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"Z\n\x1aListResourcePresetsRequest\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x8a\x01\n\x1bListResourcePresetsResponse\x12G\n\x10resource_presets\x18\x01 \x03(\x0b\x32-.yandex.cloud.mdb.sqlserver.v1.ResourcePreset\x12\"\n\x0fnext_page_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=1002\xf2\x02\n\x15ResourcePresetService\x12\xad\x01\n\x03Get\x12\x37.yandex.cloud.mdb.sqlserver.v1.GetResourcePresetRequest\x1a-.yandex.cloud.mdb.sqlserver.v1.ResourcePreset\">\x82\xd3\xe4\x93\x02\x38\x12\x36/mdb/sqlserver/v1/resourcePresets/{resource_preset_id}\x12\xa8\x01\n\x04List\x12\x39.yandex.cloud.mdb.sqlserver.v1.ListResourcePresetsRequest\x1a:.yandex.cloud.mdb.sqlserver.v1.ListResourcePresetsResponse\")\x82\xd3\xe4\x93\x02#\x12!/mdb/sqlserver/v1/resourcePresetsBv\n!yandex.cloud.api.mdb.sqlserver.v1B\x04PSRSZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserverb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.sqlserver.v1.resource_preset_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.sqlserver.v1B\004PSRSZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserver'
  _globals['_GETRESOURCEPRESETREQUEST'].fields_by_name['resource_preset_id']._loaded_options = None
  _globals['_GETRESOURCEPRESETREQUEST'].fields_by_name['resource_preset_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTRESOURCEPRESETSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTRESOURCEPRESETSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTRESOURCEPRESETSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTRESOURCEPRESETSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTRESOURCEPRESETSRESPONSE'].fields_by_name['next_page_token']._loaded_options = None
  _globals['_LISTRESOURCEPRESETSRESPONSE'].fields_by_name['next_page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_RESOURCEPRESETSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_RESOURCEPRESETSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0028\0226/mdb/sqlserver/v1/resourcePresets/{resource_preset_id}'
  _globals['_RESOURCEPRESETSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_RESOURCEPRESETSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002#\022!/mdb/sqlserver/v1/resourcePresets'
  _globals['_GETRESOURCEPRESETREQUEST']._serialized_start=208
  _globals['_GETRESOURCEPRESETREQUEST']._serialized_end=268
  _globals['_LISTRESOURCEPRESETSREQUEST']._serialized_start=270
  _globals['_LISTRESOURCEPRESETSREQUEST']._serialized_end=360
  _globals['_LISTRESOURCEPRESETSRESPONSE']._serialized_start=363
  _globals['_LISTRESOURCEPRESETSRESPONSE']._serialized_end=501
  _globals['_RESOURCEPRESETSERVICE']._serialized_start=504
  _globals['_RESOURCEPRESETSERVICE']._serialized_end=874
# @@protoc_insertion_point(module_scope)
