# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ydb/v1/backup.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ydb/v1/backup.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from google.type import dayofweek_pb2 as google_dot_type_dot_dayofweek__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n yandex/cloud/ydb/v1/backup.proto\x12\x13yandex.cloud.ydb.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/type/timeofday.proto\x1a\x1bgoogle/type/dayofweek.proto\x1a\x1dyandex/cloud/validation.proto\"\xc2\x02\n\x0e\x42\x61\x63kupSchedule\x12I\n\x15\x64\x61ily_backup_schedule\x18\x01 \x01(\x0b\x32(.yandex.cloud.ydb.v1.DailyBackupScheduleH\x00\x12K\n\x16weekly_backup_schedule\x18\x02 \x01(\x0b\x32).yandex.cloud.ydb.v1.WeeklyBackupScheduleH\x00\x12Q\n\x19recurring_backup_schedule\x18\x04 \x01(\x0b\x32,.yandex.cloud.ydb.v1.RecurringBackupScheduleH\x00\x12\x35\n\x11next_execute_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0e\n\x06policy\x12\x04\xc0\xc1\x31\x01\"i\n\x17RecurringBackupSchedule\x12\x34\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x18\n\nrecurrence\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"}\n\x18\x44\x61ysOfWeekBackupSchedule\x12-\n\x04\x64\x61ys\x18\x01 \x03(\x0e\x32\x16.google.type.DayOfWeekB\x07\x82\xc8\x31\x03\x31-7\x12\x32\n\x0c\x65xecute_time\x18\x02 \x01(\x0b\x32\x16.google.type.TimeOfDayB\x04\xe8\xc7\x31\x01\"d\n\x14WeeklyBackupSchedule\x12L\n\x0c\x64\x61ys_of_week\x18\x01 \x03(\x0b\x32-.yandex.cloud.ydb.v1.DaysOfWeekBackupScheduleB\x07\x82\xc8\x31\x03\x31-7\"I\n\x13\x44\x61ilyBackupSchedule\x12\x32\n\x0c\x65xecute_time\x18\x01 \x01(\x0b\x32\x16.google.type.TimeOfDayB\x04\xe8\xc7\x31\x01\"\xfe\x04\n\x0e\x42\x61\x63kupSettings\x12\x17\n\x04name\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12<\n\x0f\x62\x61\x63kup_schedule\x18\x03 \x01(\x0b\x32#.yandex.cloud.ydb.v1.BackupSchedule\x12\x36\n\x13\x62\x61\x63kup_time_to_live\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1f\n\x0csource_paths\x18\x05 \x03(\tB\t\x82\xc8\x31\x05<=256\x12*\n\x17source_paths_to_exclude\x18\x06 \x03(\tB\t\x82\xc8\x31\x05<=256\x12\x36\n\x04type\x18\x07 \x01(\x0e\x32(.yandex.cloud.ydb.v1.BackupSettings.Type\x12G\n\rstorage_class\x18\x08 \x01(\x0e\x32\x30.yandex.cloud.ydb.v1.BackupSettings.StorageClass\"2\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06SYSTEM\x10\x01\x12\x08\n\x04USER\x10\x02\"\xba\x01\n\x0cStorageClass\x12\x1d\n\x19STORAGE_CLASS_UNSPECIFIED\x10\x00\x12\x0c\n\x08STANDARD\x10\x01\x12\x16\n\x12REDUCED_REDUNDANCY\x10\x02\x12\x0f\n\x0bSTANDARD_IA\x10\x03\x12\x0e\n\nONEZONE_IA\x10\x04\x12\x17\n\x13INTELLIGENT_TIERING\x10\x05\x12\x0b\n\x07GLACIER\x10\x06\x12\x10\n\x0c\x44\x45\x45P_ARCHIVE\x10\x07\x12\x0c\n\x08OUTPOSTS\x10\x08\"L\n\x0c\x42\x61\x63kupConfig\x12<\n\x0f\x62\x61\x63kup_settings\x18\x01 \x03(\x0b\x32#.yandex.cloud.ydb.v1.BackupSettings\"\xaa\x04\n\x06\x42\x61\x63kup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x61tabase_id\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63ompleted_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x06status\x18\t \x01(\x0e\x32\".yandex.cloud.ydb.v1.Backup.Status\x12<\n\x0f\x62\x61\x63kup_settings\x18\n \x01(\x0b\x32#.yandex.cloud.ydb.v1.BackupSettings\x12.\n\x04type\x18\x0b \x01(\x0e\x32 .yandex.cloud.ydb.v1.Backup.Type\x12\x0c\n\x04size\x18\x0c \x01(\x03\"S\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\r\n\tCANCELLED\x10\x04\"2\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06SYSTEM\x10\x01\x12\x08\n\x04USER\x10\x02\x42V\n\x17yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ydb.v1.backup_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydb'
  _globals['_BACKUPSCHEDULE'].oneofs_by_name['policy']._loaded_options = None
  _globals['_BACKUPSCHEDULE'].oneofs_by_name['policy']._serialized_options = b'\300\3011\001'
  _globals['_RECURRINGBACKUPSCHEDULE'].fields_by_name['start_time']._loaded_options = None
  _globals['_RECURRINGBACKUPSCHEDULE'].fields_by_name['start_time']._serialized_options = b'\350\3071\001'
  _globals['_RECURRINGBACKUPSCHEDULE'].fields_by_name['recurrence']._loaded_options = None
  _globals['_RECURRINGBACKUPSCHEDULE'].fields_by_name['recurrence']._serialized_options = b'\350\3071\001'
  _globals['_DAYSOFWEEKBACKUPSCHEDULE'].fields_by_name['days']._loaded_options = None
  _globals['_DAYSOFWEEKBACKUPSCHEDULE'].fields_by_name['days']._serialized_options = b'\202\3101\0031-7'
  _globals['_DAYSOFWEEKBACKUPSCHEDULE'].fields_by_name['execute_time']._loaded_options = None
  _globals['_DAYSOFWEEKBACKUPSCHEDULE'].fields_by_name['execute_time']._serialized_options = b'\350\3071\001'
  _globals['_WEEKLYBACKUPSCHEDULE'].fields_by_name['days_of_week']._loaded_options = None
  _globals['_WEEKLYBACKUPSCHEDULE'].fields_by_name['days_of_week']._serialized_options = b'\202\3101\0031-7'
  _globals['_DAILYBACKUPSCHEDULE'].fields_by_name['execute_time']._loaded_options = None
  _globals['_DAILYBACKUPSCHEDULE'].fields_by_name['execute_time']._serialized_options = b'\350\3071\001'
  _globals['_BACKUPSETTINGS'].fields_by_name['name']._loaded_options = None
  _globals['_BACKUPSETTINGS'].fields_by_name['name']._serialized_options = b'\212\3101\005<=256'
  _globals['_BACKUPSETTINGS'].fields_by_name['description']._loaded_options = None
  _globals['_BACKUPSETTINGS'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_BACKUPSETTINGS'].fields_by_name['source_paths']._loaded_options = None
  _globals['_BACKUPSETTINGS'].fields_by_name['source_paths']._serialized_options = b'\202\3101\005<=256'
  _globals['_BACKUPSETTINGS'].fields_by_name['source_paths_to_exclude']._loaded_options = None
  _globals['_BACKUPSETTINGS'].fields_by_name['source_paths_to_exclude']._serialized_options = b'\202\3101\005<=256'
  _globals['_BACKUPSCHEDULE']._serialized_start=212
  _globals['_BACKUPSCHEDULE']._serialized_end=534
  _globals['_RECURRINGBACKUPSCHEDULE']._serialized_start=536
  _globals['_RECURRINGBACKUPSCHEDULE']._serialized_end=641
  _globals['_DAYSOFWEEKBACKUPSCHEDULE']._serialized_start=643
  _globals['_DAYSOFWEEKBACKUPSCHEDULE']._serialized_end=768
  _globals['_WEEKLYBACKUPSCHEDULE']._serialized_start=770
  _globals['_WEEKLYBACKUPSCHEDULE']._serialized_end=870
  _globals['_DAILYBACKUPSCHEDULE']._serialized_start=872
  _globals['_DAILYBACKUPSCHEDULE']._serialized_end=945
  _globals['_BACKUPSETTINGS']._serialized_start=948
  _globals['_BACKUPSETTINGS']._serialized_end=1586
  _globals['_BACKUPSETTINGS_TYPE']._serialized_start=1347
  _globals['_BACKUPSETTINGS_TYPE']._serialized_end=1397
  _globals['_BACKUPSETTINGS_STORAGECLASS']._serialized_start=1400
  _globals['_BACKUPSETTINGS_STORAGECLASS']._serialized_end=1586
  _globals['_BACKUPCONFIG']._serialized_start=1588
  _globals['_BACKUPCONFIG']._serialized_end=1664
  _globals['_BACKUP']._serialized_start=1667
  _globals['_BACKUP']._serialized_end=2221
  _globals['_BACKUP_STATUS']._serialized_start=2086
  _globals['_BACKUP_STATUS']._serialized_end=2169
  _globals['_BACKUP_TYPE']._serialized_start=1347
  _globals['_BACKUP_TYPE']._serialized_end=1397
# @@protoc_insertion_point(module_scope)
