# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iot/devices/v1/device.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iot/devices/v1/device.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/iot/devices/v1/device.proto\x12\x1byandex.cloud.iot.devices.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc1\x04\n\x06\x44\x65vice\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0bregistry_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12L\n\rtopic_aliases\x18\x06 \x03(\x0b\x32\x35.yandex.cloud.iot.devices.v1.Device.TopicAliasesEntry\x12:\n\x06status\x18\x07 \x01(\x0e\x32*.yandex.cloud.iot.devices.v1.Device.Status\x12J\n\x0fmonitoring_data\x18\x08 \x01(\x0b\x32\x31.yandex.cloud.iot.devices.v1.DeviceMonitoringData\x12?\n\x06labels\x18\t \x03(\x0b\x32/.yandex.cloud.iot.devices.v1.Device.LabelsEntry\x1a\x33\n\x11TopicAliasesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\"\x85\x01\n\x11\x44\x65viceCertificate\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x02 \x01(\t\x12\x18\n\x10\x63\x65rtificate_data\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"_\n\x0e\x44\x65vicePassword\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xc8\x02\n\x14\x44\x65viceMonitoringData\x12\x14\n\x0clast_auth_ip\x18\x01 \x01(\t\x12\x32\n\x0elast_auth_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16last_pub_activity_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16last_sub_activity_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_online_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x14last_disconnect_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp*!\n\nDeviceView\x12\t\n\x05\x42\x41SIC\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x42j\n\x1fyandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devicesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iot.devices.v1.device_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devices'
  _globals['_DEVICE_TOPICALIASESENTRY']._loaded_options = None
  _globals['_DEVICE_TOPICALIASESENTRY']._serialized_options = b'8\001'
  _globals['_DEVICE_LABELSENTRY']._loaded_options = None
  _globals['_DEVICE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_DEVICEVIEW']._serialized_start=1250
  _globals['_DEVICEVIEW']._serialized_end=1283
  _globals['_DEVICE']._serialized_start=107
  _globals['_DEVICE']._serialized_end=684
  _globals['_DEVICE_TOPICALIASESENTRY']._serialized_start=512
  _globals['_DEVICE_TOPICALIASESENTRY']._serialized_end=563
  _globals['_DEVICE_LABELSENTRY']._serialized_start=565
  _globals['_DEVICE_LABELSENTRY']._serialized_end=610
  _globals['_DEVICE_STATUS']._serialized_start=612
  _globals['_DEVICE_STATUS']._serialized_end=684
  _globals['_DEVICECERTIFICATE']._serialized_start=687
  _globals['_DEVICECERTIFICATE']._serialized_end=820
  _globals['_DEVICEPASSWORD']._serialized_start=822
  _globals['_DEVICEPASSWORD']._serialized_end=917
  _globals['_DEVICEMONITORINGDATA']._serialized_start=920
  _globals['_DEVICEMONITORINGDATA']._serialized_end=1248
# @@protoc_insertion_point(module_scope)
