"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ResourceGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    IS_USER_DEFINED_FIELD_NUMBER: builtins.int
    CONCURRENCY_FIELD_NUMBER: builtins.int
    CPU_RATE_LIMIT_FIELD_NUMBER: builtins.int
    MEMORY_LIMIT_FIELD_NUMBER: builtins.int
    MEMORY_SHARED_QUOTA_FIELD_NUMBER: builtins.int
    MEMORY_SPILL_RATIO_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def is_user_defined(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def concurrency(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """References to CONCURRENCY from gp resource group parameter"""

    @property
    def cpu_rate_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """References to CPU_RATE_LIMIT from gp resource group parameter"""

    @property
    def memory_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """References to MEMORY_LIMIT from gp resource group parameter"""

    @property
    def memory_shared_quota(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """References to MEMORY_SHARED_QUOTA from gp resource group parameter"""

    @property
    def memory_spill_ratio(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """References to MEMORY_SPILL_RATIO from gp resource group parameter"""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        is_user_defined: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        concurrency: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        cpu_rate_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        memory_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        memory_shared_quota: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        memory_spill_ratio: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["concurrency", b"concurrency", "cpu_rate_limit", b"cpu_rate_limit", "is_user_defined", b"is_user_defined", "memory_limit", b"memory_limit", "memory_shared_quota", b"memory_shared_quota", "memory_spill_ratio", b"memory_spill_ratio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["concurrency", b"concurrency", "cpu_rate_limit", b"cpu_rate_limit", "is_user_defined", b"is_user_defined", "memory_limit", b"memory_limit", "memory_shared_quota", b"memory_shared_quota", "memory_spill_ratio", b"memory_spill_ratio", "name", b"name"]) -> None: ...

global___ResourceGroup = ResourceGroup
