"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import yandex.cloud.marketplace.pim.v1.saas.product_instance_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetProductInstanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRODUCT_INSTANCE_ID_FIELD_NUMBER: builtins.int
    product_instance_id: builtins.str
    def __init__(
        self,
        *,
        product_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["product_instance_id", b"product_instance_id"]) -> None: ...

global___GetProductInstanceRequest = GetProductInstanceRequest

@typing.final
class ClaimProductInstanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    token: builtins.str
    resource_id: builtins.str
    @property
    def resource_info(self) -> yandex.cloud.marketplace.pim.v1.saas.product_instance_pb2.SaasInfo: ...
    def __init__(
        self,
        *,
        token: builtins.str = ...,
        resource_id: builtins.str = ...,
        resource_info: yandex.cloud.marketplace.pim.v1.saas.product_instance_pb2.SaasInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id", "resource_info", b"resource_info", "token", b"token"]) -> None: ...

global___ClaimProductInstanceRequest = ClaimProductInstanceRequest

@typing.final
class ClaimProductInstanceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRODUCT_ID_FIELD_NUMBER: builtins.int
    PRODUCT_INSTANCE_ID_FIELD_NUMBER: builtins.int
    LICENSE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    product_id: builtins.str
    product_instance_id: builtins.str
    license_instance_id: builtins.str
    def __init__(
        self,
        *,
        product_id: builtins.str = ...,
        product_instance_id: builtins.str = ...,
        license_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["license_instance_id", b"license_instance_id", "product_id", b"product_id", "product_instance_id", b"product_instance_id"]) -> None: ...

global___ClaimProductInstanceMetadata = ClaimProductInstanceMetadata
