# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/datasphere/v1/node_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/datasphere/v1/node_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/datasphere/v1/node_service.proto\x12\x1ayandex.cloud.datasphere.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\"b\n\x14NodeExecutionRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0f\n\x07node_id\x18\x02 \x01(\t\x12&\n\x05input\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"@\n\x15NodeExecutionResponse\x12\'\n\x06output\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"f\n\x15\x41liasExecutionRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x12\n\nalias_name\x18\x02 \x01(\t\x12&\n\x05input\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"A\n\x16\x41liasExecutionResponse\x12\'\n\x06output\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct2\xe1\x02\n\x0bNodeService\x12\xa1\x01\n\x07\x45xecute\x12\x30.yandex.cloud.datasphere.v1.NodeExecutionRequest\x1a\x31.yandex.cloud.datasphere.v1.NodeExecutionResponse\"1\x82\xd3\xe4\x93\x02+\"&/datasphere/v1/nodes/{node_id}:execute:\x01*\x12\xad\x01\n\x0c\x45xecuteAlias\x12\x31.yandex.cloud.datasphere.v1.AliasExecutionRequest\x1a\x32.yandex.cloud.datasphere.v1.AliasExecutionResponse\"6\x82\xd3\xe4\x93\x02\x30\"+/datasphere/v1/aliases/{alias_name}:execute:\x01*Bk\n\x1eyandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v1.node_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphere'
  _globals['_NODESERVICE'].methods_by_name['Execute']._loaded_options = None
  _globals['_NODESERVICE'].methods_by_name['Execute']._serialized_options = b'\202\323\344\223\002+\"&/datasphere/v1/nodes/{node_id}:execute:\001*'
  _globals['_NODESERVICE'].methods_by_name['ExecuteAlias']._loaded_options = None
  _globals['_NODESERVICE'].methods_by_name['ExecuteAlias']._serialized_options = b'\202\323\344\223\0020\"+/datasphere/v1/aliases/{alias_name}:execute:\001*'
  _globals['_NODEEXECUTIONREQUEST']._serialized_start=137
  _globals['_NODEEXECUTIONREQUEST']._serialized_end=235
  _globals['_NODEEXECUTIONRESPONSE']._serialized_start=237
  _globals['_NODEEXECUTIONRESPONSE']._serialized_end=301
  _globals['_ALIASEXECUTIONREQUEST']._serialized_start=303
  _globals['_ALIASEXECUTIONREQUEST']._serialized_end=405
  _globals['_ALIASEXECUTIONRESPONSE']._serialized_start=407
  _globals['_ALIASEXECUTIONRESPONSE']._serialized_end=472
  _globals['_NODESERVICE']._serialized_start=475
  _globals['_NODESERVICE']._serialized_end=828
# @@protoc_insertion_point(module_scope)
