# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/assistants/v1/users/user_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/assistants/v1/users/user_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.common import common_pb2 as yandex_dot_cloud_dot_ai_dot_common_dot_common__pb2
from yandex.cloud.ai.assistants.v1.users import user_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_users_dot_user__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/ai/assistants/v1/users/user_service.proto\x12#yandex.cloud.ai.assistants.v1.users\x1a#yandex/cloud/ai/common/common.proto\x1a.yandex/cloud/ai/assistants/v1/users/user.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"\xa7\x02\n\x11\x43reateUserRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x43\n\x11\x65xpiration_config\x18\x05 \x01(\x0b\x32(.yandex.cloud.ai.common.ExpirationConfig\x12R\n\x06labels\x18\x06 \x03(\x0b\x32\x42.yandex.cloud.ai.assistants.v1.users.CreateUserRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\'\n\x0eGetUserRequest\x12\x15\n\x07user_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xcc\x02\n\x11UpdateUserRequest\x12\x15\n\x07user_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x43\n\x11\x65xpiration_config\x18\x05 \x01(\x0b\x32(.yandex.cloud.ai.common.ExpirationConfig\x12R\n\x06labels\x18\x06 \x03(\x0b\x32\x42.yandex.cloud.ai.assistants.v1.users.UpdateUserRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"*\n\x11\x44\x65leteUserRequest\x12\x15\n\x07user_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x14\n\x12\x44\x65leteUserResponse\"R\n\x10ListUsersRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"f\n\x11ListUsersResponse\x12\x38\n\x05users\x18\x01 \x03(\x0b\x32).yandex.cloud.ai.assistants.v1.users.User\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe6\x05\n\x0bUserService\x12\x87\x01\n\x06\x43reate\x12\x36.yandex.cloud.ai.assistants.v1.users.CreateUserRequest\x1a).yandex.cloud.ai.assistants.v1.users.User\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/users/v1/users:\x01*\x12\x88\x01\n\x03Get\x12\x33.yandex.cloud.ai.assistants.v1.users.GetUserRequest\x1a).yandex.cloud.ai.assistants.v1.users.User\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/users/v1/users/{user_id}\x12\x91\x01\n\x06Update\x12\x36.yandex.cloud.ai.assistants.v1.users.UpdateUserRequest\x1a).yandex.cloud.ai.assistants.v1.users.User\"$\x82\xd3\xe4\x93\x02\x1e\x32\x19/users/v1/users/{user_id}:\x01*\x12\x9c\x01\n\x06\x44\x65lete\x12\x36.yandex.cloud.ai.assistants.v1.users.DeleteUserRequest\x1a\x37.yandex.cloud.ai.assistants.v1.users.DeleteUserResponse\"!\x82\xd3\xe4\x93\x02\x1b*\x19/users/v1/users/{user_id}\x12\x8e\x01\n\x04List\x12\x35.yandex.cloud.ai.assistants.v1.users.ListUsersRequest\x1a\x36.yandex.cloud.ai.assistants.v1.users.ListUsersResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/users/v1/usersBx\n\'yandex.cloud.api.ai.assistants.v1.usersZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/users;usersb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.users.user_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'yandex.cloud.api.ai.assistants.v1.usersZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/users;users'
  _globals['_CREATEUSERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEUSERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEUSERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_GETUSERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_GETUSERREQUEST'].fields_by_name['user_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEUSERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEUSERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['update_mask']._serialized_options = b'\350\3071\001'
  _globals['_DELETEUSERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_DELETEUSERREQUEST'].fields_by_name['user_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTUSERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_USERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Create']._serialized_options = b'\202\323\344\223\002\024\"\017/users/v1/users:\001*'
  _globals['_USERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\033\022\031/users/v1/users/{user_id}'
  _globals['_USERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Update']._serialized_options = b'\202\323\344\223\002\0362\031/users/v1/users/{user_id}:\001*'
  _globals['_USERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Delete']._serialized_options = b'\202\323\344\223\002\033*\031/users/v1/users/{user_id}'
  _globals['_USERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\021\022\017/users/v1/users'
  _globals['_CREATEUSERREQUEST']._serialized_start=276
  _globals['_CREATEUSERREQUEST']._serialized_end=571
  _globals['_CREATEUSERREQUEST_LABELSENTRY']._serialized_start=526
  _globals['_CREATEUSERREQUEST_LABELSENTRY']._serialized_end=571
  _globals['_GETUSERREQUEST']._serialized_start=573
  _globals['_GETUSERREQUEST']._serialized_end=612
  _globals['_UPDATEUSERREQUEST']._serialized_start=615
  _globals['_UPDATEUSERREQUEST']._serialized_end=947
  _globals['_UPDATEUSERREQUEST_LABELSENTRY']._serialized_start=526
  _globals['_UPDATEUSERREQUEST_LABELSENTRY']._serialized_end=571
  _globals['_DELETEUSERREQUEST']._serialized_start=949
  _globals['_DELETEUSERREQUEST']._serialized_end=991
  _globals['_DELETEUSERRESPONSE']._serialized_start=993
  _globals['_DELETEUSERRESPONSE']._serialized_end=1013
  _globals['_LISTUSERSREQUEST']._serialized_start=1015
  _globals['_LISTUSERSREQUEST']._serialized_end=1097
  _globals['_LISTUSERSRESPONSE']._serialized_start=1099
  _globals['_LISTUSERSRESPONSE']._serialized_end=1201
  _globals['_USERSERVICE']._serialized_start=1204
  _globals['_USERSERVICE']._serialized_end=1946
# @@protoc_insertion_point(module_scope)
