# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/ssh_certificate_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/ssh_certificate_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAyandex/cloud/organizationmanager/v1/ssh_certificate_service.proto\x12#yandex.cloud.organizationmanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\"\xdf\x01\n\x1dGenerateSshCertificateRequest\x12\x1c\n\x08\x63loud_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12#\n\x0forganization_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1e\n\nsubject_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x01\x12\x1c\n\x08os_login\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=32H\x01\x12#\n\npublic_key\x18\x05 \x01(\tB\x0f\xe8\xc7\x31\x01\x8a\xc8\x31\x07<=15000B\r\n\x05scope\x12\x04\xc0\xc1\x31\x01\x42\t\n\x07subject\"<\n\x1eGenerateSshCertificateResponse\x12\x1a\n\x12signed_certificate\x18\x01 \x01(\t2\xeb\x01\n\x15SshCertificateService\x12\xd1\x01\n\x08Generate\x12\x42.yandex.cloud.organizationmanager.v1.GenerateSshCertificateRequest\x1a\x43.yandex.cloud.organizationmanager.v1.GenerateSshCertificateResponse\"<\x82\xd3\xe4\x93\x02\x36\"1/organization-manager/v1/sshCertificates:generate:\x01*B\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.ssh_certificate_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager'
  _globals['_GENERATESSHCERTIFICATEREQUEST'].oneofs_by_name['scope']._loaded_options = None
  _globals['_GENERATESSHCERTIFICATEREQUEST'].oneofs_by_name['scope']._serialized_options = b'\300\3011\001'
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['cloud_id']._loaded_options = None
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['cloud_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['organization_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['subject_id']._loaded_options = None
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['subject_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['os_login']._loaded_options = None
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['os_login']._serialized_options = b'\212\3101\004<=32'
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['public_key']._loaded_options = None
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['public_key']._serialized_options = b'\350\3071\001\212\3101\007<=15000'
  _globals['_SSHCERTIFICATESERVICE'].methods_by_name['Generate']._loaded_options = None
  _globals['_SSHCERTIFICATESERVICE'].methods_by_name['Generate']._serialized_options = b'\202\323\344\223\0026\"1/organization-manager/v1/sshCertificates:generate:\001*'
  _globals['_GENERATESSHCERTIFICATEREQUEST']._serialized_start=168
  _globals['_GENERATESSHCERTIFICATEREQUEST']._serialized_end=391
  _globals['_GENERATESSHCERTIFICATERESPONSE']._serialized_start=393
  _globals['_GENERATESSHCERTIFICATERESPONSE']._serialized_end=453
  _globals['_SSHCERTIFICATESERVICE']._serialized_start=456
  _globals['_SSHCERTIFICATESERVICE']._serialized_end=691
# @@protoc_insertion_point(module_scope)
