"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DiskPlacementGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DiskPlacementGroup._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: DiskPlacementGroup._Status.ValueType  # 0
        CREATING: DiskPlacementGroup._Status.ValueType  # 1
        READY: DiskPlacementGroup._Status.ValueType  # 2
        DELETING: DiskPlacementGroup._Status.ValueType  # 4

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: DiskPlacementGroup.Status.ValueType  # 0
    CREATING: DiskPlacementGroup.Status.ValueType  # 1
    READY: DiskPlacementGroup.Status.ValueType  # 2
    DELETING: DiskPlacementGroup.Status.ValueType  # 4

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SPREAD_PLACEMENT_STRATEGY_FIELD_NUMBER: builtins.int
    PARTITION_PLACEMENT_STRATEGY_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the placement group."""
    folder_id: builtins.str
    """ID of the folder that the placement group belongs to."""
    name: builtins.str
    """Name of the placement group.
    The name is unique within the folder.
    """
    description: builtins.str
    """Description of the placement group."""
    zone_id: builtins.str
    """ID of the availability zone where the placement group resides."""
    status: global___DiskPlacementGroup.Status.ValueType
    """Current status of the placement group"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def spread_placement_strategy(self) -> global___DiskSpreadPlacementStrategy:
        """Distribute disks over distinct failure domains."""

    @property
    def partition_placement_strategy(self) -> global___DiskPartitionPlacementStrategy:
        """Distribute disks over partitions."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zone_id: builtins.str = ...,
        status: global___DiskPlacementGroup.Status.ValueType = ...,
        spread_placement_strategy: global___DiskSpreadPlacementStrategy | None = ...,
        partition_placement_strategy: global___DiskPartitionPlacementStrategy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "partition_placement_strategy", b"partition_placement_strategy", "placement_strategy", b"placement_strategy", "spread_placement_strategy", b"spread_placement_strategy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "partition_placement_strategy", b"partition_placement_strategy", "placement_strategy", b"placement_strategy", "spread_placement_strategy", b"spread_placement_strategy", "status", b"status", "zone_id", b"zone_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["placement_strategy", b"placement_strategy"]) -> typing.Literal["spread_placement_strategy", "partition_placement_strategy"] | None: ...

global___DiskPlacementGroup = DiskPlacementGroup

@typing.final
class DiskSpreadPlacementStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DiskSpreadPlacementStrategy = DiskSpreadPlacementStrategy

@typing.final
class DiskPartitionPlacementStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARTITIONS_FIELD_NUMBER: builtins.int
    partitions: builtins.int
    def __init__(
        self,
        *,
        partitions: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["partitions", b"partitions"]) -> None: ...

global___DiskPartitionPlacementStrategy = DiskPartitionPlacementStrategy
