# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/monitoring/v3/title_widget.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/monitoring/v3/title_widget.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/monitoring/v3/title_widget.proto\x12\x1ayandex.cloud.monitoring.v3\"\xce\x01\n\x0bTitleWidget\x12\x0c\n\x04text\x18\x01 \x01(\t\x12?\n\x04size\x18\x02 \x01(\x0e\x32\x31.yandex.cloud.monitoring.v3.TitleWidget.TitleSize\"p\n\tTitleSize\x12\x1a\n\x16TITLE_SIZE_UNSPECIFIED\x10\x00\x12\x11\n\rTITLE_SIZE_XS\x10\x01\x12\x10\n\x0cTITLE_SIZE_S\x10\x02\x12\x10\n\x0cTITLE_SIZE_M\x10\x03\x12\x10\n\x0cTITLE_SIZE_L\x10\x04\x42k\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.monitoring.v3.title_widget_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring'
  _globals['_TITLEWIDGET']._serialized_start=78
  _globals['_TITLEWIDGET']._serialized_end=284
  _globals['_TITLEWIDGET_TITLESIZE']._serialized_start=172
  _globals['_TITLEWIDGET_TITLESIZE']._serialized_end=284
# @@protoc_insertion_point(module_scope)
