# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/speechsense/v1/analysis/utterance_statistics.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/speechsense/v1/analysis/utterance_statistics.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.speechsense.v1.analysis import statistics_common_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_statistics__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?yandex/cloud/speechsense/v1/analysis/utterance_statistics.proto\x12$yandex.cloud.speechsense.v1.analysis\x1a<yandex/cloud/speechsense/v1/analysis/statistics_common.proto\"\xbf\x03\n\x13UtteranceStatistics\x12\x13\n\x0bspeaker_tag\x18\x01 \x01(\t\x12W\n\x11speech_boundaries\x18\x02 \x01(\x0b\x32<.yandex.cloud.speechsense.v1.analysis.AudioSegmentBoundaries\x12\x17\n\x0ftotal_speech_ms\x18\x03 \x01(\x03\x12\x14\n\x0cspeech_ratio\x18\x04 \x01(\x01\x12\x18\n\x10total_silence_ms\x18\x05 \x01(\x03\x12\x15\n\rsilence_ratio\x18\x06 \x01(\x01\x12\x13\n\x0bwords_count\x18\x07 \x01(\x03\x12\x15\n\rletters_count\x18\x08 \x01(\x03\x12U\n\x10words_per_second\x18\t \x01(\x0b\x32;.yandex.cloud.speechsense.v1.analysis.DescriptiveStatistics\x12W\n\x12letters_per_second\x18\n \x01(\x0b\x32;.yandex.cloud.speechsense.v1.analysis.DescriptiveStatisticsB\x9a\x01\n(yandex.cloud.api.speechsense.v1.analysisB\x18UtteranceStatisticsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.analysis.utterance_statistics_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.speechsense.v1.analysisB\030UtteranceStatisticsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsense'
  _globals['_UTTERANCESTATISTICS']._serialized_start=168
  _globals['_UTTERANCESTATISTICS']._serialized_end=615
# @@protoc_insertion_point(module_scope)
