# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/video/v1/playlist_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/video/v1/playlist_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.video.v1 import playlist_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_playlist__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/video/v1/playlist_service.proto\x12\x15yandex.cloud.video.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a$yandex/cloud/video/v1/playlist.proto\"7\n\x12GetPlaylistRequest\x12!\n\x0bplaylist_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xab\x01\n\x14ListPlaylistsRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x1f\n\npage_token\x18\x65 \x01(\tB\x0b\x8a\xc8\x31\x07<=15000\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x1a\n\x06\x66ilter\x18g \x01(\tB\n\x8a\xc8\x31\x06<=1000J\x04\x08\x02\x10\x64\"j\n\x15ListPlaylistsResponse\x12\x32\n\tplaylists\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.video.v1.Playlist\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\xac\x01\n\x15\x43reatePlaylistRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x05title\x18\x02 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=2500\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12=\n\x05items\x18\x04 \x03(\x0b\x32#.yandex.cloud.video.v1.PlaylistItemB\t\x82\xc8\x31\x05<=100\"-\n\x16\x43reatePlaylistMetadata\x12\x13\n\x0bplaylist_id\x18\x01 \x01(\t\"\xdf\x01\n\x15UpdatePlaylistRequest\x12!\n\x0bplaylist_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x34\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x19\n\x05title\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2500\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12=\n\x05items\x18\x05 \x03(\x0b\x32#.yandex.cloud.video.v1.PlaylistItemB\t\x82\xc8\x31\x05<=100\"-\n\x16UpdatePlaylistMetadata\x12\x13\n\x0bplaylist_id\x18\x01 \x01(\t\":\n\x15\x44\x65letePlaylistRequest\x12!\n\x0bplaylist_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65letePlaylistMetadata\x12\x13\n\x0bplaylist_id\x18\x01 \x01(\t\"h\n\x1b\x42\x61tchDeletePlaylistsRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\'\n\x0cplaylist_ids\x18\x02 \x03(\tB\x11\x82\xc8\x31\x05\x31-100\x8a\xc8\x31\x04<=50\"4\n\x1c\x42\x61tchDeletePlaylistsMetadata\x12\x14\n\x0cplaylist_ids\x18\x01 \x03(\t\"}\n\x1bGetPlaylistPlayerURLRequest\x12!\n\x0bplaylist_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12;\n\x06params\x18\x02 \x01(\x0b\x32+.yandex.cloud.video.v1.PlaylistPlayerParams\"F\n\x14PlaylistPlayerParams\x12\x0c\n\x04mute\x18\x01 \x01(\x08\x12\x10\n\x08\x61utoplay\x18\x02 \x01(\x08\x12\x0e\n\x06hidden\x18\x03 \x01(\x08\"@\n\x1cGetPlaylistPlayerURLResponse\x12\x12\n\nplayer_url\x18\x01 \x01(\t\x12\x0c\n\x04html\x18\x02 \x01(\t2\x99\t\n\x0fPlaylistService\x12|\n\x03Get\x12).yandex.cloud.video.v1.GetPlaylistRequest\x1a\x1f.yandex.cloud.video.v1.Playlist\")\x82\xd3\xe4\x93\x02#\x12!/video/v1/playlists/{playlist_id}\x12~\n\x04List\x12+.yandex.cloud.video.v1.ListPlaylistsRequest\x1a,.yandex.cloud.video.v1.ListPlaylistsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/video/v1/playlists\x12\x9f\x01\n\x06\x43reate\x12,.yandex.cloud.video.v1.CreatePlaylistRequest\x1a!.yandex.cloud.operation.Operation\"D\xb2\xd2*\"\n\x16\x43reatePlaylistMetadata\x12\x08Playlist\x82\xd3\xe4\x93\x02\x18\"\x13/video/v1/playlists:\x01*\x12\xad\x01\n\x06Update\x12,.yandex.cloud.video.v1.UpdatePlaylistRequest\x1a!.yandex.cloud.operation.Operation\"R\xb2\xd2*\"\n\x16UpdatePlaylistMetadata\x12\x08Playlist\x82\xd3\xe4\x93\x02&2!/video/v1/playlists/{playlist_id}:\x01*\x12\xb7\x01\n\x06\x44\x65lete\x12,.yandex.cloud.video.v1.DeletePlaylistRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*/\n\x16\x44\x65letePlaylistMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02#*!/video/v1/playlists/{playlist_id}\x12\xc9\x01\n\x0b\x42\x61tchDelete\x12\x32.yandex.cloud.video.v1.BatchDeletePlaylistsRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*5\n\x1c\x42\x61tchDeletePlaylistsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02$\"\x1f/video/v1/playlists:batchDelete:\x01*\x12\xaf\x01\n\x0cGetPlayerURL\x12\x32.yandex.cloud.video.v1.GetPlaylistPlayerURLRequest\x1a\x33.yandex.cloud.video.v1.GetPlaylistPlayerURLResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./video/v1/playlists/{playlist_id}:getPlayerURLB\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.playlist_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_GETPLAYLISTREQUEST'].fields_by_name['playlist_id']._loaded_options = None
  _globals['_GETPLAYLISTREQUEST'].fields_by_name['playlist_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTPLAYLISTSREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_LISTPLAYLISTSREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTPLAYLISTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPLAYLISTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_LISTPLAYLISTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTPLAYLISTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\007<=15000'
  _globals['_LISTPLAYLISTSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTPLAYLISTSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATEPLAYLISTREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_CREATEPLAYLISTREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEPLAYLISTREQUEST'].fields_by_name['title']._loaded_options = None
  _globals['_CREATEPLAYLISTREQUEST'].fields_by_name['title']._serialized_options = b'\350\3071\001\212\3101\006<=2500'
  _globals['_CREATEPLAYLISTREQUEST'].fields_by_name['items']._loaded_options = None
  _globals['_CREATEPLAYLISTREQUEST'].fields_by_name['items']._serialized_options = b'\202\3101\005<=100'
  _globals['_UPDATEPLAYLISTREQUEST'].fields_by_name['playlist_id']._loaded_options = None
  _globals['_UPDATEPLAYLISTREQUEST'].fields_by_name['playlist_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEPLAYLISTREQUEST'].fields_by_name['field_mask']._loaded_options = None
  _globals['_UPDATEPLAYLISTREQUEST'].fields_by_name['field_mask']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEPLAYLISTREQUEST'].fields_by_name['title']._loaded_options = None
  _globals['_UPDATEPLAYLISTREQUEST'].fields_by_name['title']._serialized_options = b'\212\3101\006<=2500'
  _globals['_UPDATEPLAYLISTREQUEST'].fields_by_name['items']._loaded_options = None
  _globals['_UPDATEPLAYLISTREQUEST'].fields_by_name['items']._serialized_options = b'\202\3101\005<=100'
  _globals['_DELETEPLAYLISTREQUEST'].fields_by_name['playlist_id']._loaded_options = None
  _globals['_DELETEPLAYLISTREQUEST'].fields_by_name['playlist_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BATCHDELETEPLAYLISTSREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_BATCHDELETEPLAYLISTSREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BATCHDELETEPLAYLISTSREQUEST'].fields_by_name['playlist_ids']._loaded_options = None
  _globals['_BATCHDELETEPLAYLISTSREQUEST'].fields_by_name['playlist_ids']._serialized_options = b'\202\3101\0051-100\212\3101\004<=50'
  _globals['_GETPLAYLISTPLAYERURLREQUEST'].fields_by_name['playlist_id']._loaded_options = None
  _globals['_GETPLAYLISTPLAYERURLREQUEST'].fields_by_name['playlist_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PLAYLISTSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_PLAYLISTSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002#\022!/video/v1/playlists/{playlist_id}'
  _globals['_PLAYLISTSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_PLAYLISTSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\025\022\023/video/v1/playlists'
  _globals['_PLAYLISTSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_PLAYLISTSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreatePlaylistMetadata\022\010Playlist\202\323\344\223\002\030\"\023/video/v1/playlists:\001*'
  _globals['_PLAYLISTSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_PLAYLISTSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdatePlaylistMetadata\022\010Playlist\202\323\344\223\002&2!/video/v1/playlists/{playlist_id}:\001*'
  _globals['_PLAYLISTSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_PLAYLISTSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeletePlaylistMetadata\022\025google.protobuf.Empty\202\323\344\223\002#*!/video/v1/playlists/{playlist_id}'
  _globals['_PLAYLISTSERVICE'].methods_by_name['BatchDelete']._loaded_options = None
  _globals['_PLAYLISTSERVICE'].methods_by_name['BatchDelete']._serialized_options = b'\262\322*5\n\034BatchDeletePlaylistsMetadata\022\025google.protobuf.Empty\202\323\344\223\002$\"\037/video/v1/playlists:batchDelete:\001*'
  _globals['_PLAYLISTSERVICE'].methods_by_name['GetPlayerURL']._loaded_options = None
  _globals['_PLAYLISTSERVICE'].methods_by_name['GetPlayerURL']._serialized_options = b'\202\323\344\223\0020\022./video/v1/playlists/{playlist_id}:getPlayerURL'
  _globals['_GETPLAYLISTREQUEST']._serialized_start=278
  _globals['_GETPLAYLISTREQUEST']._serialized_end=333
  _globals['_LISTPLAYLISTSREQUEST']._serialized_start=336
  _globals['_LISTPLAYLISTSREQUEST']._serialized_end=507
  _globals['_LISTPLAYLISTSRESPONSE']._serialized_start=509
  _globals['_LISTPLAYLISTSRESPONSE']._serialized_end=615
  _globals['_CREATEPLAYLISTREQUEST']._serialized_start=618
  _globals['_CREATEPLAYLISTREQUEST']._serialized_end=790
  _globals['_CREATEPLAYLISTMETADATA']._serialized_start=792
  _globals['_CREATEPLAYLISTMETADATA']._serialized_end=837
  _globals['_UPDATEPLAYLISTREQUEST']._serialized_start=840
  _globals['_UPDATEPLAYLISTREQUEST']._serialized_end=1063
  _globals['_UPDATEPLAYLISTMETADATA']._serialized_start=1065
  _globals['_UPDATEPLAYLISTMETADATA']._serialized_end=1110
  _globals['_DELETEPLAYLISTREQUEST']._serialized_start=1112
  _globals['_DELETEPLAYLISTREQUEST']._serialized_end=1170
  _globals['_DELETEPLAYLISTMETADATA']._serialized_start=1172
  _globals['_DELETEPLAYLISTMETADATA']._serialized_end=1217
  _globals['_BATCHDELETEPLAYLISTSREQUEST']._serialized_start=1219
  _globals['_BATCHDELETEPLAYLISTSREQUEST']._serialized_end=1323
  _globals['_BATCHDELETEPLAYLISTSMETADATA']._serialized_start=1325
  _globals['_BATCHDELETEPLAYLISTSMETADATA']._serialized_end=1377
  _globals['_GETPLAYLISTPLAYERURLREQUEST']._serialized_start=1379
  _globals['_GETPLAYLISTPLAYERURLREQUEST']._serialized_end=1504
  _globals['_PLAYLISTPLAYERPARAMS']._serialized_start=1506
  _globals['_PLAYLISTPLAYERPARAMS']._serialized_end=1576
  _globals['_GETPLAYLISTPLAYERURLRESPONSE']._serialized_start=1578
  _globals['_GETPLAYLISTPLAYERURLRESPONSE']._serialized_end=1642
  _globals['_PLAYLISTSERVICE']._serialized_start=1645
  _globals['_PLAYLISTSERVICE']._serialized_end=2822
# @@protoc_insertion_point(module_scope)
