# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/loadtesting/api/v1/regression/widget.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/loadtesting/api/v1/regression/widget.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.loadtesting.api.v1.report import kpi_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_report_dot_kpi__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7yandex/cloud/loadtesting/api/v1/regression/widget.proto\x12*yandex.cloud.loadtesting.api.v1.regression\x1a\x30yandex/cloud/loadtesting/api/v1/report/kpi.proto\"\x8a\x03\n\x06Widget\x12S\n\x08position\x18\x01 \x01(\x0b\x32\x41.yandex.cloud.loadtesting.api.v1.regression.Widget.LayoutPosition\x12H\n\x05\x63hart\x18\x02 \x01(\x0b\x32\x37.yandex.cloud.loadtesting.api.v1.regression.ChartWidgetH\x00\x12\x46\n\x04text\x18\x03 \x01(\x0b\x32\x36.yandex.cloud.loadtesting.api.v1.regression.TextWidgetH\x00\x12H\n\x05title\x18\x04 \x01(\x0b\x32\x37.yandex.cloud.loadtesting.api.v1.regression.TitleWidgetH\x00\x1a\x45\n\x0eLayoutPosition\x12\t\n\x01x\x18\x01 \x01(\x03\x12\t\n\x01y\x18\x02 \x01(\x03\x12\r\n\x05width\x18\x03 \x01(\x03\x12\x0e\n\x06height\x18\x04 \x01(\x03\x42\x08\n\x06widget\"\x9e\x01\n\x0b\x43hartWidget\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nfilter_str\x18\x04 \x01(\t\x12\x11\n\ttest_case\x18\x05 \x01(\t\x12\x39\n\x04kpis\x18\x06 \x03(\x0b\x32+.yandex.cloud.loadtesting.api.v1.report.Kpi\"\x1a\n\nTextWidget\x12\x0c\n\x04text\x18\x01 \x01(\t\"\xde\x01\n\x0bTitleWidget\x12\x0c\n\x04text\x18\x01 \x01(\t\x12O\n\x04size\x18\x02 \x01(\x0e\x32\x41.yandex.cloud.loadtesting.api.v1.regression.TitleWidget.TitleSize\"p\n\tTitleSize\x12\x1a\n\x16TITLE_SIZE_UNSPECIFIED\x10\x00\x12\x11\n\rTITLE_SIZE_XS\x10\x01\x12\x10\n\x0cTITLE_SIZE_S\x10\x02\x12\x10\n\x0cTITLE_SIZE_M\x10\x03\x12\x10\n\x0cTITLE_SIZE_L\x10\x04\x42\x8b\x01\n.yandex.cloud.api.loadtesting.api.v1.regressionZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/regression;regressionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.regression.widget_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n.yandex.cloud.api.loadtesting.api.v1.regressionZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/regression;regression'
  _globals['_WIDGET']._serialized_start=154
  _globals['_WIDGET']._serialized_end=548
  _globals['_WIDGET_LAYOUTPOSITION']._serialized_start=469
  _globals['_WIDGET_LAYOUTPOSITION']._serialized_end=538
  _globals['_CHARTWIDGET']._serialized_start=551
  _globals['_CHARTWIDGET']._serialized_end=709
  _globals['_TEXTWIDGET']._serialized_start=711
  _globals['_TEXTWIDGET']._serialized_end=737
  _globals['_TITLEWIDGET']._serialized_start=740
  _globals['_TITLEWIDGET']._serialized_end=962
  _globals['_TITLEWIDGET_TITLESIZE']._serialized_start=850
  _globals['_TITLEWIDGET_TITLESIZE']._serialized_end=962
# @@protoc_insertion_point(module_scope)
