# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/quotamanager/v1/quota_limit_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/quotamanager/v1/quota_limit_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.quotamanager.v1 import resource_pb2 as yandex_dot_cloud_dot_quotamanager_dot_v1_dot_resource__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/quotamanager/v1/quota_limit_service.proto\x12\x1cyandex.cloud.quotamanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a+yandex/cloud/quotamanager/v1/resource.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1egoogle/protobuf/wrappers.proto\"v\n\x14GetQuotaLimitRequest\x12>\n\x08resource\x18\x01 \x01(\x0b\x32&.yandex.cloud.quotamanager.v1.ResourceB\x04\xe8\xc7\x31\x01\x12\x1e\n\x08quota_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\"\xae\x01\n\x16ListQuotaLimitsRequest\x12>\n\x08resource\x18\x01 \x01(\x0b\x32&.yandex.cloud.quotamanager.v1.ResourceB\x04\xe8\xc7\x31\x01\x12\x15\n\x07service\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"\xac\x01\n\x17ListQuotaLimitsResponse\x12\x38\n\x08resource\x18\x01 \x01(\x0b\x32&.yandex.cloud.quotamanager.v1.Resource\x12>\n\x0cquota_limits\x18\x02 \x03(\x0b\x32(.yandex.cloud.quotamanager.v1.QuotaLimit\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t\"q\n\x13ListServicesRequest\x12\x1b\n\rresource_type\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"h\n\x14ListServicesResponse\x12\x37\n\x08services\x18\x01 \x03(\x0b\x32%.yandex.cloud.quotamanager.v1.Service\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"x\n\nQuotaLimit\x12\x10\n\x08quota_id\x18\x01 \x01(\t\x12+\n\x05limit\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x05usage\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"#\n\x07Service\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xf0\x03\n\x11QuotaLimitService\x12\x95\x01\n\x03Get\x12\x32.yandex.cloud.quotamanager.v1.GetQuotaLimitRequest\x1a(.yandex.cloud.quotamanager.v1.QuotaLimit\"0\x82\xd3\xe4\x93\x02*\x12(/quota-manager/v1/quotaLimits/{quota_id}\x12\x9a\x01\n\x04List\x12\x34.yandex.cloud.quotamanager.v1.ListQuotaLimitsRequest\x1a\x35.yandex.cloud.quotamanager.v1.ListQuotaLimitsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/quota-manager/v1/quotaLimits\x12\xa5\x01\n\x0cListServices\x12\x31.yandex.cloud.quotamanager.v1.ListServicesRequest\x1a\x32.yandex.cloud.quotamanager.v1.ListServicesResponse\".\x82\xd3\xe4\x93\x02(\x12&/quota-manager/v1/quotaLimits/servicesBq\n yandex.cloud.api.quotamanager.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/quotamanager/v1;quotamanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.quotamanager.v1.quota_limit_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n yandex.cloud.api.quotamanager.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/quotamanager/v1;quotamanager'
  _globals['_GETQUOTALIMITREQUEST'].fields_by_name['resource']._loaded_options = None
  _globals['_GETQUOTALIMITREQUEST'].fields_by_name['resource']._serialized_options = b'\350\3071\001'
  _globals['_GETQUOTALIMITREQUEST'].fields_by_name['quota_id']._loaded_options = None
  _globals['_GETQUOTALIMITREQUEST'].fields_by_name['quota_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _globals['_LISTQUOTALIMITSREQUEST'].fields_by_name['resource']._loaded_options = None
  _globals['_LISTQUOTALIMITSREQUEST'].fields_by_name['resource']._serialized_options = b'\350\3071\001'
  _globals['_LISTQUOTALIMITSREQUEST'].fields_by_name['service']._loaded_options = None
  _globals['_LISTQUOTALIMITSREQUEST'].fields_by_name['service']._serialized_options = b'\350\3071\001'
  _globals['_LISTQUOTALIMITSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTQUOTALIMITSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTQUOTALIMITSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTQUOTALIMITSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTSERVICESREQUEST'].fields_by_name['resource_type']._loaded_options = None
  _globals['_LISTSERVICESREQUEST'].fields_by_name['resource_type']._serialized_options = b'\350\3071\001'
  _globals['_LISTSERVICESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSERVICESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTSERVICESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSERVICESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_QUOTALIMITSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_QUOTALIMITSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002*\022(/quota-manager/v1/quotaLimits/{quota_id}'
  _globals['_QUOTALIMITSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_QUOTALIMITSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\037\022\035/quota-manager/v1/quotaLimits'
  _globals['_QUOTALIMITSERVICE'].methods_by_name['ListServices']._loaded_options = None
  _globals['_QUOTALIMITSERVICE'].methods_by_name['ListServices']._serialized_options = b'\202\323\344\223\002(\022&/quota-manager/v1/quotaLimits/services'
  _globals['_GETQUOTALIMITREQUEST']._serialized_start=226
  _globals['_GETQUOTALIMITREQUEST']._serialized_end=344
  _globals['_LISTQUOTALIMITSREQUEST']._serialized_start=347
  _globals['_LISTQUOTALIMITSREQUEST']._serialized_end=521
  _globals['_LISTQUOTALIMITSRESPONSE']._serialized_start=524
  _globals['_LISTQUOTALIMITSRESPONSE']._serialized_end=696
  _globals['_LISTSERVICESREQUEST']._serialized_start=698
  _globals['_LISTSERVICESREQUEST']._serialized_end=811
  _globals['_LISTSERVICESRESPONSE']._serialized_start=813
  _globals['_LISTSERVICESRESPONSE']._serialized_end=917
  _globals['_QUOTALIMIT']._serialized_start=919
  _globals['_QUOTALIMIT']._serialized_end=1039
  _globals['_SERVICE']._serialized_start=1041
  _globals['_SERVICE']._serialized_end=1076
  _globals['_QUOTALIMITSERVICE']._serialized_start=1079
  _globals['_QUOTALIMITSERVICE']._serialized_end=1575
# @@protoc_insertion_point(module_scope)
