# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/smartwebsecurity/v1/waf/rule_set_descriptor.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/smartwebsecurity/v1/waf/rule_set_descriptor.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>yandex/cloud/smartwebsecurity/v1/waf/rule_set_descriptor.proto\x12$yandex.cloud.smartwebsecurity.v1.waf\x1a\x1dyandex/cloud/validation.proto\"\xa0\x02\n\x11RuleSetDescriptor\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x15\n\x07version\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x10\n\x02id\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12V\n\x05rules\x18\x04 \x03(\x0b\x32G.yandex.cloud.smartwebsecurity.v1.waf.RuleSetDescriptor.RuleDescription\x1av\n\x0fRuleDescription\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\ranomaly_score\x18\x08 \x01(\x03\x12\x16\n\x0eparanoia_level\x18\t \x01(\x03J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\n\x10\x0b\x42\x85\x01\n(yandex.cloud.api.smartwebsecurity.v1.wafZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1/waf;smartwebsecurityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.smartwebsecurity.v1.waf.rule_set_descriptor_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.smartwebsecurity.v1.wafZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1/waf;smartwebsecurity'
  _globals['_RULESETDESCRIPTOR'].fields_by_name['name']._loaded_options = None
  _globals['_RULESETDESCRIPTOR'].fields_by_name['name']._serialized_options = b'\350\3071\001'
  _globals['_RULESETDESCRIPTOR'].fields_by_name['version']._loaded_options = None
  _globals['_RULESETDESCRIPTOR'].fields_by_name['version']._serialized_options = b'\350\3071\001'
  _globals['_RULESETDESCRIPTOR'].fields_by_name['id']._loaded_options = None
  _globals['_RULESETDESCRIPTOR'].fields_by_name['id']._serialized_options = b'\350\3071\001'
  _globals['_RULESETDESCRIPTOR']._serialized_start=136
  _globals['_RULESETDESCRIPTOR']._serialized_end=424
  _globals['_RULESETDESCRIPTOR_RULEDESCRIPTION']._serialized_start=306
  _globals['_RULESETDESCRIPTOR_RULEDESCRIPTION']._serialized_end=424
# @@protoc_insertion_point(module_scope)
