# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/billing/v1/sku_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/billing/v1/sku_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.billing.v1 import sku_pb2 as yandex_dot_cloud_dot_billing_dot_v1_dot_sku__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/billing/v1/sku_service.proto\x12\x17yandex.cloud.billing.v1\x1a\x1cgoogle/api/annotations.proto\x1a!yandex/cloud/billing/v1/sku.proto\x1a\x1dyandex/cloud/validation.proto\"]\n\rGetSkuRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x16\n\x08\x63urrency\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x12\x62illing_account_id\x18\x03 \x01(\t\"\x9f\x01\n\x0fListSkusRequest\x12\x16\n\x08\x63urrency\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x12\x62illing_account_id\x18\x02 \x01(\t\x12\x1a\n\x06\x66ilter\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1d\n\tpage_size\x18\x04 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"W\n\x10ListSkusResponse\x12*\n\x04skus\x18\x01 \x03(\x0b\x32\x1c.yandex.cloud.billing.v1.Sku\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xef\x01\n\nSkuService\x12j\n\x03Get\x12&.yandex.cloud.billing.v1.GetSkuRequest\x1a\x1c.yandex.cloud.billing.v1.Sku\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/billing/v1/skus/{id}\x12u\n\x04List\x12(.yandex.cloud.billing.v1.ListSkusRequest\x1a).yandex.cloud.billing.v1.ListSkusResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/billing/v1/skusBb\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.v1.sku_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing'
  _globals['_GETSKUREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETSKUREQUEST'].fields_by_name['id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETSKUREQUEST'].fields_by_name['currency']._loaded_options = None
  _globals['_GETSKUREQUEST'].fields_by_name['currency']._serialized_options = b'\350\3071\001'
  _globals['_LISTSKUSREQUEST'].fields_by_name['currency']._loaded_options = None
  _globals['_LISTSKUSREQUEST'].fields_by_name['currency']._serialized_options = b'\350\3071\001'
  _globals['_LISTSKUSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTSKUSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTSKUSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSKUSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTSKUSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSKUSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_SKUSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_SKUSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\027\022\025/billing/v1/skus/{id}'
  _globals['_SKUSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_SKUSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\022\022\020/billing/v1/skus'
  _globals['_GETSKUREQUEST']._serialized_start=166
  _globals['_GETSKUREQUEST']._serialized_end=259
  _globals['_LISTSKUSREQUEST']._serialized_start=262
  _globals['_LISTSKUSREQUEST']._serialized_end=421
  _globals['_LISTSKUSRESPONSE']._serialized_start=423
  _globals['_LISTSKUSRESPONSE']._serialized_end=510
  _globals['_SKUSERVICE']._serialized_start=513
  _globals['_SKUSERVICE']._serialized_end=752
# @@protoc_insertion_point(module_scope)
