# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/kms/v1/symmetric_crypto_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/kms/v1/symmetric_crypto_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.kms.v1 import symmetric_key_pb2 as yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/kms/v1/symmetric_crypto_service.proto\x12\x13yandex.cloud.kms.v1\x1a\x1cgoogle/api/annotations.proto\x1a\'yandex/cloud/kms/v1/symmetric_key.proto\x1a\x1dyandex/cloud/validation.proto\"\x9a\x01\n\x17SymmetricEncryptRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\nversion_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1f\n\x0b\x61\x61\x64_context\x18\x03 \x01(\x0c\x42\n\x8a\xc8\x31\x06<=8192\x12\"\n\tplaintext\x18\x04 \x01(\x0c\x42\x0f\xe8\xc7\x31\x01\x8a\xc8\x31\x07<=32768\"j\n\x18SymmetricEncryptResponse\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\nversion_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x12\n\nciphertext\x18\x03 \x01(\x0c\"r\n\x17SymmetricDecryptRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1f\n\x0b\x61\x61\x64_context\x18\x02 \x01(\x0c\x42\n\x8a\xc8\x31\x06<=8192\x12\x18\n\nciphertext\x18\x03 \x01(\x0c\x42\x04\xe8\xc7\x31\x01\"Q\n\x18SymmetricDecryptResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12\x11\n\tplaintext\x18\x03 \x01(\x0c\"\xcd\x01\n\x16GenerateDataKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\nversion_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1f\n\x0b\x61\x61\x64_context\x18\x03 \x01(\x0c\x42\n\x8a\xc8\x31\x06<=8192\x12>\n\rdata_key_spec\x18\x04 \x01(\x0e\x32\'.yandex.cloud.kms.v1.SymmetricAlgorithm\x12\x16\n\x0eskip_plaintext\x18\x05 \x01(\x08\"v\n\x17GenerateDataKeyResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x61ta_key_plaintext\x18\x03 \x01(\x0c\x12\x1b\n\x13\x64\x61ta_key_ciphertext\x18\x04 \x01(\x0c\"\xdf\x01\n\x19SymmetricReEncryptRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\nversion_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1f\n\x0b\x61\x61\x64_context\x18\x03 \x01(\x0c\x42\n\x8a\xc8\x31\x06<=8192\x12#\n\rsource_key_id\x18\x04 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12&\n\x12source_aad_context\x18\x05 \x01(\x0c\x42\n\x8a\xc8\x31\x06<=8192\x12\x18\n\nciphertext\x18\x06 \x01(\x0c\x42\x04\xe8\xc7\x31\x01\"\x86\x01\n\x1aSymmetricReEncryptResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12\x15\n\rsource_key_id\x18\x03 \x01(\t\x12\x19\n\x11source_version_id\x18\x04 \x01(\t\x12\x12\n\nciphertext\x18\x05 \x01(\x0c\x32\xfa\x04\n\x16SymmetricCryptoService\x12\x90\x01\n\x07\x45ncrypt\x12,.yandex.cloud.kms.v1.SymmetricEncryptRequest\x1a-.yandex.cloud.kms.v1.SymmetricEncryptResponse\"(\x82\xd3\xe4\x93\x02\"\"\x1d/kms/v1/keys/{key_id}:encrypt:\x01*\x12\x90\x01\n\x07\x44\x65\x63rypt\x12,.yandex.cloud.kms.v1.SymmetricDecryptRequest\x1a-.yandex.cloud.kms.v1.SymmetricDecryptResponse\"(\x82\xd3\xe4\x93\x02\"\"\x1d/kms/v1/keys/{key_id}:decrypt:\x01*\x12\x98\x01\n\tReEncrypt\x12..yandex.cloud.kms.v1.SymmetricReEncryptRequest\x1a/.yandex.cloud.kms.v1.SymmetricReEncryptResponse\"*\x82\xd3\xe4\x93\x02$\"\x1f/kms/v1/keys/{key_id}:reEncrypt:\x01*\x12\x9e\x01\n\x0fGenerateDataKey\x12+.yandex.cloud.kms.v1.GenerateDataKeyRequest\x1a,.yandex.cloud.kms.v1.GenerateDataKeyResponse\"0\x82\xd3\xe4\x93\x02*\"%/kms/v1/keys/{key_id}:generateDataKey:\x01*BV\n\x17yandex.cloud.api.kms.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1;kmsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.kms.v1.symmetric_crypto_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.kms.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1;kms'
  _globals['_SYMMETRICENCRYPTREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_SYMMETRICENCRYPTREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SYMMETRICENCRYPTREQUEST'].fields_by_name['version_id']._loaded_options = None
  _globals['_SYMMETRICENCRYPTREQUEST'].fields_by_name['version_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_SYMMETRICENCRYPTREQUEST'].fields_by_name['aad_context']._loaded_options = None
  _globals['_SYMMETRICENCRYPTREQUEST'].fields_by_name['aad_context']._serialized_options = b'\212\3101\006<=8192'
  _globals['_SYMMETRICENCRYPTREQUEST'].fields_by_name['plaintext']._loaded_options = None
  _globals['_SYMMETRICENCRYPTREQUEST'].fields_by_name['plaintext']._serialized_options = b'\350\3071\001\212\3101\007<=32768'
  _globals['_SYMMETRICENCRYPTRESPONSE'].fields_by_name['key_id']._loaded_options = None
  _globals['_SYMMETRICENCRYPTRESPONSE'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SYMMETRICENCRYPTRESPONSE'].fields_by_name['version_id']._loaded_options = None
  _globals['_SYMMETRICENCRYPTRESPONSE'].fields_by_name['version_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_SYMMETRICDECRYPTREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_SYMMETRICDECRYPTREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SYMMETRICDECRYPTREQUEST'].fields_by_name['aad_context']._loaded_options = None
  _globals['_SYMMETRICDECRYPTREQUEST'].fields_by_name['aad_context']._serialized_options = b'\212\3101\006<=8192'
  _globals['_SYMMETRICDECRYPTREQUEST'].fields_by_name['ciphertext']._loaded_options = None
  _globals['_SYMMETRICDECRYPTREQUEST'].fields_by_name['ciphertext']._serialized_options = b'\350\3071\001'
  _globals['_GENERATEDATAKEYREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_GENERATEDATAKEYREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GENERATEDATAKEYREQUEST'].fields_by_name['version_id']._loaded_options = None
  _globals['_GENERATEDATAKEYREQUEST'].fields_by_name['version_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_GENERATEDATAKEYREQUEST'].fields_by_name['aad_context']._loaded_options = None
  _globals['_GENERATEDATAKEYREQUEST'].fields_by_name['aad_context']._serialized_options = b'\212\3101\006<=8192'
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['version_id']._loaded_options = None
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['version_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['aad_context']._loaded_options = None
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['aad_context']._serialized_options = b'\212\3101\006<=8192'
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['source_key_id']._loaded_options = None
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['source_key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['source_aad_context']._loaded_options = None
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['source_aad_context']._serialized_options = b'\212\3101\006<=8192'
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['ciphertext']._loaded_options = None
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['ciphertext']._serialized_options = b'\350\3071\001'
  _globals['_SYMMETRICCRYPTOSERVICE'].methods_by_name['Encrypt']._loaded_options = None
  _globals['_SYMMETRICCRYPTOSERVICE'].methods_by_name['Encrypt']._serialized_options = b'\202\323\344\223\002\"\"\035/kms/v1/keys/{key_id}:encrypt:\001*'
  _globals['_SYMMETRICCRYPTOSERVICE'].methods_by_name['Decrypt']._loaded_options = None
  _globals['_SYMMETRICCRYPTOSERVICE'].methods_by_name['Decrypt']._serialized_options = b'\202\323\344\223\002\"\"\035/kms/v1/keys/{key_id}:decrypt:\001*'
  _globals['_SYMMETRICCRYPTOSERVICE'].methods_by_name['ReEncrypt']._loaded_options = None
  _globals['_SYMMETRICCRYPTOSERVICE'].methods_by_name['ReEncrypt']._serialized_options = b'\202\323\344\223\002$\"\037/kms/v1/keys/{key_id}:reEncrypt:\001*'
  _globals['_SYMMETRICCRYPTOSERVICE'].methods_by_name['GenerateDataKey']._loaded_options = None
  _globals['_SYMMETRICCRYPTOSERVICE'].methods_by_name['GenerateDataKey']._serialized_options = b'\202\323\344\223\002*\"%/kms/v1/keys/{key_id}:generateDataKey:\001*'
  _globals['_SYMMETRICENCRYPTREQUEST']._serialized_start=178
  _globals['_SYMMETRICENCRYPTREQUEST']._serialized_end=332
  _globals['_SYMMETRICENCRYPTRESPONSE']._serialized_start=334
  _globals['_SYMMETRICENCRYPTRESPONSE']._serialized_end=440
  _globals['_SYMMETRICDECRYPTREQUEST']._serialized_start=442
  _globals['_SYMMETRICDECRYPTREQUEST']._serialized_end=556
  _globals['_SYMMETRICDECRYPTRESPONSE']._serialized_start=558
  _globals['_SYMMETRICDECRYPTRESPONSE']._serialized_end=639
  _globals['_GENERATEDATAKEYREQUEST']._serialized_start=642
  _globals['_GENERATEDATAKEYREQUEST']._serialized_end=847
  _globals['_GENERATEDATAKEYRESPONSE']._serialized_start=849
  _globals['_GENERATEDATAKEYRESPONSE']._serialized_end=967
  _globals['_SYMMETRICREENCRYPTREQUEST']._serialized_start=970
  _globals['_SYMMETRICREENCRYPTREQUEST']._serialized_end=1193
  _globals['_SYMMETRICREENCRYPTRESPONSE']._serialized_start=1196
  _globals['_SYMMETRICREENCRYPTRESPONSE']._serialized_end=1330
  _globals['_SYMMETRICCRYPTOSERVICE']._serialized_start=1333
  _globals['_SYMMETRICCRYPTOSERVICE']._serialized_end=1967
# @@protoc_insertion_point(module_scope)
