# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/apploadbalancer/v1/target_group_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/apploadbalancer/v1/target_group_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.apploadbalancer.v1 import target_group_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_target__group__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/apploadbalancer/v1/target_group_service.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x32yandex/cloud/apploadbalancer/v1/target_group.proto\x1a\x1dyandex/cloud/validation.proto\"6\n\x15GetTargetGroupRequest\x12\x1d\n\x0ftarget_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8c\x01\n\x17ListTargetGroupsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"x\n\x18ListTargetGroupsResponse\x12\x43\n\rtarget_groups\x18\x01 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.TargetGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"9\n\x18\x44\x65leteTargetGroupRequest\x12\x1d\n\x0ftarget_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"4\n\x19\x44\x65leteTargetGroupMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"\xc6\x03\n\x18UpdateTargetGroupRequest\x12\x1d\n\x0ftarget_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9a\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x45.yandex.cloud.apploadbalancer.v1.UpdateTargetGroupRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x38\n\x07targets\x18\x06 \x03(\x0b\x32\'.yandex.cloud.apploadbalancer.v1.Target\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"4\n\x19UpdateTargetGroupMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"\x8f\x03\n\x18\x43reateTargetGroupRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9a\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x45.yandex.cloud.apploadbalancer.v1.CreateTargetGroupRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x38\n\x07targets\x18\x05 \x03(\x0b\x32\'.yandex.cloud.apploadbalancer.v1.Target\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"4\n\x19\x43reateTargetGroupMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"t\n\x11\x41\x64\x64TargetsRequest\x12\x1d\n\x0ftarget_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12@\n\x07targets\x18\x02 \x03(\x0b\x32\'.yandex.cloud.apploadbalancer.v1.TargetB\x06\x82\xc8\x31\x02>0\"-\n\x12\x41\x64\x64TargetsMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"w\n\x14RemoveTargetsRequest\x12\x1d\n\x0ftarget_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12@\n\x07targets\x18\x02 \x03(\x0b\x32\'.yandex.cloud.apploadbalancer.v1.TargetB\x06\x82\xc8\x31\x02>0\"0\n\x15RemoveTargetsMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"\x87\x01\n ListTargetGroupOperationsRequest\x12%\n\x0ftarget_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"s\n!ListTargetGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xee\x0c\n\x12TargetGroupService\x12\xa7\x01\n\x03Get\x12\x36.yandex.cloud.apploadbalancer.v1.GetTargetGroupRequest\x1a,.yandex.cloud.apploadbalancer.v1.TargetGroup\":\x82\xd3\xe4\x93\x02\x34\x12\x32/apploadbalancer/v1/targetGroups/{target_group_id}\x12\xa5\x01\n\x04List\x12\x38.yandex.cloud.apploadbalancer.v1.ListTargetGroupsRequest\x1a\x39.yandex.cloud.apploadbalancer.v1.ListTargetGroupsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /apploadbalancer/v1/targetGroups\x12\xbf\x01\n\x06\x43reate\x12\x39.yandex.cloud.apploadbalancer.v1.CreateTargetGroupRequest\x1a!.yandex.cloud.operation.Operation\"W\xb2\xd2*(\n\x19\x43reateTargetGroupMetadata\x12\x0bTargetGroup\x82\xd3\xe4\x93\x02%\" /apploadbalancer/v1/targetGroups:\x01*\x12\xd1\x01\n\x06Update\x12\x39.yandex.cloud.apploadbalancer.v1.UpdateTargetGroupRequest\x1a!.yandex.cloud.operation.Operation\"i\xb2\xd2*(\n\x19UpdateTargetGroupMetadata\x12\x0bTargetGroup\x82\xd3\xe4\x93\x02\x37\x32\x32/apploadbalancer/v1/targetGroups/{target_group_id}:\x01*\x12\xd8\x01\n\x06\x44\x65lete\x12\x39.yandex.cloud.apploadbalancer.v1.DeleteTargetGroupRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*2\n\x19\x44\x65leteTargetGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x34*2/apploadbalancer/v1/targetGroups/{target_group_id}\x12\xd2\x01\n\nAddTargets\x12\x32.yandex.cloud.apploadbalancer.v1.AddTargetsRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2*!\n\x12\x41\x64\x64TargetsMetadata\x12\x0bTargetGroup\x82\xd3\xe4\x93\x02\x42\"=/apploadbalancer/v1/targetGroups/{target_group_id}:addTargets:\x01*\x12\xde\x01\n\rRemoveTargets\x12\x35.yandex.cloud.apploadbalancer.v1.RemoveTargetsRequest\x1a!.yandex.cloud.operation.Operation\"s\xb2\xd2*$\n\x15RemoveTargetsMetadata\x12\x0bTargetGroup\x82\xd3\xe4\x93\x02\x45\"@/apploadbalancer/v1/targetGroups/{target_group_id}:removeTargets:\x01*\x12\xde\x01\n\x0eListOperations\x12\x41.yandex.cloud.apploadbalancer.v1.ListTargetGroupOperationsRequest\x1a\x42.yandex.cloud.apploadbalancer.v1.ListTargetGroupOperationsResponse\"E\x82\xd3\xe4\x93\x02?\x12=/apploadbalancer/v1/targetGroups/{target_group_id}/operationsBz\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.apploadbalancer.v1.target_group_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer'
  _globals['_GETTARGETGROUPREQUEST'].fields_by_name['target_group_id']._loaded_options = None
  _globals['_GETTARGETGROUPREQUEST'].fields_by_name['target_group_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTTARGETGROUPSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTTARGETGROUPSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTTARGETGROUPSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTTARGETGROUPSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTTARGETGROUPSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTTARGETGROUPSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTTARGETGROUPSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTTARGETGROUPSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_DELETETARGETGROUPREQUEST'].fields_by_name['target_group_id']._loaded_options = None
  _globals['_DELETETARGETGROUPREQUEST'].fields_by_name['target_group_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATETARGETGROUPREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATETARGETGROUPREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATETARGETGROUPREQUEST'].fields_by_name['target_group_id']._loaded_options = None
  _globals['_UPDATETARGETGROUPREQUEST'].fields_by_name['target_group_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATETARGETGROUPREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATETARGETGROUPREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?'
  _globals['_UPDATETARGETGROUPREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATETARGETGROUPREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATETARGETGROUPREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATETARGETGROUPREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_CREATETARGETGROUPREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATETARGETGROUPREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATETARGETGROUPREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATETARGETGROUPREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATETARGETGROUPREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATETARGETGROUPREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?'
  _globals['_CREATETARGETGROUPREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATETARGETGROUPREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATETARGETGROUPREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATETARGETGROUPREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_ADDTARGETSREQUEST'].fields_by_name['target_group_id']._loaded_options = None
  _globals['_ADDTARGETSREQUEST'].fields_by_name['target_group_id']._serialized_options = b'\350\3071\001'
  _globals['_ADDTARGETSREQUEST'].fields_by_name['targets']._loaded_options = None
  _globals['_ADDTARGETSREQUEST'].fields_by_name['targets']._serialized_options = b'\202\3101\002>0'
  _globals['_REMOVETARGETSREQUEST'].fields_by_name['target_group_id']._loaded_options = None
  _globals['_REMOVETARGETSREQUEST'].fields_by_name['target_group_id']._serialized_options = b'\350\3071\001'
  _globals['_REMOVETARGETSREQUEST'].fields_by_name['targets']._loaded_options = None
  _globals['_REMOVETARGETSREQUEST'].fields_by_name['targets']._serialized_options = b'\202\3101\002>0'
  _globals['_LISTTARGETGROUPOPERATIONSREQUEST'].fields_by_name['target_group_id']._loaded_options = None
  _globals['_LISTTARGETGROUPOPERATIONSREQUEST'].fields_by_name['target_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTTARGETGROUPOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTTARGETGROUPOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTTARGETGROUPOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTTARGETGROUPOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_TARGETGROUPSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_TARGETGROUPSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0024\0222/apploadbalancer/v1/targetGroups/{target_group_id}'
  _globals['_TARGETGROUPSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_TARGETGROUPSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\"\022 /apploadbalancer/v1/targetGroups'
  _globals['_TARGETGROUPSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_TARGETGROUPSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*(\n\031CreateTargetGroupMetadata\022\013TargetGroup\202\323\344\223\002%\" /apploadbalancer/v1/targetGroups:\001*'
  _globals['_TARGETGROUPSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_TARGETGROUPSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*(\n\031UpdateTargetGroupMetadata\022\013TargetGroup\202\323\344\223\002722/apploadbalancer/v1/targetGroups/{target_group_id}:\001*'
  _globals['_TARGETGROUPSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_TARGETGROUPSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*2\n\031DeleteTargetGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\0024*2/apploadbalancer/v1/targetGroups/{target_group_id}'
  _globals['_TARGETGROUPSERVICE'].methods_by_name['AddTargets']._loaded_options = None
  _globals['_TARGETGROUPSERVICE'].methods_by_name['AddTargets']._serialized_options = b'\262\322*!\n\022AddTargetsMetadata\022\013TargetGroup\202\323\344\223\002B\"=/apploadbalancer/v1/targetGroups/{target_group_id}:addTargets:\001*'
  _globals['_TARGETGROUPSERVICE'].methods_by_name['RemoveTargets']._loaded_options = None
  _globals['_TARGETGROUPSERVICE'].methods_by_name['RemoveTargets']._serialized_options = b'\262\322*$\n\025RemoveTargetsMetadata\022\013TargetGroup\202\323\344\223\002E\"@/apploadbalancer/v1/targetGroups/{target_group_id}:removeTargets:\001*'
  _globals['_TARGETGROUPSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_TARGETGROUPSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002?\022=/apploadbalancer/v1/targetGroups/{target_group_id}/operations'
  _globals['_GETTARGETGROUPREQUEST']._serialized_start=316
  _globals['_GETTARGETGROUPREQUEST']._serialized_end=370
  _globals['_LISTTARGETGROUPSREQUEST']._serialized_start=373
  _globals['_LISTTARGETGROUPSREQUEST']._serialized_end=513
  _globals['_LISTTARGETGROUPSRESPONSE']._serialized_start=515
  _globals['_LISTTARGETGROUPSRESPONSE']._serialized_end=635
  _globals['_DELETETARGETGROUPREQUEST']._serialized_start=637
  _globals['_DELETETARGETGROUPREQUEST']._serialized_end=694
  _globals['_DELETETARGETGROUPMETADATA']._serialized_start=696
  _globals['_DELETETARGETGROUPMETADATA']._serialized_end=748
  _globals['_UPDATETARGETGROUPREQUEST']._serialized_start=751
  _globals['_UPDATETARGETGROUPREQUEST']._serialized_end=1205
  _globals['_UPDATETARGETGROUPREQUEST_LABELSENTRY']._serialized_start=1160
  _globals['_UPDATETARGETGROUPREQUEST_LABELSENTRY']._serialized_end=1205
  _globals['_UPDATETARGETGROUPMETADATA']._serialized_start=1207
  _globals['_UPDATETARGETGROUPMETADATA']._serialized_end=1259
  _globals['_CREATETARGETGROUPREQUEST']._serialized_start=1262
  _globals['_CREATETARGETGROUPREQUEST']._serialized_end=1661
  _globals['_CREATETARGETGROUPREQUEST_LABELSENTRY']._serialized_start=1160
  _globals['_CREATETARGETGROUPREQUEST_LABELSENTRY']._serialized_end=1205
  _globals['_CREATETARGETGROUPMETADATA']._serialized_start=1663
  _globals['_CREATETARGETGROUPMETADATA']._serialized_end=1715
  _globals['_ADDTARGETSREQUEST']._serialized_start=1717
  _globals['_ADDTARGETSREQUEST']._serialized_end=1833
  _globals['_ADDTARGETSMETADATA']._serialized_start=1835
  _globals['_ADDTARGETSMETADATA']._serialized_end=1880
  _globals['_REMOVETARGETSREQUEST']._serialized_start=1882
  _globals['_REMOVETARGETSREQUEST']._serialized_end=2001
  _globals['_REMOVETARGETSMETADATA']._serialized_start=2003
  _globals['_REMOVETARGETSMETADATA']._serialized_end=2051
  _globals['_LISTTARGETGROUPOPERATIONSREQUEST']._serialized_start=2054
  _globals['_LISTTARGETGROUPOPERATIONSREQUEST']._serialized_end=2189
  _globals['_LISTTARGETGROUPOPERATIONSRESPONSE']._serialized_start=2191
  _globals['_LISTTARGETGROUPOPERATIONSRESPONSE']._serialized_end=2306
  _globals['_TARGETGROUPSERVICE']._serialized_start=2309
  _globals['_TARGETGROUPSERVICE']._serialized_end=3955
# @@protoc_insertion_point(module_scope)
