# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/serverless/eventrouter/v1/connector.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/serverless/eventrouter/v1/connector.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/serverless/eventrouter/v1/connector.proto\x12&yandex.cloud.serverless.eventrouter.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xe3\x04\n\tConnector\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x62us_id\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x03 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x04 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12M\n\x06labels\x18\x08 \x03(\x0b\x32=.yandex.cloud.serverless.eventrouter.v1.Connector.LabelsEntry\x12>\n\x06source\x18\t \x01(\x0b\x32..yandex.cloud.serverless.eventrouter.v1.Source\x12\x1b\n\x13\x64\x65letion_protection\x18\n \x01(\x08\x12H\n\x06status\x18\x0b \x01(\x0e\x32\x38.yandex.cloud.serverless.eventrouter.v1.Connector.Status\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\x0b\n\x07STOPPED\x10\x02\x12\x16\n\x12RESOURCE_NOT_FOUND\x10\x03\x12\x15\n\x11PERMISSION_DENIED\x10\x04\x12\x15\n\x11SUBJECT_NOT_FOUND\x10\x05\x12\x0c\n\x08\x44\x45LETING\x10\x07\x12\x0c\n\x08\x43REATING\x10\x08\"\xf2\x01\n\x06Source\x12I\n\x0b\x64\x61ta_stream\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.serverless.eventrouter.v1.DataStreamH\x00\x12M\n\rmessage_queue\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.serverless.eventrouter.v1.MessageQueueH\x00\x12>\n\x05timer\x18\x03 \x01(\x0b\x32-.yandex.cloud.serverless.eventrouter.v1.TimerH\x00\x42\x0e\n\x06source\x12\x04\xc0\xc1\x31\x01\"y\n\nDataStream\x12\x16\n\x08\x64\x61tabase\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bstream_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x16\n\x08\x63onsumer\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12 \n\x12service_account_id\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\"\xf0\x01\n\x0cMessageQueue\x12\x17\n\tqueue_arn\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12(\n\x12service_account_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12@\n\x12visibility_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05<=12h\x12\x1c\n\nbatch_size\x18\x04 \x01(\x03\x42\x08\xfa\xc7\x31\x04<=10\x12=\n\x0fpolling_timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05<=20s\"e\n\x05Timer\x12&\n\x0f\x63ron_expression\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\x12\x11\n\ttime_zone\x18\x02 \x01(\t\x12\x1b\n\x07payload\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=4096J\x04\x08\x03\x10\x04\x42\x8a\x01\n*yandex.cloud.api.serverless.eventrouter.v1B\x04PERCZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.eventrouter.v1.connector_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*yandex.cloud.api.serverless.eventrouter.v1B\004PERCZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouter'
  _globals['_CONNECTOR_LABELSENTRY']._loaded_options = None
  _globals['_CONNECTOR_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_SOURCE'].oneofs_by_name['source']._loaded_options = None
  _globals['_SOURCE'].oneofs_by_name['source']._serialized_options = b'\300\3011\001'
  _globals['_DATASTREAM'].fields_by_name['database']._loaded_options = None
  _globals['_DATASTREAM'].fields_by_name['database']._serialized_options = b'\350\3071\001'
  _globals['_DATASTREAM'].fields_by_name['stream_name']._loaded_options = None
  _globals['_DATASTREAM'].fields_by_name['stream_name']._serialized_options = b'\350\3071\001'
  _globals['_DATASTREAM'].fields_by_name['consumer']._loaded_options = None
  _globals['_DATASTREAM'].fields_by_name['consumer']._serialized_options = b'\350\3071\001'
  _globals['_DATASTREAM'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_DATASTREAM'].fields_by_name['service_account_id']._serialized_options = b'\350\3071\001'
  _globals['_MESSAGEQUEUE'].fields_by_name['queue_arn']._loaded_options = None
  _globals['_MESSAGEQUEUE'].fields_by_name['queue_arn']._serialized_options = b'\350\3071\001'
  _globals['_MESSAGEQUEUE'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_MESSAGEQUEUE'].fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_MESSAGEQUEUE'].fields_by_name['visibility_timeout']._loaded_options = None
  _globals['_MESSAGEQUEUE'].fields_by_name['visibility_timeout']._serialized_options = b'\372\3071\005<=12h'
  _globals['_MESSAGEQUEUE'].fields_by_name['batch_size']._loaded_options = None
  _globals['_MESSAGEQUEUE'].fields_by_name['batch_size']._serialized_options = b'\372\3071\004<=10'
  _globals['_MESSAGEQUEUE'].fields_by_name['polling_timeout']._loaded_options = None
  _globals['_MESSAGEQUEUE'].fields_by_name['polling_timeout']._serialized_options = b'\372\3071\005<=20s'
  _globals['_TIMER'].fields_by_name['cron_expression']._loaded_options = None
  _globals['_TIMER'].fields_by_name['cron_expression']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_TIMER'].fields_by_name['payload']._loaded_options = None
  _globals['_TIMER'].fields_by_name['payload']._serialized_options = b'\212\3101\006<=4096'
  _globals['_CONNECTOR']._serialized_start=195
  _globals['_CONNECTOR']._serialized_end=806
  _globals['_CONNECTOR_LABELSENTRY']._serialized_start=602
  _globals['_CONNECTOR_LABELSENTRY']._serialized_end=647
  _globals['_CONNECTOR_STATUS']._serialized_start=650
  _globals['_CONNECTOR_STATUS']._serialized_end=806
  _globals['_SOURCE']._serialized_start=809
  _globals['_SOURCE']._serialized_end=1051
  _globals['_DATASTREAM']._serialized_start=1053
  _globals['_DATASTREAM']._serialized_end=1174
  _globals['_MESSAGEQUEUE']._serialized_start=1177
  _globals['_MESSAGEQUEUE']._serialized_end=1417
  _globals['_TIMER']._serialized_start=1419
  _globals['_TIMER']._serialized_end=1520
# @@protoc_insertion_point(module_scope)
